/* gnome-ask-password-agent.c generated by valac 0.56.19, the Vala compiler
 * generated from gnome-ask-password-agent.vala, do not modify */

#include <time.h>
#include <glib.h>
#include <gtk/gtk.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <libnotify/notify.h>
#include <stdio.h>
#include <gio/gunixoutputstream.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_PASSWORD_DIALOG (password_dialog_get_type ())
#define PASSWORD_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PASSWORD_DIALOG, PasswordDialog))
#define PASSWORD_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PASSWORD_DIALOG, PasswordDialogClass))
#define IS_PASSWORD_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PASSWORD_DIALOG))
#define IS_PASSWORD_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PASSWORD_DIALOG))
#define PASSWORD_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PASSWORD_DIALOG, PasswordDialogClass))

typedef struct _PasswordDialog PasswordDialog;
typedef struct _PasswordDialogClass PasswordDialogClass;
typedef struct _PasswordDialogPrivate PasswordDialogPrivate;
enum  {
	PASSWORD_DIALOG_0_PROPERTY,
	PASSWORD_DIALOG_NUM_PROPERTIES
};
static GParamSpec* password_dialog_properties[PASSWORD_DIALOG_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TYPE_MY_STATUS_ICON (my_status_icon_get_type ())
#define MY_STATUS_ICON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MY_STATUS_ICON, MyStatusIcon))
#define MY_STATUS_ICON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MY_STATUS_ICON, MyStatusIconClass))
#define IS_MY_STATUS_ICON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MY_STATUS_ICON))
#define IS_MY_STATUS_ICON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MY_STATUS_ICON))
#define MY_STATUS_ICON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MY_STATUS_ICON, MyStatusIconClass))

typedef struct _MyStatusIcon MyStatusIcon;
typedef struct _MyStatusIconClass MyStatusIconClass;
typedef struct _MyStatusIconPrivate MyStatusIconPrivate;
enum  {
	MY_STATUS_ICON_0_PROPERTY,
	MY_STATUS_ICON_NUM_PROPERTIES
};
static GParamSpec* my_status_icon_properties[MY_STATUS_ICON_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_key_file_unref0(var) ((var == NULL) ? NULL : (var = (g_key_file_unref (var), NULL)))

struct _PasswordDialog {
	GtkDialog parent_instance;
	PasswordDialogPrivate * priv;
	GtkEntry* entry;
};

struct _PasswordDialogClass {
	GtkDialogClass parent_class;
};

struct _MyStatusIcon {
	GtkStatusIcon parent_instance;
	MyStatusIconPrivate * priv;
};

struct _MyStatusIconClass {
	GtkStatusIconClass parent_class;
};

struct _MyStatusIconPrivate {
	GFile* directory;
	GFile* current;
	GFileMonitor* file_monitor;
	gchar* message;
	gchar* icon;
	gchar* socket;
	PasswordDialog* password_dialog;
	NotifyNotification* n;
};

static gpointer password_dialog_parent_class = NULL;
static gint MyStatusIcon_private_offset;
static gpointer my_status_icon_parent_class = NULL;

VALA_EXTERN GType password_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PasswordDialog, g_object_unref)
VALA_EXTERN PasswordDialog* password_dialog_new (const gchar* message,
                                     const gchar* icon);
VALA_EXTERN PasswordDialog* password_dialog_construct (GType object_type,
                                           const gchar* message,
                                           const gchar* icon);
VALA_EXTERN void password_dialog_on_entry_activated (PasswordDialog* self);
static void _password_dialog_on_entry_activated_gtk_entry_activate (GtkEntry* _sender,
                                                             gpointer self);
static void password_dialog_finalize (GObject * obj);
static GType password_dialog_get_type_once (void);
VALA_EXTERN GType my_status_icon_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MyStatusIcon, g_object_unref)
VALA_EXTERN MyStatusIcon* my_status_icon_new (GError** error);
VALA_EXTERN MyStatusIcon* my_status_icon_construct (GType object_type,
                                        GError** error);
static void my_status_icon_file_monitor_changed (MyStatusIcon* self,
                                          GFile* file,
                                          GFile* other_file,
                                          GFileMonitorEvent event_type);
static void _my_status_icon_file_monitor_changed_g_file_monitor_changed (GFileMonitor* _sender,
                                                                  GFile* file,
                                                                  GFile* other_file,
                                                                  GFileMonitorEvent event_type,
                                                                  gpointer self);
static void my_status_icon_look_for_password (MyStatusIcon* self,
                                       GError** error);
static void my_status_icon_status_icon_activate (MyStatusIcon* self);
static void _my_status_icon_status_icon_activate_gtk_status_icon_activate (GtkStatusIcon* _sender,
                                                                    gpointer self);
VALA_EXTERN void show_error (const gchar* e);
static gboolean my_status_icon_load_password (MyStatusIcon* self,
                                       GError** error);
static void __lambda4_ (MyStatusIcon* self);
static void ___lambda4__notify_notification_closed (NotifyNotification* _sender,
                                             gpointer self);
static void _my_status_icon_status_icon_activate_notify_action_callback (NotifyNotification* notification,
                                                                  const gchar* action,
                                                                  gpointer self);
static void ___lambda5_ (MyStatusIcon* self,
                  GPid pid,
                  gint status);
static void ____lambda5__gchild_watch_func (GPid pid,
                                     gint wait_status,
                                     gpointer self);
static void my_status_icon_finalize (GObject * obj);
static GType my_status_icon_get_type_once (void);
static gint _vala_main (gchar** args,
                 gint args_length1);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

const GOptionEntry entries[1] = {{NULL}};

/***
  This file is part of systemd.

  Copyright 2010 Lennart Poettering

  systemd is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  systemd is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with systemd; If not, see <http://www.gnu.org/licenses/>.
***/
static gpointer
_g_object_ref0 (gpointer self)
{
#line 42 "src/gnome-ask-password-agent.vala"
	return self ? g_object_ref (self) : NULL;
#line 186 "gnome-ask-password-agent.c"
}

static void
_password_dialog_on_entry_activated_gtk_entry_activate (GtkEntry* _sender,
                                                        gpointer self)
{
#line 62 "src/gnome-ask-password-agent.vala"
	password_dialog_on_entry_activated ((PasswordDialog*) self);
#line 195 "gnome-ask-password-agent.c"
}

PasswordDialog*
password_dialog_construct (GType object_type,
                           const gchar* message,
                           const gchar* icon)
{
	PasswordDialog * self = NULL;
	GtkContainer* content = NULL;
	GtkBox* _tmp0_;
	GtkContainer* _tmp1_;
	GtkBox* hbox = NULL;
	GtkBox* _tmp2_;
	GtkImage* image = NULL;
	GtkImage* _tmp3_;
	GtkBox* vbox = NULL;
	GtkBox* _tmp4_;
	GtkLabel* label = NULL;
	GtkLabel* _tmp5_;
	GtkEntry* _tmp6_;
	GtkEntry* _tmp7_;
	GtkEntry* _tmp8_;
	GtkEntry* _tmp9_;
	GtkEntry* _tmp10_;
#line 33 "src/gnome-ask-password-agent.vala"
	g_return_val_if_fail (message != NULL, NULL);
#line 33 "src/gnome-ask-password-agent.vala"
	g_return_val_if_fail (icon != NULL, NULL);
#line 33 "src/gnome-ask-password-agent.vala"
	self = (PasswordDialog*) g_object_new (object_type, NULL);
#line 34 "src/gnome-ask-password-agent.vala"
	gtk_window_set_title ((GtkWindow*) self, "System Password");
#line 35 "src/gnome-ask-password-agent.vala"
	gtk_container_set_border_width ((GtkContainer*) self, (guint) 8);
#line 36 "src/gnome-ask-password-agent.vala"
	gtk_dialog_set_default_response ((GtkDialog*) self, (gint) GTK_RESPONSE_OK);
#line 37 "src/gnome-ask-password-agent.vala"
	gtk_window_set_icon_name ((GtkWindow*) self, icon);
#line 39 "src/gnome-ask-password-agent.vala"
	gtk_dialog_add_button ((GtkDialog*) self, GTK_STOCK_CANCEL, (gint) GTK_RESPONSE_CANCEL);
#line 40 "src/gnome-ask-password-agent.vala"
	gtk_dialog_add_button ((GtkDialog*) self, GTK_STOCK_OK, (gint) GTK_RESPONSE_OK);
#line 42 "src/gnome-ask-password-agent.vala"
	_tmp0_ = gtk_dialog_get_content_area ((GtkDialog*) self);
#line 42 "src/gnome-ask-password-agent.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_container_get_type (), GtkContainer));
#line 42 "src/gnome-ask-password-agent.vala"
	content = _tmp1_;
#line 44 "src/gnome-ask-password-agent.vala"
	_tmp2_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 16);
#line 44 "src/gnome-ask-password-agent.vala"
	g_object_ref_sink (_tmp2_);
#line 44 "src/gnome-ask-password-agent.vala"
	hbox = _tmp2_;
#line 45 "src/gnome-ask-password-agent.vala"
	gtk_container_set_border_width ((GtkContainer*) hbox, (guint) 8);
#line 46 "src/gnome-ask-password-agent.vala"
	gtk_container_add (content, (GtkWidget*) hbox);
#line 48 "src/gnome-ask-password-agent.vala"
	_tmp3_ = (GtkImage*) gtk_image_new_from_icon_name (icon, (GtkIconSize) GTK_ICON_SIZE_DIALOG);
#line 48 "src/gnome-ask-password-agent.vala"
	g_object_ref_sink (_tmp3_);
#line 48 "src/gnome-ask-password-agent.vala"
	image = _tmp3_;
#line 49 "src/gnome-ask-password-agent.vala"
	gtk_box_pack_start (hbox, (GtkWidget*) image, FALSE, FALSE, (guint) 0);
#line 51 "src/gnome-ask-password-agent.vala"
	_tmp4_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
#line 51 "src/gnome-ask-password-agent.vala"
	g_object_ref_sink (_tmp4_);
#line 51 "src/gnome-ask-password-agent.vala"
	vbox = _tmp4_;
#line 52 "src/gnome-ask-password-agent.vala"
	gtk_box_pack_start (hbox, (GtkWidget*) vbox, TRUE, TRUE, (guint) 0);
#line 54 "src/gnome-ask-password-agent.vala"
	_tmp5_ = (GtkLabel*) gtk_label_new (message);
#line 54 "src/gnome-ask-password-agent.vala"
	g_object_ref_sink (_tmp5_);
#line 54 "src/gnome-ask-password-agent.vala"
	label = _tmp5_;
#line 55 "src/gnome-ask-password-agent.vala"
	gtk_box_pack_start (vbox, (GtkWidget*) label, FALSE, FALSE, (guint) 0);
#line 57 "src/gnome-ask-password-agent.vala"
	_tmp6_ = (GtkEntry*) gtk_entry_new ();
#line 57 "src/gnome-ask-password-agent.vala"
	g_object_ref_sink (_tmp6_);
#line 57 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (self->entry);
#line 57 "src/gnome-ask-password-agent.vala"
	self->entry = _tmp6_;
#line 58 "src/gnome-ask-password-agent.vala"
	_tmp7_ = self->entry;
#line 58 "src/gnome-ask-password-agent.vala"
	gtk_entry_set_visibility (_tmp7_, FALSE);
#line 59 "src/gnome-ask-password-agent.vala"
	_tmp8_ = self->entry;
#line 59 "src/gnome-ask-password-agent.vala"
	gtk_entry_set_activates_default (_tmp8_, TRUE);
#line 60 "src/gnome-ask-password-agent.vala"
	_tmp9_ = self->entry;
#line 60 "src/gnome-ask-password-agent.vala"
	gtk_box_pack_start (vbox, (GtkWidget*) _tmp9_, FALSE, FALSE, (guint) 0);
#line 62 "src/gnome-ask-password-agent.vala"
	_tmp10_ = self->entry;
#line 62 "src/gnome-ask-password-agent.vala"
	g_signal_connect_object (_tmp10_, "activate", (GCallback) _password_dialog_on_entry_activated_gtk_entry_activate, self, 0);
#line 64 "src/gnome-ask-password-agent.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 33 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (label);
#line 33 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (vbox);
#line 33 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (image);
#line 33 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (hbox);
#line 33 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (content);
#line 33 "src/gnome-ask-password-agent.vala"
	return self;
#line 316 "gnome-ask-password-agent.c"
}

PasswordDialog*
password_dialog_new (const gchar* message,
                     const gchar* icon)
{
#line 33 "src/gnome-ask-password-agent.vala"
	return password_dialog_construct (TYPE_PASSWORD_DIALOG, message, icon);
#line 325 "gnome-ask-password-agent.c"
}

void
password_dialog_on_entry_activated (PasswordDialog* self)
{
#line 67 "src/gnome-ask-password-agent.vala"
	g_return_if_fail (self != NULL);
#line 68 "src/gnome-ask-password-agent.vala"
	gtk_dialog_response ((GtkDialog*) self, (gint) GTK_RESPONSE_OK);
#line 335 "gnome-ask-password-agent.c"
}

static void
password_dialog_class_init (PasswordDialogClass * klass,
                            gpointer klass_data)
{
#line 29 "src/gnome-ask-password-agent.vala"
	password_dialog_parent_class = g_type_class_peek_parent (klass);
#line 29 "src/gnome-ask-password-agent.vala"
	G_OBJECT_CLASS (klass)->finalize = password_dialog_finalize;
#line 346 "gnome-ask-password-agent.c"
}

static void
password_dialog_instance_init (PasswordDialog * self,
                               gpointer klass)
{
}

static void
password_dialog_finalize (GObject * obj)
{
	PasswordDialog * self;
#line 29 "src/gnome-ask-password-agent.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PASSWORD_DIALOG, PasswordDialog);
#line 31 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (self->entry);
#line 29 "src/gnome-ask-password-agent.vala"
	G_OBJECT_CLASS (password_dialog_parent_class)->finalize (obj);
#line 365 "gnome-ask-password-agent.c"
}

static GType
password_dialog_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (PasswordDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) password_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PasswordDialog), 0, (GInstanceInitFunc) password_dialog_instance_init, NULL };
	GType password_dialog_type_id;
	password_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "PasswordDialog", &g_define_type_info, 0);
	return password_dialog_type_id;
}

GType
password_dialog_get_type (void)
{
	static volatile gsize password_dialog_type_id__once = 0;
	if (g_once_init_enter (&password_dialog_type_id__once)) {
		GType password_dialog_type_id;
		password_dialog_type_id = password_dialog_get_type_once ();
		g_once_init_leave (&password_dialog_type_id__once, password_dialog_type_id);
	}
	return password_dialog_type_id__once;
}

static inline gpointer
my_status_icon_get_instance_private (MyStatusIcon* self)
{
	return G_STRUCT_MEMBER_P (self, MyStatusIcon_private_offset);
}

static void
_my_status_icon_file_monitor_changed_g_file_monitor_changed (GFileMonitor* _sender,
                                                             GFile* file,
                                                             GFile* other_file,
                                                             GFileMonitorEvent event_type,
                                                             gpointer self)
{
#line 91 "src/gnome-ask-password-agent.vala"
	my_status_icon_file_monitor_changed ((MyStatusIcon*) self, file, other_file, event_type);
#line 404 "gnome-ask-password-agent.c"
}

static void
_my_status_icon_status_icon_activate_gtk_status_icon_activate (GtkStatusIcon* _sender,
                                                               gpointer self)
{
#line 96 "src/gnome-ask-password-agent.vala"
	my_status_icon_status_icon_activate ((MyStatusIcon*) self);
#line 413 "gnome-ask-password-agent.c"
}

MyStatusIcon*
my_status_icon_construct (GType object_type,
                          GError** error)
{
	MyStatusIcon * self = NULL;
	GFile* _tmp0_;
	GFileMonitor* _tmp1_ = NULL;
	GFile* _tmp2_;
	GFileMonitor* _tmp3_;
	GFileMonitor* _tmp4_;
	GFileMonitor* _tmp5_;
	GError* _inner_error0_ = NULL;
#line 86 "src/gnome-ask-password-agent.vala"
	self = (MyStatusIcon*) g_object_new (object_type, "icon-name", "dialog-password", NULL);
#line 87 "src/gnome-ask-password-agent.vala"
	gtk_status_icon_set_title ((GtkStatusIcon*) self, "System Password Request");
#line 89 "src/gnome-ask-password-agent.vala"
	_tmp0_ = g_file_new_for_path ("/run/systemd/ask-password/");
#line 89 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (self->priv->directory);
#line 89 "src/gnome-ask-password-agent.vala"
	self->priv->directory = _tmp0_;
#line 90 "src/gnome-ask-password-agent.vala"
	_tmp2_ = self->priv->directory;
#line 90 "src/gnome-ask-password-agent.vala"
	_tmp3_ = g_file_monitor_directory (_tmp2_, 0, NULL, &_inner_error0_);
#line 90 "src/gnome-ask-password-agent.vala"
	_tmp1_ = _tmp3_;
#line 90 "src/gnome-ask-password-agent.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 90 "src/gnome-ask-password-agent.vala"
		g_propagate_error (error, _inner_error0_);
#line 90 "src/gnome-ask-password-agent.vala"
		_g_object_unref0 (self);
#line 90 "src/gnome-ask-password-agent.vala"
		return NULL;
#line 452 "gnome-ask-password-agent.c"
	}
#line 90 "src/gnome-ask-password-agent.vala"
	_tmp4_ = _tmp1_;
#line 90 "src/gnome-ask-password-agent.vala"
	_tmp1_ = NULL;
#line 90 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (self->priv->file_monitor);
#line 90 "src/gnome-ask-password-agent.vala"
	self->priv->file_monitor = _tmp4_;
#line 91 "src/gnome-ask-password-agent.vala"
	_tmp5_ = self->priv->file_monitor;
#line 91 "src/gnome-ask-password-agent.vala"
	g_signal_connect_object (_tmp5_, "changed", (GCallback) _my_status_icon_file_monitor_changed_g_file_monitor_changed, self, 0);
#line 93 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (self->priv->current);
#line 93 "src/gnome-ask-password-agent.vala"
	self->priv->current = NULL;
#line 94 "src/gnome-ask-password-agent.vala"
	my_status_icon_look_for_password (self, &_inner_error0_);
#line 94 "src/gnome-ask-password-agent.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 94 "src/gnome-ask-password-agent.vala"
		g_propagate_error (error, _inner_error0_);
#line 94 "src/gnome-ask-password-agent.vala"
		_g_object_unref0 (_tmp1_);
#line 94 "src/gnome-ask-password-agent.vala"
		_g_object_unref0 (self);
#line 94 "src/gnome-ask-password-agent.vala"
		return NULL;
#line 482 "gnome-ask-password-agent.c"
	}
#line 96 "src/gnome-ask-password-agent.vala"
	g_signal_connect_object ((GtkStatusIcon*) self, "activate", (GCallback) _my_status_icon_status_icon_activate_gtk_status_icon_activate, self, 0);
#line 85 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (_tmp1_);
#line 85 "src/gnome-ask-password-agent.vala"
	return self;
#line 490 "gnome-ask-password-agent.c"
}

MyStatusIcon*
my_status_icon_new (GError** error)
{
#line 85 "src/gnome-ask-password-agent.vala"
	return my_status_icon_construct (TYPE_MY_STATUS_ICON, error);
#line 498 "gnome-ask-password-agent.c"
}

static void
my_status_icon_file_monitor_changed (MyStatusIcon* self,
                                     GFile* file,
                                     GFile* other_file,
                                     GFileMonitorEvent event_type)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_ = FALSE;
	GError* _inner_error0_ = NULL;
#line 99 "src/gnome-ask-password-agent.vala"
	g_return_if_fail (self != NULL);
#line 99 "src/gnome-ask-password-agent.vala"
	g_return_if_fail (file != NULL);
#line 101 "src/gnome-ask-password-agent.vala"
	_tmp0_ = g_file_get_basename (file);
#line 101 "src/gnome-ask-password-agent.vala"
	_tmp1_ = _tmp0_;
#line 101 "src/gnome-ask-password-agent.vala"
	_tmp2_ = !g_str_has_prefix (_tmp1_, "ask.");
#line 101 "src/gnome-ask-password-agent.vala"
	_g_free0 (_tmp1_);
#line 101 "src/gnome-ask-password-agent.vala"
	if (_tmp2_) {
#line 102 "src/gnome-ask-password-agent.vala"
		return;
#line 528 "gnome-ask-password-agent.c"
	}
#line 104 "src/gnome-ask-password-agent.vala"
	if (event_type == G_FILE_MONITOR_EVENT_CREATED) {
#line 104 "src/gnome-ask-password-agent.vala"
		_tmp3_ = TRUE;
#line 534 "gnome-ask-password-agent.c"
	} else {
#line 105 "src/gnome-ask-password-agent.vala"
		_tmp3_ = event_type == G_FILE_MONITOR_EVENT_DELETED;
#line 538 "gnome-ask-password-agent.c"
	}
#line 104 "src/gnome-ask-password-agent.vala"
	if (_tmp3_) {
#line 542 "gnome-ask-password-agent.c"
		{
#line 107 "src/gnome-ask-password-agent.vala"
			my_status_icon_look_for_password (self, &_inner_error0_);
#line 107 "src/gnome-ask-password-agent.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 548 "gnome-ask-password-agent.c"
				goto __catch0_g_error;
			}
		}
		goto __finally0;
		__catch0_g_error:
		{
			GError* e = NULL;
			GError* _tmp4_;
			const gchar* _tmp5_;
#line 106 "src/gnome-ask-password-agent.vala"
			e = _inner_error0_;
#line 106 "src/gnome-ask-password-agent.vala"
			_inner_error0_ = NULL;
#line 109 "src/gnome-ask-password-agent.vala"
			_tmp4_ = e;
#line 109 "src/gnome-ask-password-agent.vala"
			_tmp5_ = _tmp4_->message;
#line 109 "src/gnome-ask-password-agent.vala"
			show_error (_tmp5_);
#line 106 "src/gnome-ask-password-agent.vala"
			_g_error_free0 (e);
#line 570 "gnome-ask-password-agent.c"
		}
		__finally0:
#line 106 "src/gnome-ask-password-agent.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 106 "src/gnome-ask-password-agent.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 106 "src/gnome-ask-password-agent.vala"
			g_clear_error (&_inner_error0_);
#line 106 "src/gnome-ask-password-agent.vala"
			return;
#line 581 "gnome-ask-password-agent.c"
		}
	}
}

static void
my_status_icon_look_for_password (MyStatusIcon* self,
                                  GError** error)
{
	GFile* _tmp0_;
	GFile* _tmp4_;
	GFile* _tmp19_;
	GError* _inner_error0_ = NULL;
#line 114 "src/gnome-ask-password-agent.vala"
	g_return_if_fail (self != NULL);
#line 116 "src/gnome-ask-password-agent.vala"
	_tmp0_ = self->priv->current;
#line 116 "src/gnome-ask-password-agent.vala"
	if (_tmp0_ != NULL) {
#line 600 "gnome-ask-password-agent.c"
		GFile* _tmp1_;
#line 117 "src/gnome-ask-password-agent.vala"
		_tmp1_ = self->priv->current;
#line 117 "src/gnome-ask-password-agent.vala"
		if (!g_file_query_exists (_tmp1_, NULL)) {
#line 606 "gnome-ask-password-agent.c"
			PasswordDialog* _tmp2_;
#line 118 "src/gnome-ask-password-agent.vala"
			_g_object_unref0 (self->priv->current);
#line 118 "src/gnome-ask-password-agent.vala"
			self->priv->current = NULL;
#line 119 "src/gnome-ask-password-agent.vala"
			_tmp2_ = self->priv->password_dialog;
#line 119 "src/gnome-ask-password-agent.vala"
			if (_tmp2_ != NULL) {
#line 616 "gnome-ask-password-agent.c"
				PasswordDialog* _tmp3_;
#line 120 "src/gnome-ask-password-agent.vala"
				_tmp3_ = self->priv->password_dialog;
#line 120 "src/gnome-ask-password-agent.vala"
				gtk_dialog_response ((GtkDialog*) _tmp3_, (gint) GTK_RESPONSE_REJECT);
#line 622 "gnome-ask-password-agent.c"
			}
		}
	}
#line 124 "src/gnome-ask-password-agent.vala"
	_tmp4_ = self->priv->current;
#line 124 "src/gnome-ask-password-agent.vala"
	if (_tmp4_ == NULL) {
#line 630 "gnome-ask-password-agent.c"
		GFileEnumerator* enumerator = NULL;
		GFile* _tmp5_;
		GFileEnumerator* _tmp6_;
		GFileInfo* i = NULL;
#line 125 "src/gnome-ask-password-agent.vala"
		_tmp5_ = self->priv->directory;
#line 125 "src/gnome-ask-password-agent.vala"
		_tmp6_ = g_file_enumerate_children (_tmp5_, "standard::name", G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, NULL, &_inner_error0_);
#line 125 "src/gnome-ask-password-agent.vala"
		enumerator = _tmp6_;
#line 125 "src/gnome-ask-password-agent.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 125 "src/gnome-ask-password-agent.vala"
			g_propagate_error (error, _inner_error0_);
#line 125 "src/gnome-ask-password-agent.vala"
			return;
#line 647 "gnome-ask-password-agent.c"
		}
#line 128 "src/gnome-ask-password-agent.vala"
		while (TRUE) {
#line 651 "gnome-ask-password-agent.c"
			GFileInfo* _tmp7_ = NULL;
			GFileEnumerator* _tmp8_;
			GFileInfo* _tmp9_;
			GFileInfo* _tmp10_;
			GFileInfo* _tmp11_;
			GFileInfo* _tmp12_;
			const gchar* _tmp13_;
			GFile* _tmp14_;
			GFileInfo* _tmp15_;
			const gchar* _tmp16_;
			GFile* _tmp17_;
			gboolean _tmp18_ = FALSE;
#line 128 "src/gnome-ask-password-agent.vala"
			_tmp8_ = enumerator;
#line 128 "src/gnome-ask-password-agent.vala"
			_tmp9_ = g_file_enumerator_next_file (_tmp8_, NULL, &_inner_error0_);
#line 128 "src/gnome-ask-password-agent.vala"
			_tmp7_ = _tmp9_;
#line 128 "src/gnome-ask-password-agent.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 128 "src/gnome-ask-password-agent.vala"
				g_propagate_error (error, _inner_error0_);
#line 128 "src/gnome-ask-password-agent.vala"
				_g_object_unref0 (i);
#line 128 "src/gnome-ask-password-agent.vala"
				_g_object_unref0 (enumerator);
#line 128 "src/gnome-ask-password-agent.vala"
				return;
#line 680 "gnome-ask-password-agent.c"
			}
#line 128 "src/gnome-ask-password-agent.vala"
			_tmp10_ = _tmp7_;
#line 128 "src/gnome-ask-password-agent.vala"
			_tmp7_ = NULL;
#line 128 "src/gnome-ask-password-agent.vala"
			_g_object_unref0 (i);
#line 128 "src/gnome-ask-password-agent.vala"
			i = _tmp10_;
#line 128 "src/gnome-ask-password-agent.vala"
			_tmp11_ = i;
#line 128 "src/gnome-ask-password-agent.vala"
			if (!(_tmp11_ != NULL)) {
#line 128 "src/gnome-ask-password-agent.vala"
				_g_object_unref0 (_tmp7_);
#line 128 "src/gnome-ask-password-agent.vala"
				break;
#line 698 "gnome-ask-password-agent.c"
			}
#line 129 "src/gnome-ask-password-agent.vala"
			_tmp12_ = i;
#line 129 "src/gnome-ask-password-agent.vala"
			_tmp13_ = g_file_info_get_name (_tmp12_);
#line 129 "src/gnome-ask-password-agent.vala"
			if (!g_str_has_prefix (_tmp13_, "ask.")) {
#line 130 "src/gnome-ask-password-agent.vala"
				_g_object_unref0 (_tmp7_);
#line 130 "src/gnome-ask-password-agent.vala"
				continue;
#line 710 "gnome-ask-password-agent.c"
			}
#line 132 "src/gnome-ask-password-agent.vala"
			_tmp14_ = self->priv->directory;
#line 132 "src/gnome-ask-password-agent.vala"
			_tmp15_ = i;
#line 132 "src/gnome-ask-password-agent.vala"
			_tmp16_ = g_file_info_get_name (_tmp15_);
#line 132 "src/gnome-ask-password-agent.vala"
			_tmp17_ = g_file_get_child (_tmp14_, _tmp16_);
#line 132 "src/gnome-ask-password-agent.vala"
			_g_object_unref0 (self->priv->current);
#line 132 "src/gnome-ask-password-agent.vala"
			self->priv->current = _tmp17_;
#line 134 "src/gnome-ask-password-agent.vala"
			_tmp18_ = my_status_icon_load_password (self, &_inner_error0_);
#line 134 "src/gnome-ask-password-agent.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 134 "src/gnome-ask-password-agent.vala"
				g_propagate_error (error, _inner_error0_);
#line 134 "src/gnome-ask-password-agent.vala"
				_g_object_unref0 (_tmp7_);
#line 134 "src/gnome-ask-password-agent.vala"
				_g_object_unref0 (i);
#line 134 "src/gnome-ask-password-agent.vala"
				_g_object_unref0 (enumerator);
#line 134 "src/gnome-ask-password-agent.vala"
				return;
#line 738 "gnome-ask-password-agent.c"
			}
#line 134 "src/gnome-ask-password-agent.vala"
			if (_tmp18_) {
#line 135 "src/gnome-ask-password-agent.vala"
				_g_object_unref0 (_tmp7_);
#line 135 "src/gnome-ask-password-agent.vala"
				break;
#line 746 "gnome-ask-password-agent.c"
			}
#line 137 "src/gnome-ask-password-agent.vala"
			_g_object_unref0 (self->priv->current);
#line 137 "src/gnome-ask-password-agent.vala"
			self->priv->current = NULL;
#line 128 "src/gnome-ask-password-agent.vala"
			_g_object_unref0 (_tmp7_);
#line 754 "gnome-ask-password-agent.c"
		}
#line 124 "src/gnome-ask-password-agent.vala"
		_g_object_unref0 (i);
#line 124 "src/gnome-ask-password-agent.vala"
		_g_object_unref0 (enumerator);
#line 760 "gnome-ask-password-agent.c"
	}
#line 141 "src/gnome-ask-password-agent.vala"
	_tmp19_ = self->priv->current;
#line 141 "src/gnome-ask-password-agent.vala"
	if (_tmp19_ == NULL) {
#line 142 "src/gnome-ask-password-agent.vala"
		gtk_status_icon_set_visible ((GtkStatusIcon*) self, FALSE);
#line 768 "gnome-ask-password-agent.c"
	}
}

static void
__lambda4_ (MyStatusIcon* self)
{
#line 189 "src/gnome-ask-password-agent.vala"
	gtk_status_icon_set_visible ((GtkStatusIcon*) self, TRUE);
#line 777 "gnome-ask-password-agent.c"
}

static void
___lambda4__notify_notification_closed (NotifyNotification* _sender,
                                        gpointer self)
{
#line 188 "src/gnome-ask-password-agent.vala"
	__lambda4_ ((MyStatusIcon*) self);
#line 786 "gnome-ask-password-agent.c"
}

static void
_my_status_icon_status_icon_activate_notify_action_callback (NotifyNotification* notification,
                                                             const gchar* action,
                                                             gpointer self)
{
#line 191 "src/gnome-ask-password-agent.vala"
	my_status_icon_status_icon_activate ((MyStatusIcon*) self);
#line 796 "gnome-ask-password-agent.c"
}

static gboolean
my_status_icon_load_password (MyStatusIcon* self,
                              GError** error)
{
	GKeyFile* key_file = NULL;
	GKeyFile* _tmp0_;
	const gchar* _tmp25_;
	const gchar* _tmp32_;
	const gchar* _tmp33_;
	const gchar* _tmp34_;
	const gchar* _tmp35_;
	const gchar* _tmp36_;
	NotifyNotification* _tmp37_;
	NotifyNotification* _tmp38_;
	NotifyNotification* _tmp39_;
	NotifyNotification* _tmp40_;
	NotifyNotification* _tmp41_;
	GError* _inner_error0_ = NULL;
	gboolean result;
#line 145 "src/gnome-ask-password-agent.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 147 "src/gnome-ask-password-agent.vala"
	_tmp0_ = g_key_file_new ();
#line 147 "src/gnome-ask-password-agent.vala"
	key_file = _tmp0_;
#line 824 "gnome-ask-password-agent.c"
	{
		struct timespec ts = {0};
		GKeyFile* _tmp1_;
		GFile* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* not_after_as_string = NULL;
		GKeyFile* _tmp5_;
		gchar* _tmp6_;
		struct timespec _tmp7_ = {0};
		guint64 now = 0ULL;
		struct timespec _tmp8_;
		struct timespec _tmp9_;
		guint64 not_after = 0ULL;
		const gchar* _tmp10_;
		guint64 _tmp11_ = 0ULL;
		gint _tmp12_;
		gboolean _tmp13_ = FALSE;
		gchar* _tmp14_ = NULL;
		GKeyFile* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
#line 152 "src/gnome-ask-password-agent.vala"
		_tmp1_ = key_file;
#line 152 "src/gnome-ask-password-agent.vala"
		_tmp2_ = self->priv->current;
#line 152 "src/gnome-ask-password-agent.vala"
		_tmp3_ = g_file_get_path (_tmp2_);
#line 152 "src/gnome-ask-password-agent.vala"
		_tmp4_ = _tmp3_;
#line 152 "src/gnome-ask-password-agent.vala"
		g_key_file_load_from_file (_tmp1_, _tmp4_, G_KEY_FILE_NONE, &_inner_error0_);
#line 152 "src/gnome-ask-password-agent.vala"
		_g_free0 (_tmp4_);
#line 152 "src/gnome-ask-password-agent.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 861 "gnome-ask-password-agent.c"
			goto __catch0_g_error;
		}
#line 154 "src/gnome-ask-password-agent.vala"
		_tmp5_ = key_file;
#line 154 "src/gnome-ask-password-agent.vala"
		_tmp6_ = g_key_file_get_string (_tmp5_, "Ask", "NotAfter", &_inner_error0_);
#line 154 "src/gnome-ask-password-agent.vala"
		not_after_as_string = _tmp6_;
#line 154 "src/gnome-ask-password-agent.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 872 "gnome-ask-password-agent.c"
			goto __catch0_g_error;
		}
#line 156 "src/gnome-ask-password-agent.vala"
		clock_gettime (1, &_tmp7_);
#line 156 "src/gnome-ask-password-agent.vala"
		ts = _tmp7_;
#line 157 "src/gnome-ask-password-agent.vala"
		_tmp8_ = ts;
#line 157 "src/gnome-ask-password-agent.vala"
		_tmp9_ = ts;
#line 157 "src/gnome-ask-password-agent.vala"
		now = (guint64) ((_tmp8_.tv_sec * 1000000) + (_tmp9_.tv_nsec / 1000));
#line 160 "src/gnome-ask-password-agent.vala"
		_tmp10_ = not_after_as_string;
#line 160 "src/gnome-ask-password-agent.vala"
		_tmp12_ = sscanf (_tmp10_, "%llu", &_tmp11_);
#line 160 "src/gnome-ask-password-agent.vala"
		not_after = _tmp11_;
#line 160 "src/gnome-ask-password-agent.vala"
		if (_tmp12_ != 1) {
#line 161 "src/gnome-ask-password-agent.vala"
			result = FALSE;
#line 161 "src/gnome-ask-password-agent.vala"
			_g_free0 (not_after_as_string);
#line 161 "src/gnome-ask-password-agent.vala"
			_g_key_file_unref0 (key_file);
#line 161 "src/gnome-ask-password-agent.vala"
			return result;
#line 901 "gnome-ask-password-agent.c"
		}
#line 163 "src/gnome-ask-password-agent.vala"
		if (not_after > ((guint64) 0)) {
#line 163 "src/gnome-ask-password-agent.vala"
			_tmp13_ = not_after < now;
#line 907 "gnome-ask-password-agent.c"
		} else {
#line 163 "src/gnome-ask-password-agent.vala"
			_tmp13_ = FALSE;
#line 911 "gnome-ask-password-agent.c"
		}
#line 163 "src/gnome-ask-password-agent.vala"
		if (_tmp13_) {
#line 164 "src/gnome-ask-password-agent.vala"
			result = FALSE;
#line 164 "src/gnome-ask-password-agent.vala"
			_g_free0 (not_after_as_string);
#line 164 "src/gnome-ask-password-agent.vala"
			_g_key_file_unref0 (key_file);
#line 164 "src/gnome-ask-password-agent.vala"
			return result;
#line 923 "gnome-ask-password-agent.c"
		}
#line 166 "src/gnome-ask-password-agent.vala"
		_tmp15_ = key_file;
#line 166 "src/gnome-ask-password-agent.vala"
		_tmp16_ = g_key_file_get_string (_tmp15_, "Ask", "Socket", &_inner_error0_);
#line 166 "src/gnome-ask-password-agent.vala"
		_tmp14_ = _tmp16_;
#line 166 "src/gnome-ask-password-agent.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 166 "src/gnome-ask-password-agent.vala"
			_g_free0 (not_after_as_string);
#line 935 "gnome-ask-password-agent.c"
			goto __catch0_g_error;
		}
#line 166 "src/gnome-ask-password-agent.vala"
		_tmp17_ = _tmp14_;
#line 166 "src/gnome-ask-password-agent.vala"
		_tmp14_ = NULL;
#line 166 "src/gnome-ask-password-agent.vala"
		_g_free0 (self->priv->socket);
#line 166 "src/gnome-ask-password-agent.vala"
		self->priv->socket = _tmp17_;
#line 149 "src/gnome-ask-password-agent.vala"
		_g_free0 (_tmp14_);
#line 149 "src/gnome-ask-password-agent.vala"
		_g_free0 (not_after_as_string);
#line 950 "gnome-ask-password-agent.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 149 "src/gnome-ask-password-agent.vala"
		g_clear_error (&_inner_error0_);
#line 168 "src/gnome-ask-password-agent.vala"
		result = FALSE;
#line 168 "src/gnome-ask-password-agent.vala"
		_g_key_file_unref0 (key_file);
#line 168 "src/gnome-ask-password-agent.vala"
		return result;
#line 963 "gnome-ask-password-agent.c"
	}
	__finally0:
#line 149 "src/gnome-ask-password-agent.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 968 "gnome-ask-password-agent.c"
		gboolean _tmp18_ = FALSE;
#line 149 "src/gnome-ask-password-agent.vala"
		g_propagate_error (error, _inner_error0_);
#line 149 "src/gnome-ask-password-agent.vala"
		_g_key_file_unref0 (key_file);
#line 149 "src/gnome-ask-password-agent.vala"
		return _tmp18_;
#line 976 "gnome-ask-password-agent.c"
	}
	{
		gchar* _tmp19_ = NULL;
		GKeyFile* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
#line 172 "src/gnome-ask-password-agent.vala"
		_tmp20_ = key_file;
#line 172 "src/gnome-ask-password-agent.vala"
		_tmp21_ = g_key_file_get_string (_tmp20_, "Ask", "Message", &_inner_error0_);
#line 172 "src/gnome-ask-password-agent.vala"
		_tmp19_ = _tmp21_;
#line 172 "src/gnome-ask-password-agent.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 991 "gnome-ask-password-agent.c"
			goto __catch1_g_error;
		}
#line 172 "src/gnome-ask-password-agent.vala"
		_tmp22_ = g_strcompress (_tmp19_);
#line 172 "src/gnome-ask-password-agent.vala"
		_g_free0 (self->priv->message);
#line 172 "src/gnome-ask-password-agent.vala"
		self->priv->message = _tmp22_;
#line 171 "src/gnome-ask-password-agent.vala"
		_g_free0 (_tmp19_);
#line 1002 "gnome-ask-password-agent.c"
	}
	goto __finally1;
	__catch1_g_error:
	{
		gchar* _tmp23_;
#line 171 "src/gnome-ask-password-agent.vala"
		g_clear_error (&_inner_error0_);
#line 174 "src/gnome-ask-password-agent.vala"
		_tmp23_ = g_strdup ("Please Enter System Password!");
#line 174 "src/gnome-ask-password-agent.vala"
		_g_free0 (self->priv->message);
#line 174 "src/gnome-ask-password-agent.vala"
		self->priv->message = _tmp23_;
#line 1016 "gnome-ask-password-agent.c"
	}
	__finally1:
#line 171 "src/gnome-ask-password-agent.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1021 "gnome-ask-password-agent.c"
		gboolean _tmp24_ = FALSE;
#line 171 "src/gnome-ask-password-agent.vala"
		g_propagate_error (error, _inner_error0_);
#line 171 "src/gnome-ask-password-agent.vala"
		_g_key_file_unref0 (key_file);
#line 171 "src/gnome-ask-password-agent.vala"
		return _tmp24_;
#line 1029 "gnome-ask-password-agent.c"
	}
#line 177 "src/gnome-ask-password-agent.vala"
	_tmp25_ = self->priv->message;
#line 177 "src/gnome-ask-password-agent.vala"
	gtk_status_icon_set_tooltip_text ((GtkStatusIcon*) self, _tmp25_);
#line 1035 "gnome-ask-password-agent.c"
	{
		gchar* _tmp26_ = NULL;
		GKeyFile* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
#line 180 "src/gnome-ask-password-agent.vala"
		_tmp27_ = key_file;
#line 180 "src/gnome-ask-password-agent.vala"
		_tmp28_ = g_key_file_get_string (_tmp27_, "Ask", "Icon", &_inner_error0_);
#line 180 "src/gnome-ask-password-agent.vala"
		_tmp26_ = _tmp28_;
#line 180 "src/gnome-ask-password-agent.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1049 "gnome-ask-password-agent.c"
			goto __catch2_g_error;
		}
#line 180 "src/gnome-ask-password-agent.vala"
		_tmp29_ = _tmp26_;
#line 180 "src/gnome-ask-password-agent.vala"
		_tmp26_ = NULL;
#line 180 "src/gnome-ask-password-agent.vala"
		_g_free0 (self->priv->icon);
#line 180 "src/gnome-ask-password-agent.vala"
		self->priv->icon = _tmp29_;
#line 179 "src/gnome-ask-password-agent.vala"
		_g_free0 (_tmp26_);
#line 1062 "gnome-ask-password-agent.c"
	}
	goto __finally2;
	__catch2_g_error:
	{
		gchar* _tmp30_;
#line 179 "src/gnome-ask-password-agent.vala"
		g_clear_error (&_inner_error0_);
#line 182 "src/gnome-ask-password-agent.vala"
		_tmp30_ = g_strdup ("dialog-password");
#line 182 "src/gnome-ask-password-agent.vala"
		_g_free0 (self->priv->icon);
#line 182 "src/gnome-ask-password-agent.vala"
		self->priv->icon = _tmp30_;
#line 1076 "gnome-ask-password-agent.c"
	}
	__finally2:
#line 179 "src/gnome-ask-password-agent.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1081 "gnome-ask-password-agent.c"
		gboolean _tmp31_ = FALSE;
#line 179 "src/gnome-ask-password-agent.vala"
		g_propagate_error (error, _inner_error0_);
#line 179 "src/gnome-ask-password-agent.vala"
		_g_key_file_unref0 (key_file);
#line 179 "src/gnome-ask-password-agent.vala"
		return _tmp31_;
#line 1089 "gnome-ask-password-agent.c"
	}
#line 184 "src/gnome-ask-password-agent.vala"
	_tmp32_ = self->priv->icon;
#line 184 "src/gnome-ask-password-agent.vala"
	gtk_status_icon_set_from_icon_name ((GtkStatusIcon*) self, _tmp32_);
#line 186 "src/gnome-ask-password-agent.vala"
	_tmp33_ = gtk_status_icon_get_title ((GtkStatusIcon*) self);
#line 186 "src/gnome-ask-password-agent.vala"
	_tmp34_ = _tmp33_;
#line 186 "src/gnome-ask-password-agent.vala"
	_tmp35_ = self->priv->message;
#line 186 "src/gnome-ask-password-agent.vala"
	_tmp36_ = self->priv->icon;
#line 186 "src/gnome-ask-password-agent.vala"
	_tmp37_ = notify_notification_new (_tmp34_, _tmp35_, _tmp36_);
#line 186 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (self->priv->n);
#line 186 "src/gnome-ask-password-agent.vala"
	self->priv->n = _tmp37_;
#line 187 "src/gnome-ask-password-agent.vala"
	_tmp38_ = self->priv->n;
#line 187 "src/gnome-ask-password-agent.vala"
	notify_notification_set_timeout (_tmp38_, 5000);
#line 188 "src/gnome-ask-password-agent.vala"
	_tmp39_ = self->priv->n;
#line 188 "src/gnome-ask-password-agent.vala"
	g_signal_connect_object (_tmp39_, "closed", (GCallback) ___lambda4__notify_notification_closed, self, 0);
#line 191 "src/gnome-ask-password-agent.vala"
	_tmp40_ = self->priv->n;
#line 191 "src/gnome-ask-password-agent.vala"
	notify_notification_add_action (_tmp40_, "enter_pw", "Enter password", _my_status_icon_status_icon_activate_notify_action_callback, g_object_ref (self), g_object_unref);
#line 192 "src/gnome-ask-password-agent.vala"
	_tmp41_ = self->priv->n;
#line 192 "src/gnome-ask-password-agent.vala"
	notify_notification_show (_tmp41_, &_inner_error0_);
#line 192 "src/gnome-ask-password-agent.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1127 "gnome-ask-password-agent.c"
		gboolean _tmp42_ = FALSE;
#line 192 "src/gnome-ask-password-agent.vala"
		g_propagate_error (error, _inner_error0_);
#line 192 "src/gnome-ask-password-agent.vala"
		_g_key_file_unref0 (key_file);
#line 192 "src/gnome-ask-password-agent.vala"
		return _tmp42_;
#line 1135 "gnome-ask-password-agent.c"
	}
#line 194 "src/gnome-ask-password-agent.vala"
	result = TRUE;
#line 194 "src/gnome-ask-password-agent.vala"
	_g_key_file_unref0 (key_file);
#line 194 "src/gnome-ask-password-agent.vala"
	return result;
#line 1143 "gnome-ask-password-agent.c"
}

static void
___lambda5_ (MyStatusIcon* self,
             GPid pid,
             gint status)
{
#line 235 "src/gnome-ask-password-agent.vala"
	g_spawn_close_pid (pid);
#line 1153 "gnome-ask-password-agent.c"
}

static void
____lambda5__gchild_watch_func (GPid pid,
                                gint wait_status,
                                gpointer self)
{
#line 234 "src/gnome-ask-password-agent.vala"
	___lambda5_ ((MyStatusIcon*) self, pid, wait_status);
#line 1163 "gnome-ask-password-agent.c"
}

static guint8*
string_get_data (const gchar* self,
                 gint* result_length1)
{
	guint8* result;
	guint8* res = NULL;
	gint res_length1;
	gint _res_size_;
	gint _tmp0_;
	gint _tmp1_;
	guint8* _tmp2_;
	gint _tmp2__length1;
#line 1609 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1610 "glib-2.0.vapi"
	res = (guint8*) self;
#line 1610 "glib-2.0.vapi"
	res_length1 = -1;
#line 1610 "glib-2.0.vapi"
	_res_size_ = res_length1;
#line 1611 "glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1611 "glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1611 "glib-2.0.vapi"
	res_length1 = (gint) _tmp1_;
#line 1612 "glib-2.0.vapi"
	_tmp2_ = res;
#line 1612 "glib-2.0.vapi"
	_tmp2__length1 = res_length1;
#line 1612 "glib-2.0.vapi"
	if (result_length1) {
#line 1612 "glib-2.0.vapi"
		*result_length1 = _tmp2__length1;
#line 1200 "gnome-ask-password-agent.c"
	}
#line 1612 "glib-2.0.vapi"
	result = _tmp2_;
#line 1612 "glib-2.0.vapi"
	return result;
#line 1206 "gnome-ask-password-agent.c"
}

static void
my_status_icon_status_icon_activate (MyStatusIcon* self)
{
	GFile* _tmp0_;
	PasswordDialog* _tmp1_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	PasswordDialog* _tmp5_;
	gint _result_ = 0;
	PasswordDialog* _tmp6_;
	gchar* password = NULL;
	PasswordDialog* _tmp7_;
	GtkEntry* _tmp8_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	PasswordDialog* _tmp11_;
	gboolean _tmp12_ = FALSE;
	gboolean _tmp13_ = FALSE;
	GPid child_pid = 0;
	gint to_process = 0;
	GError* _inner_error0_ = NULL;
#line 197 "src/gnome-ask-password-agent.vala"
	g_return_if_fail (self != NULL);
#line 199 "src/gnome-ask-password-agent.vala"
	_tmp0_ = self->priv->current;
#line 199 "src/gnome-ask-password-agent.vala"
	if (_tmp0_ == NULL) {
#line 200 "src/gnome-ask-password-agent.vala"
		return;
#line 1238 "gnome-ask-password-agent.c"
	}
#line 202 "src/gnome-ask-password-agent.vala"
	_tmp1_ = self->priv->password_dialog;
#line 202 "src/gnome-ask-password-agent.vala"
	if (_tmp1_ != NULL) {
#line 1244 "gnome-ask-password-agent.c"
		PasswordDialog* _tmp2_;
#line 203 "src/gnome-ask-password-agent.vala"
		_tmp2_ = self->priv->password_dialog;
#line 203 "src/gnome-ask-password-agent.vala"
		gtk_window_present ((GtkWindow*) _tmp2_);
#line 204 "src/gnome-ask-password-agent.vala"
		return;
#line 1252 "gnome-ask-password-agent.c"
	}
#line 207 "src/gnome-ask-password-agent.vala"
	_tmp3_ = self->priv->message;
#line 207 "src/gnome-ask-password-agent.vala"
	_tmp4_ = self->priv->icon;
#line 207 "src/gnome-ask-password-agent.vala"
	_tmp5_ = password_dialog_new (_tmp3_, _tmp4_);
#line 207 "src/gnome-ask-password-agent.vala"
	g_object_ref_sink (_tmp5_);
#line 207 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (self->priv->password_dialog);
#line 207 "src/gnome-ask-password-agent.vala"
	self->priv->password_dialog = _tmp5_;
#line 209 "src/gnome-ask-password-agent.vala"
	_tmp6_ = self->priv->password_dialog;
#line 209 "src/gnome-ask-password-agent.vala"
	_result_ = gtk_dialog_run ((GtkDialog*) _tmp6_);
#line 210 "src/gnome-ask-password-agent.vala"
	_tmp7_ = self->priv->password_dialog;
#line 210 "src/gnome-ask-password-agent.vala"
	_tmp8_ = _tmp7_->entry;
#line 210 "src/gnome-ask-password-agent.vala"
	_tmp9_ = gtk_entry_get_text (_tmp8_);
#line 210 "src/gnome-ask-password-agent.vala"
	_tmp10_ = g_strdup (_tmp9_);
#line 210 "src/gnome-ask-password-agent.vala"
	password = _tmp10_;
#line 212 "src/gnome-ask-password-agent.vala"
	_tmp11_ = self->priv->password_dialog;
#line 212 "src/gnome-ask-password-agent.vala"
	gtk_widget_destroy ((GtkWidget*) _tmp11_);
#line 213 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (self->priv->password_dialog);
#line 213 "src/gnome-ask-password-agent.vala"
	self->priv->password_dialog = NULL;
#line 215 "src/gnome-ask-password-agent.vala"
	if (_result_ == ((gint) GTK_RESPONSE_REJECT)) {
#line 215 "src/gnome-ask-password-agent.vala"
		_tmp13_ = TRUE;
#line 1292 "gnome-ask-password-agent.c"
	} else {
#line 216 "src/gnome-ask-password-agent.vala"
		_tmp13_ = _result_ == ((gint) GTK_RESPONSE_DELETE_EVENT);
#line 1296 "gnome-ask-password-agent.c"
	}
#line 215 "src/gnome-ask-password-agent.vala"
	if (_tmp13_) {
#line 215 "src/gnome-ask-password-agent.vala"
		_tmp12_ = TRUE;
#line 1302 "gnome-ask-password-agent.c"
	} else {
#line 217 "src/gnome-ask-password-agent.vala"
		_tmp12_ = _result_ == ((gint) GTK_RESPONSE_CANCEL);
#line 1306 "gnome-ask-password-agent.c"
	}
#line 215 "src/gnome-ask-password-agent.vala"
	if (_tmp12_) {
#line 218 "src/gnome-ask-password-agent.vala"
		_g_free0 (password);
#line 218 "src/gnome-ask-password-agent.vala"
		return;
#line 1314 "gnome-ask-password-agent.c"
	}
	{
		const gchar* _tmp14_ = NULL;
		gchar* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
		const gchar* _tmp18_;
		gchar* _tmp19_;
		gchar** _tmp20_;
		gchar** _tmp21_;
		gint _tmp21__length1;
		GPid _tmp22_ = 0;
		gint _tmp23_ = 0;
		GOutputStream* stream = NULL;
		GUnixOutputStream* _tmp24_;
		GOutputStream* _tmp25_;
		const gchar* _tmp26_;
		guint8* _tmp27_;
		gint _tmp27__length1;
		gint _tmp28_ = 0;
		guint8* _tmp29_;
		gint _tmp29__length1;
#line 226 "src/gnome-ask-password-agent.vala"
		if (_result_ == ((gint) GTK_RESPONSE_OK)) {
#line 226 "src/gnome-ask-password-agent.vala"
			_tmp14_ = "1";
#line 1341 "gnome-ask-password-agent.c"
		} else {
#line 226 "src/gnome-ask-password-agent.vala"
			_tmp14_ = "0";
#line 1345 "gnome-ask-password-agent.c"
		}
#line 224 "src/gnome-ask-password-agent.vala"
		_tmp15_ = g_strdup ("/usr/bin/pkexec");
#line 224 "src/gnome-ask-password-agent.vala"
		_tmp16_ = g_strdup ("/lib/systemd/systemd-reply-password");
#line 224 "src/gnome-ask-password-agent.vala"
		_tmp17_ = g_strdup (_tmp14_);
#line 224 "src/gnome-ask-password-agent.vala"
		_tmp18_ = self->priv->socket;
#line 224 "src/gnome-ask-password-agent.vala"
		_tmp19_ = g_strdup (_tmp18_);
#line 224 "src/gnome-ask-password-agent.vala"
		_tmp20_ = g_new0 (gchar*, 4 + 1);
#line 224 "src/gnome-ask-password-agent.vala"
		_tmp20_[0] = _tmp15_;
#line 224 "src/gnome-ask-password-agent.vala"
		_tmp20_[1] = _tmp16_;
#line 224 "src/gnome-ask-password-agent.vala"
		_tmp20_[2] = _tmp17_;
#line 224 "src/gnome-ask-password-agent.vala"
		_tmp20_[3] = _tmp19_;
#line 224 "src/gnome-ask-password-agent.vala"
		_tmp21_ = _tmp20_;
#line 224 "src/gnome-ask-password-agent.vala"
		_tmp21__length1 = 4;
#line 224 "src/gnome-ask-password-agent.vala"
		g_spawn_async_with_pipes (NULL, _tmp21_, NULL, G_SPAWN_DO_NOT_REAP_CHILD, NULL, NULL, &_tmp22_, &_tmp23_, NULL, NULL, &_inner_error0_);
#line 224 "src/gnome-ask-password-agent.vala"
		child_pid = _tmp22_;
#line 224 "src/gnome-ask-password-agent.vala"
		to_process = _tmp23_;
#line 224 "src/gnome-ask-password-agent.vala"
		_tmp21_ = (_vala_array_free (_tmp21_, _tmp21__length1, (GDestroyNotify) g_free), NULL);
#line 224 "src/gnome-ask-password-agent.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1381 "gnome-ask-password-agent.c"
			goto __catch0_g_error;
		}
#line 234 "src/gnome-ask-password-agent.vala"
		g_child_watch_add_full (G_PRIORITY_DEFAULT_IDLE, child_pid, ____lambda5__gchild_watch_func, g_object_ref (self), g_object_unref);
#line 238 "src/gnome-ask-password-agent.vala"
		_tmp24_ = (GUnixOutputStream*) g_unix_output_stream_new (to_process, TRUE);
#line 238 "src/gnome-ask-password-agent.vala"
		stream = (GOutputStream*) _tmp24_;
#line 240 "src/gnome-ask-password-agent.vala"
		_tmp25_ = stream;
#line 240 "src/gnome-ask-password-agent.vala"
		_tmp26_ = password;
#line 240 "src/gnome-ask-password-agent.vala"
		_tmp27_ = string_get_data (_tmp26_, &_tmp28_);
#line 240 "src/gnome-ask-password-agent.vala"
		_tmp27__length1 = _tmp28_;
#line 240 "src/gnome-ask-password-agent.vala"
		_tmp29_ = _tmp27_;
#line 240 "src/gnome-ask-password-agent.vala"
		_tmp29__length1 = _tmp27__length1;
#line 240 "src/gnome-ask-password-agent.vala"
		g_output_stream_write (_tmp25_, _tmp29_, (gsize) _tmp29__length1, NULL, &_inner_error0_);
#line 240 "src/gnome-ask-password-agent.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 240 "src/gnome-ask-password-agent.vala"
			_g_object_unref0 (stream);
#line 1408 "gnome-ask-password-agent.c"
			goto __catch0_g_error;
		}
#line 223 "src/gnome-ask-password-agent.vala"
		_g_object_unref0 (stream);
#line 1413 "gnome-ask-password-agent.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp30_;
		const gchar* _tmp31_;
#line 223 "src/gnome-ask-password-agent.vala"
		e = _inner_error0_;
#line 223 "src/gnome-ask-password-agent.vala"
		_inner_error0_ = NULL;
#line 245 "src/gnome-ask-password-agent.vala"
		_tmp30_ = e;
#line 245 "src/gnome-ask-password-agent.vala"
		_tmp31_ = _tmp30_->message;
#line 245 "src/gnome-ask-password-agent.vala"
		show_error (_tmp31_);
#line 223 "src/gnome-ask-password-agent.vala"
		_g_error_free0 (e);
#line 1433 "gnome-ask-password-agent.c"
	}
	__finally0:
#line 223 "src/gnome-ask-password-agent.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 223 "src/gnome-ask-password-agent.vala"
		_g_free0 (password);
#line 223 "src/gnome-ask-password-agent.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 223 "src/gnome-ask-password-agent.vala"
		g_clear_error (&_inner_error0_);
#line 223 "src/gnome-ask-password-agent.vala"
		return;
#line 1446 "gnome-ask-password-agent.c"
	}
#line 197 "src/gnome-ask-password-agent.vala"
	_g_free0 (password);
#line 1450 "gnome-ask-password-agent.c"
}

static void
my_status_icon_class_init (MyStatusIconClass * klass,
                           gpointer klass_data)
{
#line 72 "src/gnome-ask-password-agent.vala"
	my_status_icon_parent_class = g_type_class_peek_parent (klass);
#line 72 "src/gnome-ask-password-agent.vala"
	g_type_class_adjust_private_offset (klass, &MyStatusIcon_private_offset);
#line 72 "src/gnome-ask-password-agent.vala"
	G_OBJECT_CLASS (klass)->finalize = my_status_icon_finalize;
#line 1463 "gnome-ask-password-agent.c"
}

static void
my_status_icon_instance_init (MyStatusIcon * self,
                              gpointer klass)
{
#line 72 "src/gnome-ask-password-agent.vala"
	self->priv = my_status_icon_get_instance_private (self);
#line 1472 "gnome-ask-password-agent.c"
}

static void
my_status_icon_finalize (GObject * obj)
{
	MyStatusIcon * self;
#line 72 "src/gnome-ask-password-agent.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_MY_STATUS_ICON, MyStatusIcon);
#line 74 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (self->priv->directory);
#line 75 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (self->priv->current);
#line 76 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (self->priv->file_monitor);
#line 78 "src/gnome-ask-password-agent.vala"
	_g_free0 (self->priv->message);
#line 79 "src/gnome-ask-password-agent.vala"
	_g_free0 (self->priv->icon);
#line 80 "src/gnome-ask-password-agent.vala"
	_g_free0 (self->priv->socket);
#line 82 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (self->priv->password_dialog);
#line 83 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (self->priv->n);
#line 72 "src/gnome-ask-password-agent.vala"
	G_OBJECT_CLASS (my_status_icon_parent_class)->finalize (obj);
#line 1499 "gnome-ask-password-agent.c"
}

static GType
my_status_icon_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (MyStatusIconClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) my_status_icon_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (MyStatusIcon), 0, (GInstanceInitFunc) my_status_icon_instance_init, NULL };
	GType my_status_icon_type_id;
	my_status_icon_type_id = g_type_register_static (gtk_status_icon_get_type (), "MyStatusIcon", &g_define_type_info, 0);
	MyStatusIcon_private_offset = g_type_add_instance_private (my_status_icon_type_id, sizeof (MyStatusIconPrivate));
	return my_status_icon_type_id;
}

GType
my_status_icon_get_type (void)
{
	static volatile gsize my_status_icon_type_id__once = 0;
	if (g_once_init_enter (&my_status_icon_type_id__once)) {
		GType my_status_icon_type_id;
		my_status_icon_type_id = my_status_icon_get_type_once ();
		g_once_init_leave (&my_status_icon_type_id__once, my_status_icon_type_id);
	}
	return my_status_icon_type_id__once;
}

void
show_error (const gchar* e)
{
	GtkMessageDialog* m = NULL;
	GtkMessageDialog* _tmp0_;
#line 254 "src/gnome-ask-password-agent.vala"
	g_return_if_fail (e != NULL);
#line 255 "src/gnome-ask-password-agent.vala"
	_tmp0_ = (GtkMessageDialog*) gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, "%s", e);
#line 255 "src/gnome-ask-password-agent.vala"
	g_object_ref_sink (_tmp0_);
#line 255 "src/gnome-ask-password-agent.vala"
	m = _tmp0_;
#line 256 "src/gnome-ask-password-agent.vala"
	gtk_dialog_run ((GtkDialog*) m);
#line 257 "src/gnome-ask-password-agent.vala"
	gtk_widget_destroy ((GtkWidget*) m);
#line 254 "src/gnome-ask-password-agent.vala"
	_g_object_unref0 (m);
#line 1543 "gnome-ask-password-agent.c"
}

static gint
_vala_main (gchar** args,
            gint args_length1)
{
	GError* _inner_error0_ = NULL;
	gint result;
	{
		MyStatusIcon* i = NULL;
		MyStatusIcon* _tmp0_;
#line 262 "src/gnome-ask-password-agent.vala"
		gtk_init_with_args ((gint*) (&args_length1), &args, "[OPTION...]", entries, "systemd-ask-password-agent", &_inner_error0_);
#line 262 "src/gnome-ask-password-agent.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 262 "src/gnome-ask-password-agent.vala"
			if (_inner_error0_->domain == G_IO_ERROR) {
#line 1561 "gnome-ask-password-agent.c"
				goto __catch0_g_io_error;
			}
			goto __catch0_g_error;
		}
#line 263 "src/gnome-ask-password-agent.vala"
		notify_init ("Password Agent");
#line 265 "src/gnome-ask-password-agent.vala"
		_tmp0_ = my_status_icon_new (&_inner_error0_);
#line 265 "src/gnome-ask-password-agent.vala"
		i = _tmp0_;
#line 265 "src/gnome-ask-password-agent.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 265 "src/gnome-ask-password-agent.vala"
			if (_inner_error0_->domain == G_IO_ERROR) {
#line 1576 "gnome-ask-password-agent.c"
				goto __catch0_g_io_error;
			}
			goto __catch0_g_error;
		}
#line 266 "src/gnome-ask-password-agent.vala"
		gtk_main ();
#line 261 "src/gnome-ask-password-agent.vala"
		_g_object_unref0 (i);
#line 1585 "gnome-ask-password-agent.c"
	}
	goto __finally0;
	__catch0_g_io_error:
	{
		GError* e = NULL;
		GError* _tmp1_;
		const gchar* _tmp2_;
#line 261 "src/gnome-ask-password-agent.vala"
		e = _inner_error0_;
#line 261 "src/gnome-ask-password-agent.vala"
		_inner_error0_ = NULL;
#line 268 "src/gnome-ask-password-agent.vala"
		_tmp1_ = e;
#line 268 "src/gnome-ask-password-agent.vala"
		_tmp2_ = _tmp1_->message;
#line 268 "src/gnome-ask-password-agent.vala"
		show_error (_tmp2_);
#line 261 "src/gnome-ask-password-agent.vala"
		_g_error_free0 (e);
#line 1605 "gnome-ask-password-agent.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		FILE* _tmp3_;
		GError* _tmp4_;
		const gchar* _tmp5_;
#line 261 "src/gnome-ask-password-agent.vala"
		e = _inner_error0_;
#line 261 "src/gnome-ask-password-agent.vala"
		_inner_error0_ = NULL;
#line 270 "src/gnome-ask-password-agent.vala"
		_tmp3_ = stderr;
#line 270 "src/gnome-ask-password-agent.vala"
		_tmp4_ = e;
#line 270 "src/gnome-ask-password-agent.vala"
		_tmp5_ = _tmp4_->message;
#line 270 "src/gnome-ask-password-agent.vala"
		fprintf (_tmp3_, "%s\n", _tmp5_);
#line 261 "src/gnome-ask-password-agent.vala"
		_g_error_free0 (e);
#line 1628 "gnome-ask-password-agent.c"
	}
	__finally0:
#line 261 "src/gnome-ask-password-agent.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1633 "gnome-ask-password-agent.c"
		gint _tmp6_ = -1;
#line 261 "src/gnome-ask-password-agent.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 261 "src/gnome-ask-password-agent.vala"
		g_clear_error (&_inner_error0_);
#line 261 "src/gnome-ask-password-agent.vala"
		return _tmp6_;
#line 1641 "gnome-ask-password-agent.c"
	}
#line 273 "src/gnome-ask-password-agent.vala"
	result = 0;
#line 273 "src/gnome-ask-password-agent.vala"
	return result;
#line 1647 "gnome-ask-password-agent.c"
}

int
main (int argc,
      char ** argv)
{
#line 260 "src/gnome-ask-password-agent.vala"
	return _vala_main (argv, argc);
#line 1656 "gnome-ask-password-agent.c"
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

