/* systemadm.c generated by valac 0.56.19, the Vala compiler
 * generated from systemadm.vala, do not modify */

#define _XOPEN_SOURCE

#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <gtk/gtk.h>
#include <glib-object.h>
#include <pango/pango.h>
#include <gee.h>
#include <gio/gio.h>
#include <errno.h>
#include <stdio.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TYPE_LEFT_LABEL (left_label_get_type ())
#define LEFT_LABEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LEFT_LABEL, LeftLabel))
#define LEFT_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LEFT_LABEL, LeftLabelClass))
#define IS_LEFT_LABEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LEFT_LABEL))
#define IS_LEFT_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LEFT_LABEL))
#define LEFT_LABEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LEFT_LABEL, LeftLabelClass))

typedef struct _LeftLabel LeftLabel;
typedef struct _LeftLabelClass LeftLabelClass;
typedef struct _LeftLabelPrivate LeftLabelPrivate;
enum  {
	LEFT_LABEL_0_PROPERTY,
	LEFT_LABEL_NUM_PROPERTIES
};
static GParamSpec* left_label_properties[LEFT_LABEL_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_RIGHT_LABEL (right_label_get_type ())
#define RIGHT_LABEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_RIGHT_LABEL, RightLabel))
#define RIGHT_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_RIGHT_LABEL, RightLabelClass))
#define IS_RIGHT_LABEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_RIGHT_LABEL))
#define IS_RIGHT_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_RIGHT_LABEL))
#define RIGHT_LABEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_RIGHT_LABEL, RightLabelClass))

typedef struct _RightLabel RightLabel;
typedef struct _RightLabelClass RightLabelClass;
typedef struct _RightLabelPrivate RightLabelPrivate;
enum  {
	RIGHT_LABEL_0_PROPERTY,
	RIGHT_LABEL_NUM_PROPERTIES
};
static GParamSpec* right_label_properties[RIGHT_LABEL_NUM_PROPERTIES];

#define TYPE_MAIN_WINDOW (main_window_get_type ())
#define MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MAIN_WINDOW, MainWindow))
#define MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MAIN_WINDOW, MainWindowClass))
#define IS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MAIN_WINDOW))
#define IS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MAIN_WINDOW))
#define MAIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MAIN_WINDOW, MainWindowClass))

typedef struct _MainWindow MainWindow;
typedef struct _MainWindowClass MainWindowClass;
typedef struct _MainWindowPrivate MainWindowPrivate;

#define TYPE_UNIT (unit_get_type ())
#define UNIT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_UNIT, Unit))
#define IS_UNIT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_UNIT))
#define UNIT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_UNIT, UnitIface))

typedef struct _Unit Unit;
typedef struct _UnitIface UnitIface;

#define TYPE_UNIT_PROXY (unit_proxy_get_type ())

#define UNIT_TYPE_JOB_LINK (unit_job_link_get_type ())
typedef struct _UnitJobLink UnitJobLink;

#define TYPE_MANAGER (manager_get_type ())
#define MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MANAGER, Manager))
#define IS_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MANAGER))
#define MANAGER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_MANAGER, ManagerIface))

typedef struct _Manager Manager;
typedef struct _ManagerIface ManagerIface;

#define TYPE_MANAGER_PROXY (manager_proxy_get_type ())

#define MANAGER_TYPE_UNIT_INFO (manager_unit_info_get_type ())
typedef struct _ManagerUnitInfo ManagerUnitInfo;

#define MANAGER_TYPE_JOB_INFO (manager_job_info_get_type ())
typedef struct _ManagerJobInfo ManagerJobInfo;
enum  {
	MAIN_WINDOW_0_PROPERTY,
	MAIN_WINDOW_NUM_PROPERTIES
};
static GParamSpec* main_window_properties[MAIN_WINDOW_NUM_PROPERTIES];

#define TYPE_JOB (job_get_type ())
#define JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_JOB, Job))
#define IS_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_JOB))
#define JOB_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_JOB, JobIface))

typedef struct _Job Job;
typedef struct _JobIface JobIface;

#define TYPE_JOB_PROXY (job_proxy_get_type ())

#define JOB_TYPE_UNIT_LINK (job_unit_link_get_type ())
typedef struct _JobUnitLink JobUnitLink;

#define TYPE_PROPERTIES (properties_get_type ())
#define PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PROPERTIES, Properties))
#define IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PROPERTIES))
#define PROPERTIES_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_PROPERTIES, PropertiesIface))

typedef struct _Properties Properties;
typedef struct _PropertiesIface PropertiesIface;

#define TYPE_PROPERTIES_PROXY (properties_proxy_get_type ())
#define __vala_GtkTreePath_free0(var) ((var == NULL) ? NULL : (var = (_vala_GtkTreePath_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _LeftLabel {
	GtkLabel parent_instance;
	LeftLabelPrivate * priv;
};

struct _LeftLabelClass {
	GtkLabelClass parent_class;
};

struct _RightLabel {
	GtkLabel parent_instance;
	RightLabelPrivate * priv;
};

struct _RightLabelClass {
	GtkLabelClass parent_class;
};

struct _MainWindow {
	GtkWindow parent_instance;
	MainWindowPrivate * priv;
};

struct _MainWindowClass {
	GtkWindowClass parent_class;
};

struct _UnitJobLink {
	guint32 id;
	char* path;
};

struct _UnitIface {
	GTypeInterface parent_iface;
	char* (*start) (Unit* self, const gchar* mode, GError** error);
	char* (*stop) (Unit* self, const gchar* mode, GError** error);
	char* (*reload) (Unit* self, const gchar* mode, GError** error);
	char* (*restart) (Unit* self, const gchar* mode, GError** error);
	char* (*try_restart) (Unit* self, const gchar* mode, GError** error);
	char* (*reload_or_restart) (Unit* self, const gchar* mode, GError** error);
	char* (*reload_or_try_restart) (Unit* self, const gchar* mode, GError** error);
	void (*reset_failed) (Unit* self, GError** error);
	gchar* (*get_id) (Unit* self);
	gchar** (*get_names) (Unit* self, gint* result_length1);
	gchar* (*get_following) (Unit* self);
	gchar** (*get_requires) (Unit* self, gint* result_length1);
	gchar** (*get_requires_overridable) (Unit* self, gint* result_length1);
	gchar** (*get_requisite) (Unit* self, gint* result_length1);
	gchar** (*get_requisite_overridable) (Unit* self, gint* result_length1);
	gchar** (*get_wants) (Unit* self, gint* result_length1);
	gchar** (*get_required_by) (Unit* self, gint* result_length1);
	gchar** (*get_required_by_overridable) (Unit* self, gint* result_length1);
	gchar** (*get_wanted_by) (Unit* self, gint* result_length1);
	gchar** (*get_conflicts) (Unit* self, gint* result_length1);
	gchar** (*get_conflicted_by) (Unit* self, gint* result_length1);
	gchar** (*get_before) (Unit* self, gint* result_length1);
	gchar** (*get_after) (Unit* self, gint* result_length1);
	gchar** (*get_on_failure) (Unit* self, gint* result_length1);
	gchar* (*get_description) (Unit* self);
	gchar* (*get_load_state) (Unit* self);
	gchar* (*get_active_state) (Unit* self);
	gchar* (*get_sub_state) (Unit* self);
	gchar* (*get_fragment_path) (Unit* self);
	guint64 (*get_inactive_exit_timestamp) (Unit* self);
	guint64 (*get_active_enter_timestamp) (Unit* self);
	guint64 (*get_active_exit_timestamp) (Unit* self);
	guint64 (*get_inactive_enter_timestamp) (Unit* self);
	gboolean (*get_can_start) (Unit* self);
	gboolean (*get_can_stop) (Unit* self);
	gboolean (*get_can_reload) (Unit* self);
	void (*get_job) (Unit* self, UnitJobLink * result);
	gboolean (*get_recursive_stop) (Unit* self);
	gboolean (*get_stop_when_unneeded) (Unit* self);
	gboolean (*get_refuse_manual_start) (Unit* self);
	gboolean (*get_refuse_manual_stop) (Unit* self);
	gboolean (*get_default_dependencies) (Unit* self);
	gchar* (*get_default_control_group) (Unit* self);
	gchar** (*get_control_groups) (Unit* self, gint* result_length1);
	gboolean (*get_need_daemon_reload) (Unit* self);
	guint64 (*get_job_timeout_usec) (Unit* self);
};

struct _ManagerUnitInfo {
	gchar* id;
	gchar* description;
	gchar* load_state;
	gchar* active_state;
	gchar* sub_state;
	gchar* following;
	char* unit_path;
	guint32 job_id;
	gchar* job_type;
	char* job_path;
};

struct _ManagerJobInfo {
	guint32 id;
	gchar* name;
	gchar* type;
	gchar* state;
	char* job_path;
	char* unit_path;
};

struct _ManagerIface {
	GTypeInterface parent_iface;
	ManagerUnitInfo* (*list_units) (Manager* self, gint* result_length1, GError** error);
	ManagerJobInfo* (*list_jobs) (Manager* self, gint* result_length1, GError** error);
	char* (*get_unit) (Manager* self, const gchar* name, GError** error);
	char* (*get_unit_by_pid) (Manager* self, guint32 pid, GError** error);
	char* (*load_unit) (Manager* self, const gchar* name, GError** error);
	char* (*get_job) (Manager* self, guint32 id, GError** error);
	char* (*start_unit) (Manager* self, const gchar* name, const gchar* mode, GError** error);
	char* (*stop_unit) (Manager* self, const gchar* name, const gchar* mode, GError** error);
	char* (*reload_unit) (Manager* self, const gchar* name, const gchar* mode, GError** error);
	char* (*restart_unit) (Manager* self, const gchar* name, const gchar* mode, GError** error);
	char* (*try_restart_unit) (Manager* self, const gchar* name, const gchar* mode, GError** error);
	char* (*reload_or_restart_unit) (Manager* self, const gchar* name, const gchar* mode, GError** error);
	char* (*reload_or_try_restart_unit) (Manager* self, const gchar* name, const gchar* mode, GError** error);
	void (*reset_failed_unit) (Manager* self, const gchar* name, GError** error);
	void (*clear_jobs) (Manager* self, GError** error);
	void (*subscribe) (Manager* self, GError** error);
	void (*unsubscribe) (Manager* self, GError** error);
	gchar* (*dump) (Manager* self, GError** error);
	void (*reload) (Manager* self, GError** error);
	void (*reexecute) (Manager* self, GError** error);
	void (*exit) (Manager* self, GError** error);
	void (*halt) (Manager* self, GError** error);
	void (*power_off) (Manager* self, GError** error);
	void (*reboot) (Manager* self, GError** error);
	void (*kexec) (Manager* self, GError** error);
	char* (*create_snapshot) (Manager* self, const gchar* name, gboolean cleanup, GError** error);
	void (*set_environment) (Manager* self, gchar** names, gint names_length1, GError** error);
	void (*unset_environment) (Manager* self, gchar** names, gint names_length1, GError** error);
	gchar** (*get_environment) (Manager* self, gint* result_length1);
};

struct _MainWindowPrivate {
	gchar* current_unit_id;
	guint32 current_job_id;
	GtkTreeView* unit_view;
	GtkTreeView* job_view;
	GtkListStore* unit_model;
	GtkListStore* job_model;
	GeeHashMap* unit_map;
	GtkButton* start_button;
	GtkButton* stop_button;
	GtkButton* restart_button;
	GtkButton* reload_button;
	GtkButton* cancel_button;
	GtkEntry* unit_load_entry;
	GtkButton* unit_load_button;
	GtkButton* server_snapshot_button;
	GtkButton* server_reload_button;
	Manager* manager;
	RightLabel* unit_id_label;
	RightLabel* unit_dependency_label;
	RightLabel* unit_description_label;
	RightLabel* unit_load_state_label;
	RightLabel* unit_active_state_label;
	RightLabel* unit_sub_state_label;
	RightLabel* unit_fragment_path_label;
	RightLabel* unit_active_enter_timestamp_label;
	RightLabel* unit_active_exit_timestamp_label;
	RightLabel* unit_can_start_label;
	RightLabel* unit_can_reload_label;
	RightLabel* unit_cgroup_label;
	RightLabel* job_id_label;
	RightLabel* job_state_label;
	RightLabel* job_type_label;
	GtkComboBoxText* unit_type_combo_box;
	GtkCheckButton* inactive_checkbox;
};

struct _JobUnitLink {
	gchar* id;
	char* path;
};

struct _JobIface {
	GTypeInterface parent_iface;
	void (*cancel) (Job* self, GError** error);
	guint32 (*get_id) (Job* self);
	gchar* (*get_state) (Job* self);
	gchar* (*get_job_type) (Job* self);
	void (*get_unit) (Job* self, JobUnitLink * result);
};

struct _PropertiesIface {
	GTypeInterface parent_iface;
	GVariant* (*get) (Properties* self, const gchar* iface, const gchar* property, GError** error);
};

VALA_EXTERN gboolean user;
gboolean user = FALSE;
static gpointer left_label_parent_class = NULL;
static gpointer right_label_parent_class = NULL;
static gint MainWindow_private_offset;
static gpointer main_window_parent_class = NULL;

VALA_EXTERN gchar* format_time (guint64 time_ns);
VALA_EXTERN void new_column (GtkTreeView* view,
                 gint column_id,
                 const gchar* title);
VALA_EXTERN GType left_label_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LeftLabel, g_object_unref)
VALA_EXTERN LeftLabel* left_label_new (const gchar* text);
VALA_EXTERN LeftLabel* left_label_construct (GType object_type,
                                 const gchar* text);
static GType left_label_get_type_once (void);
VALA_EXTERN GType right_label_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (RightLabel, g_object_unref)
VALA_EXTERN RightLabel* right_label_new (const gchar* text);
VALA_EXTERN RightLabel* right_label_construct (GType object_type,
                                   const gchar* text);
VALA_EXTERN void right_label_set_text_or_na (RightLabel* self,
                                 const gchar* text);
VALA_EXTERN void right_label_set_markup_or_na (RightLabel* self,
                                   const gchar* text);
static GType right_label_get_type_once (void);
VALA_EXTERN GtkScrolledWindow* new_scrolled_window (GtkWidget* widget);
VALA_EXTERN GType main_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MainWindow, g_object_unref)
VALA_EXTERN GType unit_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint unit_register_object (void* object,
                            GDBusConnection* connection,
                            const gchar* path,
                            GError** error);
VALA_EXTERN GType unit_job_link_get_type (void) G_GNUC_CONST ;
VALA_EXTERN UnitJobLink* unit_job_link_dup (const UnitJobLink* self);
VALA_EXTERN void unit_job_link_free (UnitJobLink* self);
VALA_EXTERN void unit_job_link_copy (const UnitJobLink* self,
                         UnitJobLink* dest);
VALA_EXTERN void unit_job_link_destroy (UnitJobLink* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (UnitJobLink, unit_job_link_destroy)
VALA_EXTERN GType unit_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Unit, g_object_unref)
VALA_EXTERN GType manager_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint manager_register_object (void* object,
                               GDBusConnection* connection,
                               const gchar* path,
                               GError** error);
VALA_EXTERN GType manager_unit_info_get_type (void) G_GNUC_CONST ;
VALA_EXTERN ManagerUnitInfo* manager_unit_info_dup (const ManagerUnitInfo* self);
VALA_EXTERN void manager_unit_info_free (ManagerUnitInfo* self);
VALA_EXTERN void manager_unit_info_copy (const ManagerUnitInfo* self,
                             ManagerUnitInfo* dest);
VALA_EXTERN void manager_unit_info_destroy (ManagerUnitInfo* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (ManagerUnitInfo, manager_unit_info_destroy)
VALA_EXTERN GType manager_job_info_get_type (void) G_GNUC_CONST ;
VALA_EXTERN ManagerJobInfo* manager_job_info_dup (const ManagerJobInfo* self);
VALA_EXTERN void manager_job_info_free (ManagerJobInfo* self);
VALA_EXTERN void manager_job_info_copy (const ManagerJobInfo* self,
                            ManagerJobInfo* dest);
VALA_EXTERN void manager_job_info_destroy (ManagerJobInfo* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (ManagerJobInfo, manager_job_info_destroy)
VALA_EXTERN GType manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Manager, g_object_unref)
VALA_EXTERN MainWindow* main_window_new (GError** error);
VALA_EXTERN MainWindow* main_window_construct (GType object_type,
                                   GError** error);
static void _gtk_main_quit_gtk_widget_destroy (GtkWidget* _sender,
                                        gpointer self);
VALA_EXTERN void main_window_unit_type_changed (MainWindow* self);
static void _main_window_unit_type_changed_gtk_combo_box_changed (GtkComboBox* _sender,
                                                           gpointer self);
static void _main_window_unit_type_changed_gtk_toggle_button_toggled (GtkToggleButton* _sender,
                                                               gpointer self);
VALA_EXTERN void main_window_on_unit_load_entry_changed (MainWindow* self);
static void _main_window_on_unit_load_entry_changed_gtk_editable_changed (GtkEditable* _sender,
                                                                   gpointer self);
VALA_EXTERN void main_window_on_unit_load (MainWindow* self);
static void _main_window_on_unit_load_gtk_entry_activate (GtkEntry* _sender,
                                                   gpointer self);
static void _main_window_on_unit_load_gtk_button_clicked (GtkButton* _sender,
                                                   gpointer self);
VALA_EXTERN void main_window_on_server_snapshot (MainWindow* self);
static void _main_window_on_server_snapshot_gtk_button_clicked (GtkButton* _sender,
                                                         gpointer self);
VALA_EXTERN void main_window_on_server_reload (MainWindow* self);
static void _main_window_on_server_reload_gtk_button_clicked (GtkButton* _sender,
                                                       gpointer self);
VALA_EXTERN GType job_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint job_register_object (void* object,
                           GDBusConnection* connection,
                           const gchar* path,
                           GError** error);
VALA_EXTERN GType job_unit_link_get_type (void) G_GNUC_CONST ;
VALA_EXTERN JobUnitLink* job_unit_link_dup (const JobUnitLink* self);
VALA_EXTERN void job_unit_link_free (JobUnitLink* self);
VALA_EXTERN void job_unit_link_copy (const JobUnitLink* self,
                         JobUnitLink* dest);
VALA_EXTERN void job_unit_link_destroy (JobUnitLink* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (JobUnitLink, job_unit_link_destroy)
VALA_EXTERN GType job_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Job, g_object_unref)
VALA_EXTERN gboolean main_window_unit_filter (MainWindow* self,
                                  GtkTreeModel* model,
                                  GtkTreeIter* iter);
static gboolean _main_window_unit_filter_gtk_tree_model_filter_visible_func (GtkTreeModel* model,
                                                                      GtkTreeIter* iter,
                                                                      gpointer self);
VALA_EXTERN void main_window_unit_changed (MainWindow* self);
static void _main_window_unit_changed_gtk_tree_view_cursor_changed (GtkTreeView* _sender,
                                                             gpointer self);
VALA_EXTERN void main_window_job_changed (MainWindow* self);
static void _main_window_job_changed_gtk_tree_view_cursor_changed (GtkTreeView* _sender,
                                                            gpointer self);
VALA_EXTERN gboolean main_window_on_activate_link (MainWindow* self,
                                       const gchar* uri);
static gboolean _main_window_on_activate_link_gtk_label_activate_link (GtkLabel* _sender,
                                                                const gchar* uri,
                                                                gpointer self);
VALA_EXTERN void main_window_on_start (MainWindow* self);
static void _main_window_on_start_gtk_button_clicked (GtkButton* _sender,
                                               gpointer self);
VALA_EXTERN void main_window_on_stop (MainWindow* self);
static void _main_window_on_stop_gtk_button_clicked (GtkButton* _sender,
                                              gpointer self);
VALA_EXTERN void main_window_on_reload (MainWindow* self);
static void _main_window_on_reload_gtk_button_clicked (GtkButton* _sender,
                                                gpointer self);
VALA_EXTERN void main_window_on_restart (MainWindow* self);
static void _main_window_on_restart_gtk_button_clicked (GtkButton* _sender,
                                                 gpointer self);
VALA_EXTERN void main_window_on_cancel (MainWindow* self);
static void _main_window_on_cancel_gtk_button_clicked (GtkButton* _sender,
                                                gpointer self);
VALA_EXTERN void main_window_on_unit_new (MainWindow* self,
                              const gchar* id,
                              const char* path);
static void _main_window_on_unit_new_manager_unit_new (Manager* _sender,
                                                const gchar* id,
                                                const char* path,
                                                gpointer self);
VALA_EXTERN void main_window_on_job_new (MainWindow* self,
                             guint32 id,
                             const char* path);
static void _main_window_on_job_new_manager_job_new (Manager* _sender,
                                              guint32 id,
                                              const char* path,
                                              gpointer self);
VALA_EXTERN void main_window_on_unit_removed (MainWindow* self,
                                  const gchar* id,
                                  const char* path);
static void _main_window_on_unit_removed_manager_unit_removed (Manager* _sender,
                                                        const gchar* id,
                                                        const char* path,
                                                        gpointer self);
VALA_EXTERN void main_window_on_job_removed (MainWindow* self,
                                 guint32 id,
                                 const char* path,
                                 const gchar* res);
static void _main_window_on_job_removed_manager_job_removed (Manager* _sender,
                                                      guint32 id,
                                                      const char* path,
                                                      const gchar* res,
                                                      gpointer self);
VALA_EXTERN void manager_subscribe (Manager* self,
                        GError** error);
VALA_EXTERN void main_window_clear_unit (MainWindow* self);
VALA_EXTERN void main_window_clear_job (MainWindow* self);
VALA_EXTERN void main_window_populate_unit_model (MainWindow* self,
                                      GError** error);
VALA_EXTERN void main_window_populate_job_model (MainWindow* self,
                                     GError** error);
VALA_EXTERN ManagerUnitInfo* manager_list_units (Manager* self,
                                     gint* result_length1,
                                     GError** error);
VALA_EXTERN GType properties_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint properties_register_object (void* object,
                                  GDBusConnection* connection,
                                  const gchar* path,
                                  GError** error);
VALA_EXTERN GType properties_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Properties, g_object_unref)
static void _vala_ManagerUnitInfo_array_free (ManagerUnitInfo * array,
                                       gssize array_length);
VALA_EXTERN void main_window_on_unit_changed (MainWindow* self,
                                  Properties* p,
                                  const gchar* iface,
                                  GHashTable* changed_properties,
                                  gchar** invalidated_properties,
                                  gint invalidated_properties_length1);
static void _main_window_on_unit_changed_properties_properties_changed (Properties* _sender,
                                                                 const gchar* iface,
                                                                 GHashTable* changed_properties,
                                                                 gchar** invalidated_properties,
                                                                 gint invalidated_properties_length1,
                                                                 gpointer self);
VALA_EXTERN ManagerJobInfo* manager_list_jobs (Manager* self,
                                   gint* result_length1,
                                   GError** error);
static void _vala_ManagerJobInfo_array_free (ManagerJobInfo * array,
                                      gssize array_length);
VALA_EXTERN void main_window_on_job_changed (MainWindow* self,
                                 Properties* p,
                                 const gchar* iface,
                                 GHashTable* changed_properties,
                                 gchar** invalidated_properties,
                                 gint invalidated_properties_length1);
static void _main_window_on_job_changed_properties_properties_changed (Properties* _sender,
                                                                const gchar* iface,
                                                                GHashTable* changed_properties,
                                                                gchar** invalidated_properties,
                                                                gint invalidated_properties_length1,
                                                                gpointer self);
VALA_EXTERN Unit* main_window_get_current_unit (MainWindow* self);
static void _vala_GtkTreePath_free (GtkTreePath* self);
VALA_EXTERN Unit* main_window_get_unit (MainWindow* self,
                            const gchar* id);
VALA_EXTERN void main_window_show_unit (MainWindow* self,
                            Unit* unit);
VALA_EXTERN gchar* main_window_format_unit_link (MainWindow* self,
                                     const gchar* i,
                                     gboolean link);
VALA_EXTERN gchar* unit_get_sub_state (Unit* self);
VALA_EXTERN gchar* main_window_make_dependency_string (MainWindow* self,
                                           const gchar* prefix,
                                           const gchar* word,
                                           gchar** dependencies,
                                           gint dependencies_length1);
VALA_EXTERN gchar* unit_get_id (Unit* self);
VALA_EXTERN gchar** unit_get_names (Unit* self,
                        gint* result_length1);
VALA_EXTERN gchar** unit_get_requires (Unit* self,
                           gint* result_length1);
VALA_EXTERN gchar** unit_get_requires_overridable (Unit* self,
                                       gint* result_length1);
VALA_EXTERN gchar** unit_get_requisite (Unit* self,
                            gint* result_length1);
VALA_EXTERN gchar** unit_get_requisite_overridable (Unit* self,
                                        gint* result_length1);
VALA_EXTERN gchar** unit_get_wants (Unit* self,
                        gint* result_length1);
VALA_EXTERN gchar** unit_get_required_by (Unit* self,
                              gint* result_length1);
VALA_EXTERN gchar** unit_get_required_by_overridable (Unit* self,
                                          gint* result_length1);
VALA_EXTERN gchar** unit_get_wanted_by (Unit* self,
                            gint* result_length1);
VALA_EXTERN gchar** unit_get_conflicts (Unit* self,
                            gint* result_length1);
VALA_EXTERN gchar** unit_get_before (Unit* self,
                         gint* result_length1);
VALA_EXTERN gchar** unit_get_after (Unit* self,
                        gint* result_length1);
VALA_EXTERN gchar* unit_get_description (Unit* self);
VALA_EXTERN gchar* unit_get_load_state (Unit* self);
VALA_EXTERN gchar* unit_get_active_state (Unit* self);
VALA_EXTERN gchar* unit_get_fragment_path (Unit* self);
VALA_EXTERN guint64 unit_get_active_enter_timestamp (Unit* self);
VALA_EXTERN guint64 unit_get_active_exit_timestamp (Unit* self);
VALA_EXTERN gboolean unit_get_can_start (Unit* self);
VALA_EXTERN gboolean unit_get_can_reload (Unit* self);
VALA_EXTERN gchar* unit_get_default_control_group (Unit* self);
VALA_EXTERN Job* main_window_get_current_job (MainWindow* self);
VALA_EXTERN void main_window_show_job (MainWindow* self,
                           Job* job);
VALA_EXTERN guint32 job_get_id (Job* self);
VALA_EXTERN gchar* job_get_state (Job* self);
VALA_EXTERN gchar* job_get_job_type (Job* self);
VALA_EXTERN char* unit_start (Unit* self,
                  const gchar* mode,
                  GError** error);
VALA_EXTERN void main_window_show_error (MainWindow* self,
                             GError* e);
VALA_EXTERN char* unit_stop (Unit* self,
                 const gchar* mode,
                 GError** error);
VALA_EXTERN char* unit_reload (Unit* self,
                   const gchar* mode,
                   GError** error);
VALA_EXTERN char* unit_restart (Unit* self,
                    const gchar* mode,
                    GError** error);
VALA_EXTERN void job_cancel (Job* self,
                 GError** error);
VALA_EXTERN void main_window_update_unit_iter (MainWindow* self,
                                   GtkTreeIter* iter,
                                   const gchar* id,
                                   Unit* u);
VALA_EXTERN void unit_get_job (Unit* self,
                   UnitJobLink * result);
VALA_EXTERN void main_window_update_job_iter (MainWindow* self,
                                  GtkTreeIter* iter,
                                  guint32 id,
                                  Job* j);
VALA_EXTERN void job_get_unit (Job* self,
                   JobUnitLink * result);
VALA_EXTERN void manager_reload (Manager* self,
                     GError** error);
VALA_EXTERN char* manager_create_snapshot (Manager* self,
                               const gchar* name,
                               gboolean cleanup,
                               GError** error);
VALA_EXTERN char* manager_load_unit (Manager* self,
                         const gchar* name,
                         GError** error);
VALA_EXTERN char* manager_get_unit (Manager* self,
                        const gchar* name,
                        GError** error);
VALA_EXTERN gint dbus_error_to_errno (const gchar* _error_);
static void main_window_finalize (GObject * obj);
static GType main_window_get_type_once (void);
VALA_EXTERN void show_error (GError* e);
static gint _vala_main (gchar** args,
                 gint args_length1);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

const GOptionEntry entries[3] = {{"user", (gchar) 0, (gint) 0, G_OPTION_ARG_NONE, &user, "Connect to user service manager", NULL}, {"system", (gchar) 0, (gint) G_OPTION_FLAG_REVERSE, G_OPTION_ARG_NONE, &user, "Connect to system manager", NULL}, {NULL}};

static void
g_time_local (time_t time,
              struct tm* result)
{
	struct tm _result_ = {0};
	struct tm _tmp0_ = {0};
#line 3317 "glib-2.0.vapi"
	localtime_r (&time, &_tmp0_);
#line 3317 "glib-2.0.vapi"
	_result_ = _tmp0_;
#line 3318 "glib-2.0.vapi"
	*result = _result_;
#line 3318 "glib-2.0.vapi"
	return;
#line 677 "systemadm.c"
}

static gchar*
g_time_format (struct tm *self,
               const gchar* format)
{
	gchar* buffer = NULL;
	gchar* _tmp0_;
	gint buffer_length1;
	gint _buffer_size_;
	gchar* _tmp1_;
	gchar* result;
#line 3325 "glib-2.0.vapi"
	g_return_val_if_fail (format != NULL, NULL);
#line 3326 "glib-2.0.vapi"
	_tmp0_ = g_new0 (gchar, 64);
#line 3326 "glib-2.0.vapi"
	buffer = _tmp0_;
#line 3326 "glib-2.0.vapi"
	buffer_length1 = 64;
#line 3326 "glib-2.0.vapi"
	_buffer_size_ = buffer_length1;
#line 3327 "glib-2.0.vapi"
	strftime (buffer, (gint) buffer_length1, format, &(*self));
#line 3328 "glib-2.0.vapi"
	_tmp1_ = g_strdup ((const gchar*) buffer);
#line 3328 "glib-2.0.vapi"
	result = _tmp1_;
#line 3328 "glib-2.0.vapi"
	buffer = (g_free (buffer), NULL);
#line 3328 "glib-2.0.vapi"
	return result;
#line 710 "systemadm.c"
}

gchar*
format_time (guint64 time_ns)
{
	struct tm timestamp = {0};
	struct tm _tmp1_ = {0};
	gchar* _tmp2_;
	gchar* result;
#line 27 "src/systemadm.vala"
	if (time_ns <= ((guint64) 0)) {
#line 722 "systemadm.c"
		gchar* _tmp0_;
#line 28 "src/systemadm.vala"
		_tmp0_ = g_strdup ("");
#line 28 "src/systemadm.vala"
		result = _tmp0_;
#line 28 "src/systemadm.vala"
		return result;
#line 730 "systemadm.c"
	}
#line 29 "src/systemadm.vala"
	g_time_local ((time_t) (time_ns / 1000000), &_tmp1_);
#line 29 "src/systemadm.vala"
	timestamp = _tmp1_;
#line 30 "src/systemadm.vala"
	_tmp2_ = g_time_format (&timestamp, "%a, %d %b %Y %H:%M:%S");
#line 30 "src/systemadm.vala"
	result = _tmp2_;
#line 30 "src/systemadm.vala"
	return result;
#line 742 "systemadm.c"
}

void
new_column (GtkTreeView* view,
            gint column_id,
            const gchar* title)
{
	GtkTreeViewColumn* col = NULL;
	GtkCellRendererText* _tmp0_;
	GtkCellRendererText* _tmp1_;
	GtkTreeViewColumn* _tmp2_;
#line 33 "src/systemadm.vala"
	g_return_if_fail (view != NULL);
#line 33 "src/systemadm.vala"
	g_return_if_fail (title != NULL);
#line 35 "src/systemadm.vala"
	_tmp0_ = (GtkCellRendererText*) gtk_cell_renderer_text_new ();
#line 35 "src/systemadm.vala"
	g_object_ref_sink (_tmp0_);
#line 35 "src/systemadm.vala"
	_tmp1_ = _tmp0_;
#line 35 "src/systemadm.vala"
	_tmp2_ = gtk_tree_view_column_new_with_attributes (title, (GtkCellRenderer*) _tmp1_, "text", column_id, NULL);
#line 35 "src/systemadm.vala"
	g_object_ref_sink (_tmp2_);
#line 35 "src/systemadm.vala"
	_g_object_unref0 (col);
#line 35 "src/systemadm.vala"
	col = _tmp2_;
#line 35 "src/systemadm.vala"
	_g_object_unref0 (_tmp1_);
#line 36 "src/systemadm.vala"
	gtk_tree_view_column_set_sort_column_id (col, column_id);
#line 37 "src/systemadm.vala"
	gtk_tree_view_insert_column (view, col, -1);
#line 33 "src/systemadm.vala"
	_g_object_unref0 (col);
#line 780 "systemadm.c"
}

LeftLabel*
left_label_construct (GType object_type,
                      const gchar* text)
{
	LeftLabel * self = NULL;
#line 41 "src/systemadm.vala"
	self = (LeftLabel*) g_object_new (object_type, NULL);
#line 42 "src/systemadm.vala"
	if (text != NULL) {
#line 792 "systemadm.c"
		gchar* _tmp0_;
		gchar* _tmp1_;
#line 43 "src/systemadm.vala"
		_tmp0_ = g_strdup_printf ("<b>%s</b>", text);
#line 43 "src/systemadm.vala"
		_tmp1_ = _tmp0_;
#line 43 "src/systemadm.vala"
		gtk_label_set_markup ((GtkLabel*) self, _tmp1_);
#line 43 "src/systemadm.vala"
		_g_free0 (_tmp1_);
#line 803 "systemadm.c"
	}
#line 44 "src/systemadm.vala"
	gtk_widget_set_halign ((GtkWidget*) self, GTK_ALIGN_START);
#line 45 "src/systemadm.vala"
	gtk_widget_set_valign ((GtkWidget*) self, GTK_ALIGN_START);
#line 41 "src/systemadm.vala"
	return self;
#line 811 "systemadm.c"
}

LeftLabel*
left_label_new (const gchar* text)
{
#line 41 "src/systemadm.vala"
	return left_label_construct (TYPE_LEFT_LABEL, text);
#line 819 "systemadm.c"
}

static void
left_label_class_init (LeftLabelClass * klass,
                       gpointer klass_data)
{
#line 40 "src/systemadm.vala"
	left_label_parent_class = g_type_class_peek_parent (klass);
#line 828 "systemadm.c"
}

static void
left_label_instance_init (LeftLabel * self,
                          gpointer klass)
{
}

static GType
left_label_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (LeftLabelClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) left_label_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LeftLabel), 0, (GInstanceInitFunc) left_label_instance_init, NULL };
	GType left_label_type_id;
	left_label_type_id = g_type_register_static (gtk_label_get_type (), "LeftLabel", &g_define_type_info, 0);
	return left_label_type_id;
}

GType
left_label_get_type (void)
{
	static volatile gsize left_label_type_id__once = 0;
	if (g_once_init_enter (&left_label_type_id__once)) {
		GType left_label_type_id;
		left_label_type_id = left_label_get_type_once ();
		g_once_init_leave (&left_label_type_id__once, left_label_type_id);
	}
	return left_label_type_id__once;
}

RightLabel*
right_label_construct (GType object_type,
                       const gchar* text)
{
	RightLabel * self = NULL;
#line 51 "src/systemadm.vala"
	self = (RightLabel*) g_object_new (object_type, NULL);
#line 52 "src/systemadm.vala"
	gtk_label_set_selectable ((GtkLabel*) self, TRUE);
#line 53 "src/systemadm.vala"
	right_label_set_text_or_na (self, text);
#line 54 "src/systemadm.vala"
	g_object_set ((GtkLabel*) self, "wrap", TRUE, NULL);
#line 55 "src/systemadm.vala"
	g_object_set ((GtkLabel*) self, "wrap-mode", PANGO_WRAP_WORD_CHAR, NULL);
#line 56 "src/systemadm.vala"
	gtk_widget_set_halign ((GtkWidget*) self, GTK_ALIGN_START);
#line 57 "src/systemadm.vala"
	gtk_widget_set_valign ((GtkWidget*) self, GTK_ALIGN_START);
#line 58 "src/systemadm.vala"
	gtk_widget_set_hexpand ((GtkWidget*) self, TRUE);
#line 51 "src/systemadm.vala"
	return self;
#line 881 "systemadm.c"
}

RightLabel*
right_label_new (const gchar* text)
{
#line 51 "src/systemadm.vala"
	return right_label_construct (TYPE_RIGHT_LABEL, text);
#line 889 "systemadm.c"
}

void
right_label_set_text_or_na (RightLabel* self,
                            const gchar* text)
{
	gboolean _tmp0_ = FALSE;
#line 61 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 62 "src/systemadm.vala"
	if (text == NULL) {
#line 62 "src/systemadm.vala"
		_tmp0_ = TRUE;
#line 903 "systemadm.c"
	} else {
#line 62 "src/systemadm.vala"
		_tmp0_ = g_strcmp0 (text, "") == 0;
#line 907 "systemadm.c"
	}
#line 62 "src/systemadm.vala"
	if (_tmp0_) {
#line 63 "src/systemadm.vala"
		gtk_label_set_markup ((GtkLabel*) self, "<i>n/a</i>");
#line 913 "systemadm.c"
	} else {
#line 65 "src/systemadm.vala"
		gtk_label_set_text ((GtkLabel*) self, text);
#line 917 "systemadm.c"
	}
}

void
right_label_set_markup_or_na (RightLabel* self,
                              const gchar* text)
{
	gboolean _tmp0_ = FALSE;
#line 68 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 69 "src/systemadm.vala"
	if (text == NULL) {
#line 69 "src/systemadm.vala"
		_tmp0_ = TRUE;
#line 932 "systemadm.c"
	} else {
#line 69 "src/systemadm.vala"
		_tmp0_ = g_strcmp0 (text, "") == 0;
#line 936 "systemadm.c"
	}
#line 69 "src/systemadm.vala"
	if (_tmp0_) {
#line 70 "src/systemadm.vala"
		gtk_label_set_markup ((GtkLabel*) self, "<i>n/a</i>");
#line 942 "systemadm.c"
	} else {
#line 72 "src/systemadm.vala"
		gtk_label_set_markup ((GtkLabel*) self, text);
#line 946 "systemadm.c"
	}
}

static void
right_label_class_init (RightLabelClass * klass,
                        gpointer klass_data)
{
#line 49 "src/systemadm.vala"
	right_label_parent_class = g_type_class_peek_parent (klass);
#line 956 "systemadm.c"
}

static void
right_label_instance_init (RightLabel * self,
                           gpointer klass)
{
}

static GType
right_label_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (RightLabelClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) right_label_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (RightLabel), 0, (GInstanceInitFunc) right_label_instance_init, NULL };
	GType right_label_type_id;
	right_label_type_id = g_type_register_static (gtk_label_get_type (), "RightLabel", &g_define_type_info, 0);
	return right_label_type_id;
}

GType
right_label_get_type (void)
{
	static volatile gsize right_label_type_id__once = 0;
	if (g_once_init_enter (&right_label_type_id__once)) {
		GType right_label_type_id;
		right_label_type_id = right_label_get_type_once ();
		g_once_init_leave (&right_label_type_id__once, right_label_type_id);
	}
	return right_label_type_id__once;
}

GtkScrolledWindow*
new_scrolled_window (GtkWidget* widget)
{
	GtkScrolledWindow* scroll = NULL;
	GtkScrolledWindow* _tmp0_;
	GtkScrolledWindow* result;
#line 76 "src/systemadm.vala"
	g_return_val_if_fail (widget != NULL, NULL);
#line 77 "src/systemadm.vala"
	_tmp0_ = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
#line 77 "src/systemadm.vala"
	g_object_ref_sink (_tmp0_);
#line 77 "src/systemadm.vala"
	scroll = _tmp0_;
#line 78 "src/systemadm.vala"
	gtk_scrolled_window_set_policy (scroll, GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
#line 79 "src/systemadm.vala"
	gtk_scrolled_window_set_shadow_type (scroll, GTK_SHADOW_IN);
#line 80 "src/systemadm.vala"
	gtk_container_add ((GtkContainer*) scroll, widget);
#line 81 "src/systemadm.vala"
	result = scroll;
#line 81 "src/systemadm.vala"
	return result;
#line 1010 "systemadm.c"
}

static inline gpointer
main_window_get_instance_private (MainWindow* self)
{
	return G_STRUCT_MEMBER_P (self, MainWindow_private_offset);
}

static void
_gtk_main_quit_gtk_widget_destroy (GtkWidget* _sender,
                                   gpointer self)
{
#line 136 "src/systemadm.vala"
	gtk_main_quit ();
#line 1025 "systemadm.c"
}

static void
_main_window_unit_type_changed_gtk_combo_box_changed (GtkComboBox* _sender,
                                                      gpointer self)
{
#line 168 "src/systemadm.vala"
	main_window_unit_type_changed ((MainWindow*) self);
#line 1034 "systemadm.c"
}

static void
_main_window_unit_type_changed_gtk_toggle_button_toggled (GtkToggleButton* _sender,
                                                          gpointer self)
{
#line 171 "src/systemadm.vala"
	main_window_unit_type_changed ((MainWindow*) self);
#line 1043 "systemadm.c"
}

static void
_main_window_on_unit_load_entry_changed_gtk_editable_changed (GtkEditable* _sender,
                                                              gpointer self)
{
#line 178 "src/systemadm.vala"
	main_window_on_unit_load_entry_changed ((MainWindow*) self);
#line 1052 "systemadm.c"
}

static void
_main_window_on_unit_load_gtk_entry_activate (GtkEntry* _sender,
                                              gpointer self)
{
#line 179 "src/systemadm.vala"
	main_window_on_unit_load ((MainWindow*) self);
#line 1061 "systemadm.c"
}

static void
_main_window_on_unit_load_gtk_button_clicked (GtkButton* _sender,
                                              gpointer self)
{
#line 180 "src/systemadm.vala"
	main_window_on_unit_load ((MainWindow*) self);
#line 1070 "systemadm.c"
}

static void
_main_window_on_server_snapshot_gtk_button_clicked (GtkButton* _sender,
                                                    gpointer self)
{
#line 189 "src/systemadm.vala"
	main_window_on_server_snapshot ((MainWindow*) self);
#line 1079 "systemadm.c"
}

static void
_main_window_on_server_reload_gtk_button_clicked (GtkButton* _sender,
                                                  gpointer self)
{
#line 190 "src/systemadm.vala"
	main_window_on_server_reload ((MainWindow*) self);
#line 1088 "systemadm.c"
}

static gboolean
_main_window_unit_filter_gtk_tree_model_filter_visible_func (GtkTreeModel* model,
                                                             GtkTreeIter* iter,
                                                             gpointer self)
{
	gboolean result;
	result = main_window_unit_filter ((MainWindow*) self, model, iter);
#line 203 "src/systemadm.vala"
	return result;
#line 1100 "systemadm.c"
}

static void
_main_window_unit_changed_gtk_tree_view_cursor_changed (GtkTreeView* _sender,
                                                        gpointer self)
{
#line 210 "src/systemadm.vala"
	main_window_unit_changed ((MainWindow*) self);
#line 1109 "systemadm.c"
}

static void
_main_window_job_changed_gtk_tree_view_cursor_changed (GtkTreeView* _sender,
                                                       gpointer self)
{
#line 211 "src/systemadm.vala"
	main_window_job_changed ((MainWindow*) self);
#line 1118 "systemadm.c"
}

static gboolean
_main_window_on_activate_link_gtk_label_activate_link (GtkLabel* _sender,
                                                       const gchar* uri,
                                                       gpointer self)
{
	gboolean result;
	result = main_window_on_activate_link ((MainWindow*) self, uri);
#line 259 "src/systemadm.vala"
	return result;
#line 1130 "systemadm.c"
}

static void
_main_window_on_start_gtk_button_clicked (GtkButton* _sender,
                                          gpointer self)
{
#line 318 "src/systemadm.vala"
	main_window_on_start ((MainWindow*) self);
#line 1139 "systemadm.c"
}

static void
_main_window_on_stop_gtk_button_clicked (GtkButton* _sender,
                                         gpointer self)
{
#line 319 "src/systemadm.vala"
	main_window_on_stop ((MainWindow*) self);
#line 1148 "systemadm.c"
}

static void
_main_window_on_reload_gtk_button_clicked (GtkButton* _sender,
                                           gpointer self)
{
#line 320 "src/systemadm.vala"
	main_window_on_reload ((MainWindow*) self);
#line 1157 "systemadm.c"
}

static void
_main_window_on_restart_gtk_button_clicked (GtkButton* _sender,
                                            gpointer self)
{
#line 321 "src/systemadm.vala"
	main_window_on_restart ((MainWindow*) self);
#line 1166 "systemadm.c"
}

static void
_main_window_on_cancel_gtk_button_clicked (GtkButton* _sender,
                                           gpointer self)
{
#line 335 "src/systemadm.vala"
	main_window_on_cancel ((MainWindow*) self);
#line 1175 "systemadm.c"
}

static void
_main_window_on_unit_new_manager_unit_new (Manager* _sender,
                                           const gchar* id,
                                           const char* path,
                                           gpointer self)
{
#line 344 "src/systemadm.vala"
	main_window_on_unit_new ((MainWindow*) self, id, path);
#line 1186 "systemadm.c"
}

static void
_main_window_on_job_new_manager_job_new (Manager* _sender,
                                         guint32 id,
                                         const char* path,
                                         gpointer self)
{
#line 345 "src/systemadm.vala"
	main_window_on_job_new ((MainWindow*) self, id, path);
#line 1197 "systemadm.c"
}

static void
_main_window_on_unit_removed_manager_unit_removed (Manager* _sender,
                                                   const gchar* id,
                                                   const char* path,
                                                   gpointer self)
{
#line 346 "src/systemadm.vala"
	main_window_on_unit_removed ((MainWindow*) self, id, path);
#line 1208 "systemadm.c"
}

static void
_main_window_on_job_removed_manager_job_removed (Manager* _sender,
                                                 guint32 id,
                                                 const char* path,
                                                 const gchar* res,
                                                 gpointer self)
{
#line 347 "src/systemadm.vala"
	main_window_on_job_removed ((MainWindow*) self, id, path, res);
#line 1220 "systemadm.c"
}

MainWindow*
main_window_construct (GType object_type,
                       GError** error)
{
	MainWindow * self = NULL;
	const gchar* _tmp0_ = NULL;
	GtkNotebook* notebook = NULL;
	GtkNotebook* _tmp1_;
	GtkNotebook* _tmp2_;
	GtkBox* unit_vbox = NULL;
	GtkBox* _tmp3_;
	GtkNotebook* _tmp4_;
	GtkBox* _tmp5_;
	GtkLabel* _tmp6_;
	GtkLabel* _tmp7_;
	GtkBox* _tmp8_;
	GtkBox* job_vbox = NULL;
	GtkBox* _tmp9_;
	GtkNotebook* _tmp10_;
	GtkBox* _tmp11_;
	GtkLabel* _tmp12_;
	GtkLabel* _tmp13_;
	GtkBox* _tmp14_;
	GtkComboBoxText* _tmp15_;
	GtkBox* type_hbox = NULL;
	GtkBox* _tmp16_;
	GtkBox* _tmp17_;
	GtkComboBoxText* _tmp18_;
	GtkBox* _tmp19_;
	GtkBox* _tmp20_;
	GtkComboBoxText* _tmp21_;
	GtkComboBoxText* _tmp22_;
	GtkComboBoxText* _tmp23_;
	GtkComboBoxText* _tmp24_;
	GtkComboBoxText* _tmp25_;
	GtkComboBoxText* _tmp26_;
	GtkComboBoxText* _tmp27_;
	GtkComboBoxText* _tmp28_;
	GtkComboBoxText* _tmp29_;
	GtkComboBoxText* _tmp30_;
	GtkComboBoxText* _tmp31_;
	GtkComboBoxText* _tmp32_;
	GtkComboBoxText* _tmp33_;
	GtkComboBoxText* _tmp34_;
	GtkComboBoxText* _tmp35_;
	GtkCheckButton* _tmp36_;
	GtkCheckButton* _tmp37_;
	GtkBox* _tmp38_;
	GtkCheckButton* _tmp39_;
	GtkEntry* _tmp40_;
	GtkButton* _tmp41_;
	GtkButton* _tmp42_;
	GtkEntry* _tmp43_;
	GtkEntry* _tmp44_;
	GtkButton* _tmp45_;
	GtkBox* unit_load_hbox = NULL;
	GtkBox* _tmp46_;
	GtkBox* _tmp47_;
	GtkEntry* _tmp48_;
	GtkBox* _tmp49_;
	GtkButton* _tmp50_;
	GtkButton* _tmp51_;
	GtkButton* _tmp52_;
	GtkButton* _tmp53_;
	GtkButton* _tmp54_;
	GtkBox* _tmp55_;
	GtkButton* _tmp56_;
	GtkBox* _tmp57_;
	GtkButton* _tmp58_;
	GtkBox* _tmp59_;
	GtkBox* _tmp60_;
	GtkListStore* _tmp61_;
	GtkListStore* _tmp62_;
	GeeHashMap* _tmp63_;
	GtkTreeModelFilter* unit_model_filter = NULL;
	GtkListStore* _tmp64_;
	GtkTreeModelFilter* _tmp65_;
	GtkTreeModelFilter* _tmp66_;
	GtkTreeModelSort* unit_model_sort = NULL;
	GtkTreeModelFilter* _tmp67_;
	GtkTreeModelSort* _tmp68_;
	GtkTreeModelSort* _tmp69_;
	GtkTreeView* _tmp70_;
	GtkListStore* _tmp71_;
	GtkTreeView* _tmp72_;
	GtkTreeView* _tmp73_;
	GtkTreeView* _tmp74_;
	GtkTreeView* _tmp75_;
	GtkTreeView* _tmp76_;
	GtkTreeView* _tmp77_;
	GtkTreeView* _tmp78_;
	GtkTreeView* _tmp79_;
	GtkTreeView* _tmp80_;
	GtkTreeView* _tmp81_;
	GtkTreeView* _tmp82_;
	GtkTreeView* _tmp83_;
	GtkPaned* paned = NULL;
	GtkPaned* _tmp84_;
	GtkBox* _tmp85_;
	GtkPaned* _tmp86_;
	GtkPaned* _tmp87_;
	GtkTreeView* _tmp88_;
	GtkScrolledWindow* _tmp89_;
	GtkScrolledWindow* _tmp90_;
	GtkBox* unit_vbox2 = NULL;
	GtkBox* _tmp91_;
	GtkPaned* _tmp92_;
	GtkBox* _tmp93_;
	GtkScrolledWindow* _tmp94_;
	GtkScrolledWindow* _tmp95_;
	GtkPaned* _tmp96_;
	GtkBox* _tmp97_;
	GtkPaned* _tmp98_;
	GtkPaned* _tmp99_;
	GtkTreeView* _tmp100_;
	GtkScrolledWindow* _tmp101_;
	GtkScrolledWindow* _tmp102_;
	GtkBox* job_vbox2 = NULL;
	GtkBox* _tmp103_;
	GtkPaned* _tmp104_;
	GtkBox* _tmp105_;
	GtkScrolledWindow* _tmp106_;
	GtkScrolledWindow* _tmp107_;
	RightLabel* _tmp108_;
	RightLabel* _tmp109_;
	RightLabel* _tmp110_;
	RightLabel* _tmp111_;
	RightLabel* _tmp112_;
	RightLabel* _tmp113_;
	RightLabel* _tmp114_;
	RightLabel* _tmp115_;
	RightLabel* _tmp116_;
	RightLabel* _tmp117_;
	RightLabel* _tmp118_;
	RightLabel* _tmp119_;
	RightLabel* _tmp120_;
	RightLabel* _tmp121_;
	RightLabel* _tmp122_;
	RightLabel* _tmp123_;
	RightLabel* _tmp124_;
	RightLabel* _tmp125_;
	RightLabel* _tmp126_;
	GtkGrid* unit_grid = NULL;
	GtkGrid* _tmp127_;
	GtkGrid* _tmp128_;
	GtkGrid* _tmp129_;
	GtkBox* _tmp130_;
	GtkGrid* _tmp131_;
	GtkGrid* job_grid = NULL;
	GtkGrid* _tmp132_;
	GtkGrid* _tmp133_;
	GtkGrid* _tmp134_;
	GtkBox* _tmp135_;
	GtkGrid* _tmp136_;
	GtkGrid* _tmp137_;
	LeftLabel* _tmp138_;
	LeftLabel* _tmp139_;
	GtkGrid* _tmp140_;
	RightLabel* _tmp141_;
	GtkGrid* _tmp142_;
	LeftLabel* _tmp143_;
	LeftLabel* _tmp144_;
	GtkGrid* _tmp145_;
	RightLabel* _tmp146_;
	GtkGrid* _tmp147_;
	LeftLabel* _tmp148_;
	LeftLabel* _tmp149_;
	GtkGrid* _tmp150_;
	RightLabel* _tmp151_;
	GtkGrid* _tmp152_;
	LeftLabel* _tmp153_;
	LeftLabel* _tmp154_;
	GtkGrid* _tmp155_;
	RightLabel* _tmp156_;
	GtkGrid* _tmp157_;
	LeftLabel* _tmp158_;
	LeftLabel* _tmp159_;
	GtkGrid* _tmp160_;
	RightLabel* _tmp161_;
	GtkGrid* _tmp162_;
	LeftLabel* _tmp163_;
	LeftLabel* _tmp164_;
	GtkGrid* _tmp165_;
	RightLabel* _tmp166_;
	GtkGrid* _tmp167_;
	LeftLabel* _tmp168_;
	LeftLabel* _tmp169_;
	GtkGrid* _tmp170_;
	RightLabel* _tmp171_;
	GtkGrid* _tmp172_;
	LeftLabel* _tmp173_;
	LeftLabel* _tmp174_;
	GtkGrid* _tmp175_;
	RightLabel* _tmp176_;
	GtkGrid* _tmp177_;
	LeftLabel* _tmp178_;
	LeftLabel* _tmp179_;
	GtkGrid* _tmp180_;
	RightLabel* _tmp181_;
	GtkGrid* _tmp182_;
	LeftLabel* _tmp183_;
	LeftLabel* _tmp184_;
	GtkGrid* _tmp185_;
	RightLabel* _tmp186_;
	GtkGrid* _tmp187_;
	LeftLabel* _tmp188_;
	LeftLabel* _tmp189_;
	GtkGrid* _tmp190_;
	RightLabel* _tmp191_;
	GtkGrid* _tmp192_;
	LeftLabel* _tmp193_;
	LeftLabel* _tmp194_;
	GtkGrid* _tmp195_;
	RightLabel* _tmp196_;
	GtkGrid* _tmp197_;
	LeftLabel* _tmp198_;
	LeftLabel* _tmp199_;
	GtkGrid* _tmp200_;
	RightLabel* _tmp201_;
	GtkGrid* _tmp202_;
	LeftLabel* _tmp203_;
	LeftLabel* _tmp204_;
	GtkGrid* _tmp205_;
	RightLabel* _tmp206_;
	GtkGrid* _tmp207_;
	LeftLabel* _tmp208_;
	LeftLabel* _tmp209_;
	GtkGrid* _tmp210_;
	RightLabel* _tmp211_;
	GtkButtonBox* bbox = NULL;
	GtkButtonBox* _tmp212_;
	GtkButtonBox* _tmp213_;
	GtkButtonBox* _tmp214_;
	GtkBox* _tmp215_;
	GtkButtonBox* _tmp216_;
	GtkButton* _tmp217_;
	GtkButton* _tmp218_;
	GtkButton* _tmp219_;
	GtkButton* _tmp220_;
	GtkButton* _tmp221_;
	GtkButton* _tmp222_;
	GtkButton* _tmp223_;
	GtkButton* _tmp224_;
	GtkButtonBox* _tmp225_;
	GtkButton* _tmp226_;
	GtkButtonBox* _tmp227_;
	GtkButton* _tmp228_;
	GtkButtonBox* _tmp229_;
	GtkButton* _tmp230_;
	GtkButtonBox* _tmp231_;
	GtkButton* _tmp232_;
	GtkButtonBox* _tmp233_;
	GtkButtonBox* _tmp234_;
	GtkButtonBox* _tmp235_;
	GtkBox* _tmp236_;
	GtkButtonBox* _tmp237_;
	GtkButton* _tmp238_;
	GtkButton* _tmp239_;
	GtkButtonBox* _tmp240_;
	GtkButton* _tmp241_;
	GBusType _tmp242_ = 0;
	Manager* _tmp243_ = NULL;
	Manager* _tmp244_;
	Manager* _tmp245_;
	Manager* _tmp246_;
	Manager* _tmp247_;
	Manager* _tmp248_;
	Manager* _tmp249_;
	Manager* _tmp250_;
	GError* _inner_error0_ = NULL;
#line 131 "src/systemadm.vala"
	self = (MainWindow*) g_object_new (object_type, NULL);
#line 132 "src/systemadm.vala"
	if (user) {
#line 132 "src/systemadm.vala"
		_tmp0_ = "systemd User Service Manager";
#line 1499 "systemadm.c"
	} else {
#line 132 "src/systemadm.vala"
		_tmp0_ = "systemd System Manager";
#line 1503 "systemadm.c"
	}
#line 132 "src/systemadm.vala"
	gtk_window_set_title ((GtkWindow*) self, _tmp0_);
#line 133 "src/systemadm.vala"
	gtk_window_set_position ((GtkWindow*) self, GTK_WIN_POS_CENTER);
#line 134 "src/systemadm.vala"
	gtk_window_set_default_size ((GtkWindow*) self, 1000, 700);
#line 135 "src/systemadm.vala"
	gtk_container_set_border_width ((GtkContainer*) self, (guint) 12);
#line 136 "src/systemadm.vala"
	g_signal_connect ((GtkWidget*) self, "destroy", (GCallback) _gtk_main_quit_gtk_widget_destroy, NULL);
#line 138 "src/systemadm.vala"
	_tmp1_ = (GtkNotebook*) gtk_notebook_new ();
#line 138 "src/systemadm.vala"
	g_object_ref_sink (_tmp1_);
#line 138 "src/systemadm.vala"
	notebook = _tmp1_;
#line 139 "src/systemadm.vala"
	_tmp2_ = notebook;
#line 139 "src/systemadm.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp2_);
#line 141 "src/systemadm.vala"
	_tmp3_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
#line 141 "src/systemadm.vala"
	g_object_ref_sink (_tmp3_);
#line 141 "src/systemadm.vala"
	unit_vbox = _tmp3_;
#line 142 "src/systemadm.vala"
	_tmp4_ = notebook;
#line 142 "src/systemadm.vala"
	_tmp5_ = unit_vbox;
#line 142 "src/systemadm.vala"
	_tmp6_ = (GtkLabel*) gtk_label_new ("Units");
#line 142 "src/systemadm.vala"
	g_object_ref_sink (_tmp6_);
#line 142 "src/systemadm.vala"
	_tmp7_ = _tmp6_;
#line 142 "src/systemadm.vala"
	gtk_notebook_append_page (_tmp4_, (GtkWidget*) _tmp5_, (GtkWidget*) _tmp7_);
#line 142 "src/systemadm.vala"
	_g_object_unref0 (_tmp7_);
#line 143 "src/systemadm.vala"
	_tmp8_ = unit_vbox;
#line 143 "src/systemadm.vala"
	gtk_container_set_border_width ((GtkContainer*) _tmp8_, (guint) 12);
#line 145 "src/systemadm.vala"
	_tmp9_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
#line 145 "src/systemadm.vala"
	g_object_ref_sink (_tmp9_);
#line 145 "src/systemadm.vala"
	job_vbox = _tmp9_;
#line 146 "src/systemadm.vala"
	_tmp10_ = notebook;
#line 146 "src/systemadm.vala"
	_tmp11_ = job_vbox;
#line 146 "src/systemadm.vala"
	_tmp12_ = (GtkLabel*) gtk_label_new ("Jobs");
#line 146 "src/systemadm.vala"
	g_object_ref_sink (_tmp12_);
#line 146 "src/systemadm.vala"
	_tmp13_ = _tmp12_;
#line 146 "src/systemadm.vala"
	gtk_notebook_append_page (_tmp10_, (GtkWidget*) _tmp11_, (GtkWidget*) _tmp13_);
#line 146 "src/systemadm.vala"
	_g_object_unref0 (_tmp13_);
#line 147 "src/systemadm.vala"
	_tmp14_ = job_vbox;
#line 147 "src/systemadm.vala"
	gtk_container_set_border_width ((GtkContainer*) _tmp14_, (guint) 12);
#line 149 "src/systemadm.vala"
	_tmp15_ = (GtkComboBoxText*) gtk_combo_box_text_new ();
#line 149 "src/systemadm.vala"
	g_object_ref_sink (_tmp15_);
#line 149 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_type_combo_box);
#line 149 "src/systemadm.vala"
	self->priv->unit_type_combo_box = _tmp15_;
#line 150 "src/systemadm.vala"
	_tmp16_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
#line 150 "src/systemadm.vala"
	g_object_ref_sink (_tmp16_);
#line 150 "src/systemadm.vala"
	type_hbox = _tmp16_;
#line 151 "src/systemadm.vala"
	_tmp17_ = type_hbox;
#line 151 "src/systemadm.vala"
	_tmp18_ = self->priv->unit_type_combo_box;
#line 151 "src/systemadm.vala"
	gtk_box_pack_start (_tmp17_, (GtkWidget*) _tmp18_, FALSE, FALSE, (guint) 0);
#line 152 "src/systemadm.vala"
	_tmp19_ = unit_vbox;
#line 152 "src/systemadm.vala"
	_tmp20_ = type_hbox;
#line 152 "src/systemadm.vala"
	gtk_box_pack_start (_tmp19_, (GtkWidget*) _tmp20_, FALSE, FALSE, (guint) 0);
#line 154 "src/systemadm.vala"
	_tmp21_ = self->priv->unit_type_combo_box;
#line 154 "src/systemadm.vala"
	gtk_combo_box_text_append_text (_tmp21_, "All unit types");
#line 155 "src/systemadm.vala"
	_tmp22_ = self->priv->unit_type_combo_box;
#line 155 "src/systemadm.vala"
	gtk_combo_box_text_append_text (_tmp22_, "Targets");
#line 156 "src/systemadm.vala"
	_tmp23_ = self->priv->unit_type_combo_box;
#line 156 "src/systemadm.vala"
	gtk_combo_box_text_append_text (_tmp23_, "Slices");
#line 157 "src/systemadm.vala"
	_tmp24_ = self->priv->unit_type_combo_box;
#line 157 "src/systemadm.vala"
	gtk_combo_box_text_append_text (_tmp24_, "Scopes");
#line 158 "src/systemadm.vala"
	_tmp25_ = self->priv->unit_type_combo_box;
#line 158 "src/systemadm.vala"
	gtk_combo_box_text_append_text (_tmp25_, "Services");
#line 159 "src/systemadm.vala"
	_tmp26_ = self->priv->unit_type_combo_box;
#line 159 "src/systemadm.vala"
	gtk_combo_box_text_append_text (_tmp26_, "Devices");
#line 160 "src/systemadm.vala"
	_tmp27_ = self->priv->unit_type_combo_box;
#line 160 "src/systemadm.vala"
	gtk_combo_box_text_append_text (_tmp27_, "Mounts");
#line 161 "src/systemadm.vala"
	_tmp28_ = self->priv->unit_type_combo_box;
#line 161 "src/systemadm.vala"
	gtk_combo_box_text_append_text (_tmp28_, "Automounts");
#line 162 "src/systemadm.vala"
	_tmp29_ = self->priv->unit_type_combo_box;
#line 162 "src/systemadm.vala"
	gtk_combo_box_text_append_text (_tmp29_, "Swaps");
#line 163 "src/systemadm.vala"
	_tmp30_ = self->priv->unit_type_combo_box;
#line 163 "src/systemadm.vala"
	gtk_combo_box_text_append_text (_tmp30_, "Sockets");
#line 164 "src/systemadm.vala"
	_tmp31_ = self->priv->unit_type_combo_box;
#line 164 "src/systemadm.vala"
	gtk_combo_box_text_append_text (_tmp31_, "Paths");
#line 165 "src/systemadm.vala"
	_tmp32_ = self->priv->unit_type_combo_box;
#line 165 "src/systemadm.vala"
	gtk_combo_box_text_append_text (_tmp32_, "Timers");
#line 166 "src/systemadm.vala"
	_tmp33_ = self->priv->unit_type_combo_box;
#line 166 "src/systemadm.vala"
	gtk_combo_box_text_append_text (_tmp33_, "Snapshots");
#line 167 "src/systemadm.vala"
	_tmp34_ = self->priv->unit_type_combo_box;
#line 167 "src/systemadm.vala"
	gtk_combo_box_set_active ((GtkComboBox*) _tmp34_, 0);
#line 168 "src/systemadm.vala"
	_tmp35_ = self->priv->unit_type_combo_box;
#line 168 "src/systemadm.vala"
	g_signal_connect_object ((GtkComboBox*) _tmp35_, "changed", (GCallback) _main_window_unit_type_changed_gtk_combo_box_changed, self, 0);
#line 170 "src/systemadm.vala"
	_tmp36_ = (GtkCheckButton*) gtk_check_button_new_with_label ("inactive too");
#line 170 "src/systemadm.vala"
	g_object_ref_sink (_tmp36_);
#line 170 "src/systemadm.vala"
	_g_object_unref0 (self->priv->inactive_checkbox);
#line 170 "src/systemadm.vala"
	self->priv->inactive_checkbox = _tmp36_;
#line 171 "src/systemadm.vala"
	_tmp37_ = self->priv->inactive_checkbox;
#line 171 "src/systemadm.vala"
	g_signal_connect_object ((GtkToggleButton*) _tmp37_, "toggled", (GCallback) _main_window_unit_type_changed_gtk_toggle_button_toggled, self, 0);
#line 172 "src/systemadm.vala"
	_tmp38_ = type_hbox;
#line 172 "src/systemadm.vala"
	_tmp39_ = self->priv->inactive_checkbox;
#line 172 "src/systemadm.vala"
	gtk_box_pack_start (_tmp38_, (GtkWidget*) _tmp39_, FALSE, FALSE, (guint) 0);
#line 174 "src/systemadm.vala"
	_tmp40_ = (GtkEntry*) gtk_entry_new ();
#line 174 "src/systemadm.vala"
	g_object_ref_sink (_tmp40_);
#line 174 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_load_entry);
#line 174 "src/systemadm.vala"
	self->priv->unit_load_entry = _tmp40_;
#line 175 "src/systemadm.vala"
	_tmp41_ = (GtkButton*) gtk_button_new_with_mnemonic ("_Load");
#line 175 "src/systemadm.vala"
	g_object_ref_sink (_tmp41_);
#line 175 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_load_button);
#line 175 "src/systemadm.vala"
	self->priv->unit_load_button = _tmp41_;
#line 176 "src/systemadm.vala"
	_tmp42_ = self->priv->unit_load_button;
#line 176 "src/systemadm.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp42_, FALSE);
#line 178 "src/systemadm.vala"
	_tmp43_ = self->priv->unit_load_entry;
#line 178 "src/systemadm.vala"
	g_signal_connect_object ((GtkEditable*) _tmp43_, "changed", (GCallback) _main_window_on_unit_load_entry_changed_gtk_editable_changed, self, 0);
#line 179 "src/systemadm.vala"
	_tmp44_ = self->priv->unit_load_entry;
#line 179 "src/systemadm.vala"
	g_signal_connect_object (_tmp44_, "activate", (GCallback) _main_window_on_unit_load_gtk_entry_activate, self, 0);
#line 180 "src/systemadm.vala"
	_tmp45_ = self->priv->unit_load_button;
#line 180 "src/systemadm.vala"
	g_signal_connect_object (_tmp45_, "clicked", (GCallback) _main_window_on_unit_load_gtk_button_clicked, self, 0);
#line 182 "src/systemadm.vala"
	_tmp46_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
#line 182 "src/systemadm.vala"
	g_object_ref_sink (_tmp46_);
#line 182 "src/systemadm.vala"
	unit_load_hbox = _tmp46_;
#line 183 "src/systemadm.vala"
	_tmp47_ = unit_load_hbox;
#line 183 "src/systemadm.vala"
	_tmp48_ = self->priv->unit_load_entry;
#line 183 "src/systemadm.vala"
	gtk_box_pack_start (_tmp47_, (GtkWidget*) _tmp48_, FALSE, TRUE, (guint) 0);
#line 184 "src/systemadm.vala"
	_tmp49_ = unit_load_hbox;
#line 184 "src/systemadm.vala"
	_tmp50_ = self->priv->unit_load_button;
#line 184 "src/systemadm.vala"
	gtk_box_pack_start (_tmp49_, (GtkWidget*) _tmp50_, FALSE, TRUE, (guint) 0);
#line 186 "src/systemadm.vala"
	_tmp51_ = (GtkButton*) gtk_button_new_with_mnemonic ("Take S_napshot");
#line 186 "src/systemadm.vala"
	g_object_ref_sink (_tmp51_);
#line 186 "src/systemadm.vala"
	_g_object_unref0 (self->priv->server_snapshot_button);
#line 186 "src/systemadm.vala"
	self->priv->server_snapshot_button = _tmp51_;
#line 187 "src/systemadm.vala"
	_tmp52_ = (GtkButton*) gtk_button_new_with_mnemonic ("Reload _Configuration");
#line 187 "src/systemadm.vala"
	g_object_ref_sink (_tmp52_);
#line 187 "src/systemadm.vala"
	_g_object_unref0 (self->priv->server_reload_button);
#line 187 "src/systemadm.vala"
	self->priv->server_reload_button = _tmp52_;
#line 189 "src/systemadm.vala"
	_tmp53_ = self->priv->server_snapshot_button;
#line 189 "src/systemadm.vala"
	g_signal_connect_object (_tmp53_, "clicked", (GCallback) _main_window_on_server_snapshot_gtk_button_clicked, self, 0);
#line 190 "src/systemadm.vala"
	_tmp54_ = self->priv->server_reload_button;
#line 190 "src/systemadm.vala"
	g_signal_connect_object (_tmp54_, "clicked", (GCallback) _main_window_on_server_reload_gtk_button_clicked, self, 0);
#line 192 "src/systemadm.vala"
	_tmp55_ = type_hbox;
#line 192 "src/systemadm.vala"
	_tmp56_ = self->priv->server_snapshot_button;
#line 192 "src/systemadm.vala"
	gtk_box_pack_end (_tmp55_, (GtkWidget*) _tmp56_, FALSE, TRUE, (guint) 0);
#line 193 "src/systemadm.vala"
	_tmp57_ = type_hbox;
#line 193 "src/systemadm.vala"
	_tmp58_ = self->priv->server_reload_button;
#line 193 "src/systemadm.vala"
	gtk_box_pack_end (_tmp57_, (GtkWidget*) _tmp58_, FALSE, TRUE, (guint) 0);
#line 194 "src/systemadm.vala"
	_tmp59_ = type_hbox;
#line 194 "src/systemadm.vala"
	_tmp60_ = unit_load_hbox;
#line 194 "src/systemadm.vala"
	gtk_box_pack_end (_tmp59_, (GtkWidget*) _tmp60_, FALSE, TRUE, (guint) 24);
#line 196 "src/systemadm.vala"
	_tmp61_ = gtk_list_store_new (7, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, TYPE_UNIT, -1);
#line 196 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_model);
#line 196 "src/systemadm.vala"
	self->priv->unit_model = _tmp61_;
#line 197 "src/systemadm.vala"
	_tmp62_ = gtk_list_store_new (6, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, TYPE_JOB, G_TYPE_UINT, -1);
#line 197 "src/systemadm.vala"
	_g_object_unref0 (self->priv->job_model);
#line 197 "src/systemadm.vala"
	self->priv->job_model = _tmp62_;
#line 199 "src/systemadm.vala"
	_tmp63_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, TYPE_UNIT, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 199 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_map);
#line 199 "src/systemadm.vala"
	self->priv->unit_map = _tmp63_;
#line 202 "src/systemadm.vala"
	_tmp64_ = self->priv->unit_model;
#line 202 "src/systemadm.vala"
	_tmp65_ = (GtkTreeModelFilter*) gtk_tree_model_filter_new ((GtkTreeModel*) _tmp64_, NULL);
#line 202 "src/systemadm.vala"
	_g_object_unref0 (unit_model_filter);
#line 202 "src/systemadm.vala"
	unit_model_filter = _tmp65_;
#line 203 "src/systemadm.vala"
	_tmp66_ = unit_model_filter;
#line 203 "src/systemadm.vala"
	gtk_tree_model_filter_set_visible_func (_tmp66_, _main_window_unit_filter_gtk_tree_model_filter_visible_func, g_object_ref (self), g_object_unref);
#line 205 "src/systemadm.vala"
	_tmp67_ = unit_model_filter;
#line 205 "src/systemadm.vala"
	_tmp68_ = (GtkTreeModelSort*) gtk_tree_model_sort_new_with_model ((GtkTreeModel*) _tmp67_);
#line 205 "src/systemadm.vala"
	unit_model_sort = _tmp68_;
#line 207 "src/systemadm.vala"
	_tmp69_ = unit_model_sort;
#line 207 "src/systemadm.vala"
	_tmp70_ = (GtkTreeView*) gtk_tree_view_new_with_model ((GtkTreeModel*) _tmp69_);
#line 207 "src/systemadm.vala"
	g_object_ref_sink (_tmp70_);
#line 207 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_view);
#line 207 "src/systemadm.vala"
	self->priv->unit_view = _tmp70_;
#line 208 "src/systemadm.vala"
	_tmp71_ = self->priv->job_model;
#line 208 "src/systemadm.vala"
	_tmp72_ = (GtkTreeView*) gtk_tree_view_new_with_model ((GtkTreeModel*) _tmp71_);
#line 208 "src/systemadm.vala"
	g_object_ref_sink (_tmp72_);
#line 208 "src/systemadm.vala"
	_g_object_unref0 (self->priv->job_view);
#line 208 "src/systemadm.vala"
	self->priv->job_view = _tmp72_;
#line 210 "src/systemadm.vala"
	_tmp73_ = self->priv->unit_view;
#line 210 "src/systemadm.vala"
	g_signal_connect_object (_tmp73_, "cursor-changed", (GCallback) _main_window_unit_changed_gtk_tree_view_cursor_changed, self, 0);
#line 211 "src/systemadm.vala"
	_tmp74_ = self->priv->job_view;
#line 211 "src/systemadm.vala"
	g_signal_connect_object (_tmp74_, "cursor-changed", (GCallback) _main_window_job_changed_gtk_tree_view_cursor_changed, self, 0);
#line 213 "src/systemadm.vala"
	_tmp75_ = self->priv->unit_view;
#line 213 "src/systemadm.vala"
	new_column (_tmp75_, 2, "Load State");
#line 214 "src/systemadm.vala"
	_tmp76_ = self->priv->unit_view;
#line 214 "src/systemadm.vala"
	new_column (_tmp76_, 3, "Active State");
#line 215 "src/systemadm.vala"
	_tmp77_ = self->priv->unit_view;
#line 215 "src/systemadm.vala"
	new_column (_tmp77_, 4, "Unit State");
#line 216 "src/systemadm.vala"
	_tmp78_ = self->priv->unit_view;
#line 216 "src/systemadm.vala"
	new_column (_tmp78_, 0, "Unit");
#line 217 "src/systemadm.vala"
	_tmp79_ = self->priv->unit_view;
#line 217 "src/systemadm.vala"
	new_column (_tmp79_, 5, "Job");
#line 219 "src/systemadm.vala"
	_tmp80_ = self->priv->job_view;
#line 219 "src/systemadm.vala"
	new_column (_tmp80_, 0, "Job");
#line 220 "src/systemadm.vala"
	_tmp81_ = self->priv->job_view;
#line 220 "src/systemadm.vala"
	new_column (_tmp81_, 1, "Unit");
#line 221 "src/systemadm.vala"
	_tmp82_ = self->priv->job_view;
#line 221 "src/systemadm.vala"
	new_column (_tmp82_, 2, "Type");
#line 222 "src/systemadm.vala"
	_tmp83_ = self->priv->job_view;
#line 222 "src/systemadm.vala"
	new_column (_tmp83_, 3, "State");
#line 224 "src/systemadm.vala"
	_tmp84_ = (GtkPaned*) gtk_paned_new (GTK_ORIENTATION_VERTICAL);
#line 224 "src/systemadm.vala"
	g_object_ref_sink (_tmp84_);
#line 224 "src/systemadm.vala"
	paned = _tmp84_;
#line 225 "src/systemadm.vala"
	_tmp85_ = unit_vbox;
#line 225 "src/systemadm.vala"
	_tmp86_ = paned;
#line 225 "src/systemadm.vala"
	gtk_box_pack_start (_tmp85_, (GtkWidget*) _tmp86_, TRUE, TRUE, (guint) 0);
#line 227 "src/systemadm.vala"
	_tmp87_ = paned;
#line 227 "src/systemadm.vala"
	_tmp88_ = self->priv->unit_view;
#line 227 "src/systemadm.vala"
	_tmp89_ = new_scrolled_window ((GtkWidget*) _tmp88_);
#line 227 "src/systemadm.vala"
	_tmp90_ = _tmp89_;
#line 227 "src/systemadm.vala"
	gtk_paned_pack1 (_tmp87_, (GtkWidget*) _tmp90_, TRUE, TRUE);
#line 227 "src/systemadm.vala"
	_g_object_unref0 (_tmp90_);
#line 229 "src/systemadm.vala"
	_tmp91_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
#line 229 "src/systemadm.vala"
	g_object_ref_sink (_tmp91_);
#line 229 "src/systemadm.vala"
	unit_vbox2 = _tmp91_;
#line 230 "src/systemadm.vala"
	_tmp92_ = paned;
#line 230 "src/systemadm.vala"
	_tmp93_ = unit_vbox2;
#line 230 "src/systemadm.vala"
	_tmp94_ = new_scrolled_window ((GtkWidget*) _tmp93_);
#line 230 "src/systemadm.vala"
	_tmp95_ = _tmp94_;
#line 230 "src/systemadm.vala"
	gtk_paned_pack2 (_tmp92_, (GtkWidget*) _tmp95_, FALSE, TRUE);
#line 230 "src/systemadm.vala"
	_g_object_unref0 (_tmp95_);
#line 232 "src/systemadm.vala"
	_tmp96_ = (GtkPaned*) gtk_paned_new (GTK_ORIENTATION_VERTICAL);
#line 232 "src/systemadm.vala"
	g_object_ref_sink (_tmp96_);
#line 232 "src/systemadm.vala"
	_g_object_unref0 (paned);
#line 232 "src/systemadm.vala"
	paned = _tmp96_;
#line 233 "src/systemadm.vala"
	_tmp97_ = job_vbox;
#line 233 "src/systemadm.vala"
	_tmp98_ = paned;
#line 233 "src/systemadm.vala"
	gtk_box_pack_start (_tmp97_, (GtkWidget*) _tmp98_, TRUE, TRUE, (guint) 0);
#line 235 "src/systemadm.vala"
	_tmp99_ = paned;
#line 235 "src/systemadm.vala"
	_tmp100_ = self->priv->job_view;
#line 235 "src/systemadm.vala"
	_tmp101_ = new_scrolled_window ((GtkWidget*) _tmp100_);
#line 235 "src/systemadm.vala"
	_tmp102_ = _tmp101_;
#line 235 "src/systemadm.vala"
	gtk_paned_pack1 (_tmp99_, (GtkWidget*) _tmp102_, TRUE, TRUE);
#line 235 "src/systemadm.vala"
	_g_object_unref0 (_tmp102_);
#line 237 "src/systemadm.vala"
	_tmp103_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
#line 237 "src/systemadm.vala"
	g_object_ref_sink (_tmp103_);
#line 237 "src/systemadm.vala"
	job_vbox2 = _tmp103_;
#line 238 "src/systemadm.vala"
	_tmp104_ = paned;
#line 238 "src/systemadm.vala"
	_tmp105_ = job_vbox2;
#line 238 "src/systemadm.vala"
	_tmp106_ = new_scrolled_window ((GtkWidget*) _tmp105_);
#line 238 "src/systemadm.vala"
	_tmp107_ = _tmp106_;
#line 238 "src/systemadm.vala"
	gtk_paned_pack2 (_tmp104_, (GtkWidget*) _tmp107_, FALSE, TRUE);
#line 238 "src/systemadm.vala"
	_g_object_unref0 (_tmp107_);
#line 240 "src/systemadm.vala"
	_tmp108_ = right_label_new (NULL);
#line 240 "src/systemadm.vala"
	g_object_ref_sink (_tmp108_);
#line 240 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_id_label);
#line 240 "src/systemadm.vala"
	self->priv->unit_id_label = _tmp108_;
#line 241 "src/systemadm.vala"
	_tmp109_ = right_label_new (NULL);
#line 241 "src/systemadm.vala"
	g_object_ref_sink (_tmp109_);
#line 241 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_dependency_label);
#line 241 "src/systemadm.vala"
	self->priv->unit_dependency_label = _tmp109_;
#line 242 "src/systemadm.vala"
	_tmp110_ = right_label_new (NULL);
#line 242 "src/systemadm.vala"
	g_object_ref_sink (_tmp110_);
#line 242 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_description_label);
#line 242 "src/systemadm.vala"
	self->priv->unit_description_label = _tmp110_;
#line 243 "src/systemadm.vala"
	_tmp111_ = right_label_new (NULL);
#line 243 "src/systemadm.vala"
	g_object_ref_sink (_tmp111_);
#line 243 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_load_state_label);
#line 243 "src/systemadm.vala"
	self->priv->unit_load_state_label = _tmp111_;
#line 244 "src/systemadm.vala"
	_tmp112_ = right_label_new (NULL);
#line 244 "src/systemadm.vala"
	g_object_ref_sink (_tmp112_);
#line 244 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_active_state_label);
#line 244 "src/systemadm.vala"
	self->priv->unit_active_state_label = _tmp112_;
#line 245 "src/systemadm.vala"
	_tmp113_ = right_label_new (NULL);
#line 245 "src/systemadm.vala"
	g_object_ref_sink (_tmp113_);
#line 245 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_sub_state_label);
#line 245 "src/systemadm.vala"
	self->priv->unit_sub_state_label = _tmp113_;
#line 246 "src/systemadm.vala"
	_tmp114_ = right_label_new (NULL);
#line 246 "src/systemadm.vala"
	g_object_ref_sink (_tmp114_);
#line 246 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_fragment_path_label);
#line 246 "src/systemadm.vala"
	self->priv->unit_fragment_path_label = _tmp114_;
#line 247 "src/systemadm.vala"
	_tmp115_ = right_label_new (NULL);
#line 247 "src/systemadm.vala"
	g_object_ref_sink (_tmp115_);
#line 247 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_active_enter_timestamp_label);
#line 247 "src/systemadm.vala"
	self->priv->unit_active_enter_timestamp_label = _tmp115_;
#line 248 "src/systemadm.vala"
	_tmp116_ = right_label_new (NULL);
#line 248 "src/systemadm.vala"
	g_object_ref_sink (_tmp116_);
#line 248 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_active_exit_timestamp_label);
#line 248 "src/systemadm.vala"
	self->priv->unit_active_exit_timestamp_label = _tmp116_;
#line 249 "src/systemadm.vala"
	_tmp117_ = right_label_new (NULL);
#line 249 "src/systemadm.vala"
	g_object_ref_sink (_tmp117_);
#line 249 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_can_start_label);
#line 249 "src/systemadm.vala"
	self->priv->unit_can_start_label = _tmp117_;
#line 250 "src/systemadm.vala"
	_tmp118_ = right_label_new (NULL);
#line 250 "src/systemadm.vala"
	g_object_ref_sink (_tmp118_);
#line 250 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_can_reload_label);
#line 250 "src/systemadm.vala"
	self->priv->unit_can_reload_label = _tmp118_;
#line 251 "src/systemadm.vala"
	_tmp119_ = right_label_new (NULL);
#line 251 "src/systemadm.vala"
	g_object_ref_sink (_tmp119_);
#line 251 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_cgroup_label);
#line 251 "src/systemadm.vala"
	self->priv->unit_cgroup_label = _tmp119_;
#line 253 "src/systemadm.vala"
	_tmp120_ = right_label_new (NULL);
#line 253 "src/systemadm.vala"
	g_object_ref_sink (_tmp120_);
#line 253 "src/systemadm.vala"
	_g_object_unref0 (self->priv->job_id_label);
#line 253 "src/systemadm.vala"
	self->priv->job_id_label = _tmp120_;
#line 254 "src/systemadm.vala"
	_tmp121_ = right_label_new (NULL);
#line 254 "src/systemadm.vala"
	g_object_ref_sink (_tmp121_);
#line 254 "src/systemadm.vala"
	_g_object_unref0 (self->priv->job_state_label);
#line 254 "src/systemadm.vala"
	self->priv->job_state_label = _tmp121_;
#line 255 "src/systemadm.vala"
	_tmp122_ = right_label_new (NULL);
#line 255 "src/systemadm.vala"
	g_object_ref_sink (_tmp122_);
#line 255 "src/systemadm.vala"
	_g_object_unref0 (self->priv->job_type_label);
#line 255 "src/systemadm.vala"
	self->priv->job_type_label = _tmp122_;
#line 257 "src/systemadm.vala"
	_tmp123_ = self->priv->unit_dependency_label;
#line 257 "src/systemadm.vala"
	gtk_label_set_track_visited_links ((GtkLabel*) _tmp123_, FALSE);
#line 258 "src/systemadm.vala"
	_tmp124_ = self->priv->unit_dependency_label;
#line 258 "src/systemadm.vala"
	gtk_label_set_selectable ((GtkLabel*) _tmp124_, TRUE);
#line 259 "src/systemadm.vala"
	_tmp125_ = self->priv->unit_dependency_label;
#line 259 "src/systemadm.vala"
	g_signal_connect_object ((GtkLabel*) _tmp125_, "activate-link", (GCallback) _main_window_on_activate_link_gtk_label_activate_link, self, 0);
#line 261 "src/systemadm.vala"
	_tmp126_ = self->priv->unit_fragment_path_label;
#line 261 "src/systemadm.vala"
	gtk_label_set_track_visited_links ((GtkLabel*) _tmp126_, FALSE);
#line 263 "src/systemadm.vala"
	_tmp127_ = (GtkGrid*) gtk_grid_new ();
#line 263 "src/systemadm.vala"
	g_object_ref_sink (_tmp127_);
#line 263 "src/systemadm.vala"
	unit_grid = _tmp127_;
#line 264 "src/systemadm.vala"
	_tmp128_ = unit_grid;
#line 264 "src/systemadm.vala"
	gtk_grid_set_column_spacing (_tmp128_, 6);
#line 265 "src/systemadm.vala"
	_tmp129_ = unit_grid;
#line 265 "src/systemadm.vala"
	gtk_grid_set_row_spacing (_tmp129_, 6);
#line 266 "src/systemadm.vala"
	_tmp130_ = unit_vbox2;
#line 266 "src/systemadm.vala"
	_tmp131_ = unit_grid;
#line 266 "src/systemadm.vala"
	gtk_box_pack_start (_tmp130_, (GtkWidget*) _tmp131_, FALSE, TRUE, (guint) 0);
#line 268 "src/systemadm.vala"
	_tmp132_ = (GtkGrid*) gtk_grid_new ();
#line 268 "src/systemadm.vala"
	g_object_ref_sink (_tmp132_);
#line 268 "src/systemadm.vala"
	job_grid = _tmp132_;
#line 269 "src/systemadm.vala"
	_tmp133_ = job_grid;
#line 269 "src/systemadm.vala"
	gtk_grid_set_column_spacing (_tmp133_, 6);
#line 270 "src/systemadm.vala"
	_tmp134_ = job_grid;
#line 270 "src/systemadm.vala"
	gtk_grid_set_column_spacing (_tmp134_, 6);
#line 271 "src/systemadm.vala"
	_tmp135_ = job_vbox2;
#line 271 "src/systemadm.vala"
	_tmp136_ = job_grid;
#line 271 "src/systemadm.vala"
	gtk_box_pack_start (_tmp135_, (GtkWidget*) _tmp136_, FALSE, TRUE, (guint) 0);
#line 273 "src/systemadm.vala"
	_tmp137_ = unit_grid;
#line 273 "src/systemadm.vala"
	_tmp138_ = left_label_new ("Id:");
#line 273 "src/systemadm.vala"
	g_object_ref_sink (_tmp138_);
#line 273 "src/systemadm.vala"
	_tmp139_ = _tmp138_;
#line 273 "src/systemadm.vala"
	gtk_grid_attach (_tmp137_, (GtkWidget*) _tmp139_, 0, 0, 1, 1);
#line 273 "src/systemadm.vala"
	_g_object_unref0 (_tmp139_);
#line 274 "src/systemadm.vala"
	_tmp140_ = unit_grid;
#line 274 "src/systemadm.vala"
	_tmp141_ = self->priv->unit_id_label;
#line 274 "src/systemadm.vala"
	gtk_grid_attach (_tmp140_, (GtkWidget*) _tmp141_, 1, 0, 5, 1);
#line 275 "src/systemadm.vala"
	_tmp142_ = unit_grid;
#line 275 "src/systemadm.vala"
	_tmp143_ = left_label_new ("Description:");
#line 275 "src/systemadm.vala"
	g_object_ref_sink (_tmp143_);
#line 275 "src/systemadm.vala"
	_tmp144_ = _tmp143_;
#line 275 "src/systemadm.vala"
	gtk_grid_attach (_tmp142_, (GtkWidget*) _tmp144_, 0, 1, 1, 1);
#line 275 "src/systemadm.vala"
	_g_object_unref0 (_tmp144_);
#line 276 "src/systemadm.vala"
	_tmp145_ = unit_grid;
#line 276 "src/systemadm.vala"
	_tmp146_ = self->priv->unit_description_label;
#line 276 "src/systemadm.vala"
	gtk_grid_attach (_tmp145_, (GtkWidget*) _tmp146_, 1, 1, 5, 1);
#line 277 "src/systemadm.vala"
	_tmp147_ = unit_grid;
#line 277 "src/systemadm.vala"
	_tmp148_ = left_label_new ("Dependencies:");
#line 277 "src/systemadm.vala"
	g_object_ref_sink (_tmp148_);
#line 277 "src/systemadm.vala"
	_tmp149_ = _tmp148_;
#line 277 "src/systemadm.vala"
	gtk_grid_attach (_tmp147_, (GtkWidget*) _tmp149_, 0, 2, 1, 1);
#line 277 "src/systemadm.vala"
	_g_object_unref0 (_tmp149_);
#line 278 "src/systemadm.vala"
	_tmp150_ = unit_grid;
#line 278 "src/systemadm.vala"
	_tmp151_ = self->priv->unit_dependency_label;
#line 278 "src/systemadm.vala"
	gtk_grid_attach (_tmp150_, (GtkWidget*) _tmp151_, 1, 2, 5, 1);
#line 279 "src/systemadm.vala"
	_tmp152_ = unit_grid;
#line 279 "src/systemadm.vala"
	_tmp153_ = left_label_new ("Fragment Path:");
#line 279 "src/systemadm.vala"
	g_object_ref_sink (_tmp153_);
#line 279 "src/systemadm.vala"
	_tmp154_ = _tmp153_;
#line 279 "src/systemadm.vala"
	gtk_grid_attach (_tmp152_, (GtkWidget*) _tmp154_, 0, 3, 1, 1);
#line 279 "src/systemadm.vala"
	_g_object_unref0 (_tmp154_);
#line 280 "src/systemadm.vala"
	_tmp155_ = unit_grid;
#line 280 "src/systemadm.vala"
	_tmp156_ = self->priv->unit_fragment_path_label;
#line 280 "src/systemadm.vala"
	gtk_grid_attach (_tmp155_, (GtkWidget*) _tmp156_, 1, 3, 5, 1);
#line 281 "src/systemadm.vala"
	_tmp157_ = unit_grid;
#line 281 "src/systemadm.vala"
	_tmp158_ = left_label_new ("Control Group:");
#line 281 "src/systemadm.vala"
	g_object_ref_sink (_tmp158_);
#line 281 "src/systemadm.vala"
	_tmp159_ = _tmp158_;
#line 281 "src/systemadm.vala"
	gtk_grid_attach (_tmp157_, (GtkWidget*) _tmp159_, 0, 4, 1, 1);
#line 281 "src/systemadm.vala"
	_g_object_unref0 (_tmp159_);
#line 282 "src/systemadm.vala"
	_tmp160_ = unit_grid;
#line 282 "src/systemadm.vala"
	_tmp161_ = self->priv->unit_cgroup_label;
#line 282 "src/systemadm.vala"
	gtk_grid_attach (_tmp160_, (GtkWidget*) _tmp161_, 1, 4, 5, 1);
#line 283 "src/systemadm.vala"
	_tmp162_ = unit_grid;
#line 283 "src/systemadm.vala"
	_tmp163_ = left_label_new ("Load State:");
#line 283 "src/systemadm.vala"
	g_object_ref_sink (_tmp163_);
#line 283 "src/systemadm.vala"
	_tmp164_ = _tmp163_;
#line 283 "src/systemadm.vala"
	gtk_grid_attach (_tmp162_, (GtkWidget*) _tmp164_, 0, 5, 1, 1);
#line 283 "src/systemadm.vala"
	_g_object_unref0 (_tmp164_);
#line 284 "src/systemadm.vala"
	_tmp165_ = unit_grid;
#line 284 "src/systemadm.vala"
	_tmp166_ = self->priv->unit_load_state_label;
#line 284 "src/systemadm.vala"
	gtk_grid_attach (_tmp165_, (GtkWidget*) _tmp166_, 1, 5, 5, 1);
#line 286 "src/systemadm.vala"
	_tmp167_ = unit_grid;
#line 286 "src/systemadm.vala"
	_tmp168_ = left_label_new ("Active State:");
#line 286 "src/systemadm.vala"
	g_object_ref_sink (_tmp168_);
#line 286 "src/systemadm.vala"
	_tmp169_ = _tmp168_;
#line 286 "src/systemadm.vala"
	gtk_grid_attach (_tmp167_, (GtkWidget*) _tmp169_, 0, 6, 1, 1);
#line 286 "src/systemadm.vala"
	_g_object_unref0 (_tmp169_);
#line 287 "src/systemadm.vala"
	_tmp170_ = unit_grid;
#line 287 "src/systemadm.vala"
	_tmp171_ = self->priv->unit_active_state_label;
#line 287 "src/systemadm.vala"
	gtk_grid_attach (_tmp170_, (GtkWidget*) _tmp171_, 1, 6, 1, 1);
#line 288 "src/systemadm.vala"
	_tmp172_ = unit_grid;
#line 288 "src/systemadm.vala"
	_tmp173_ = left_label_new ("Unit State:");
#line 288 "src/systemadm.vala"
	g_object_ref_sink (_tmp173_);
#line 288 "src/systemadm.vala"
	_tmp174_ = _tmp173_;
#line 288 "src/systemadm.vala"
	gtk_grid_attach (_tmp172_, (GtkWidget*) _tmp174_, 0, 7, 1, 1);
#line 288 "src/systemadm.vala"
	_g_object_unref0 (_tmp174_);
#line 289 "src/systemadm.vala"
	_tmp175_ = unit_grid;
#line 289 "src/systemadm.vala"
	_tmp176_ = self->priv->unit_sub_state_label;
#line 289 "src/systemadm.vala"
	gtk_grid_attach (_tmp175_, (GtkWidget*) _tmp176_, 1, 7, 1, 1);
#line 291 "src/systemadm.vala"
	_tmp177_ = unit_grid;
#line 291 "src/systemadm.vala"
	_tmp178_ = left_label_new ("Activated:");
#line 291 "src/systemadm.vala"
	g_object_ref_sink (_tmp178_);
#line 291 "src/systemadm.vala"
	_tmp179_ = _tmp178_;
#line 291 "src/systemadm.vala"
	gtk_grid_attach (_tmp177_, (GtkWidget*) _tmp179_, 2, 6, 1, 1);
#line 291 "src/systemadm.vala"
	_g_object_unref0 (_tmp179_);
#line 292 "src/systemadm.vala"
	_tmp180_ = unit_grid;
#line 292 "src/systemadm.vala"
	_tmp181_ = self->priv->unit_active_enter_timestamp_label;
#line 292 "src/systemadm.vala"
	gtk_grid_attach (_tmp180_, (GtkWidget*) _tmp181_, 3, 6, 1, 1);
#line 293 "src/systemadm.vala"
	_tmp182_ = unit_grid;
#line 293 "src/systemadm.vala"
	_tmp183_ = left_label_new ("Deactivated:");
#line 293 "src/systemadm.vala"
	g_object_ref_sink (_tmp183_);
#line 293 "src/systemadm.vala"
	_tmp184_ = _tmp183_;
#line 293 "src/systemadm.vala"
	gtk_grid_attach (_tmp182_, (GtkWidget*) _tmp184_, 2, 7, 1, 1);
#line 293 "src/systemadm.vala"
	_g_object_unref0 (_tmp184_);
#line 294 "src/systemadm.vala"
	_tmp185_ = unit_grid;
#line 294 "src/systemadm.vala"
	_tmp186_ = self->priv->unit_active_exit_timestamp_label;
#line 294 "src/systemadm.vala"
	gtk_grid_attach (_tmp185_, (GtkWidget*) _tmp186_, 3, 7, 1, 1);
#line 296 "src/systemadm.vala"
	_tmp187_ = unit_grid;
#line 296 "src/systemadm.vala"
	_tmp188_ = left_label_new ("Can Start/Stop:");
#line 296 "src/systemadm.vala"
	g_object_ref_sink (_tmp188_);
#line 296 "src/systemadm.vala"
	_tmp189_ = _tmp188_;
#line 296 "src/systemadm.vala"
	gtk_grid_attach (_tmp187_, (GtkWidget*) _tmp189_, 4, 6, 1, 1);
#line 296 "src/systemadm.vala"
	_g_object_unref0 (_tmp189_);
#line 297 "src/systemadm.vala"
	_tmp190_ = unit_grid;
#line 297 "src/systemadm.vala"
	_tmp191_ = self->priv->unit_can_start_label;
#line 297 "src/systemadm.vala"
	gtk_grid_attach (_tmp190_, (GtkWidget*) _tmp191_, 5, 6, 1, 1);
#line 298 "src/systemadm.vala"
	_tmp192_ = unit_grid;
#line 298 "src/systemadm.vala"
	_tmp193_ = left_label_new ("Can Reload:");
#line 298 "src/systemadm.vala"
	g_object_ref_sink (_tmp193_);
#line 298 "src/systemadm.vala"
	_tmp194_ = _tmp193_;
#line 298 "src/systemadm.vala"
	gtk_grid_attach (_tmp192_, (GtkWidget*) _tmp194_, 4, 7, 1, 1);
#line 298 "src/systemadm.vala"
	_g_object_unref0 (_tmp194_);
#line 299 "src/systemadm.vala"
	_tmp195_ = unit_grid;
#line 299 "src/systemadm.vala"
	_tmp196_ = self->priv->unit_can_reload_label;
#line 299 "src/systemadm.vala"
	gtk_grid_attach (_tmp195_, (GtkWidget*) _tmp196_, 5, 7, 1, 1);
#line 301 "src/systemadm.vala"
	_tmp197_ = job_grid;
#line 301 "src/systemadm.vala"
	_tmp198_ = left_label_new ("Id:");
#line 301 "src/systemadm.vala"
	g_object_ref_sink (_tmp198_);
#line 301 "src/systemadm.vala"
	_tmp199_ = _tmp198_;
#line 301 "src/systemadm.vala"
	gtk_grid_attach (_tmp197_, (GtkWidget*) _tmp199_, 0, 1, 1, 1);
#line 301 "src/systemadm.vala"
	_g_object_unref0 (_tmp199_);
#line 302 "src/systemadm.vala"
	_tmp200_ = job_grid;
#line 302 "src/systemadm.vala"
	_tmp201_ = self->priv->job_id_label;
#line 302 "src/systemadm.vala"
	gtk_grid_attach (_tmp200_, (GtkWidget*) _tmp201_, 1, 1, 1, 1);
#line 303 "src/systemadm.vala"
	_tmp202_ = job_grid;
#line 303 "src/systemadm.vala"
	_tmp203_ = left_label_new ("State:");
#line 303 "src/systemadm.vala"
	g_object_ref_sink (_tmp203_);
#line 303 "src/systemadm.vala"
	_tmp204_ = _tmp203_;
#line 303 "src/systemadm.vala"
	gtk_grid_attach (_tmp202_, (GtkWidget*) _tmp204_, 0, 2, 1, 1);
#line 303 "src/systemadm.vala"
	_g_object_unref0 (_tmp204_);
#line 304 "src/systemadm.vala"
	_tmp205_ = job_grid;
#line 304 "src/systemadm.vala"
	_tmp206_ = self->priv->job_state_label;
#line 304 "src/systemadm.vala"
	gtk_grid_attach (_tmp205_, (GtkWidget*) _tmp206_, 1, 2, 1, 1);
#line 305 "src/systemadm.vala"
	_tmp207_ = job_grid;
#line 305 "src/systemadm.vala"
	_tmp208_ = left_label_new ("Type:");
#line 305 "src/systemadm.vala"
	g_object_ref_sink (_tmp208_);
#line 305 "src/systemadm.vala"
	_tmp209_ = _tmp208_;
#line 305 "src/systemadm.vala"
	gtk_grid_attach (_tmp207_, (GtkWidget*) _tmp209_, 0, 3, 1, 1);
#line 305 "src/systemadm.vala"
	_g_object_unref0 (_tmp209_);
#line 306 "src/systemadm.vala"
	_tmp210_ = job_grid;
#line 306 "src/systemadm.vala"
	_tmp211_ = self->priv->job_type_label;
#line 306 "src/systemadm.vala"
	gtk_grid_attach (_tmp210_, (GtkWidget*) _tmp211_, 1, 3, 1, 1);
#line 308 "src/systemadm.vala"
	_tmp212_ = (GtkButtonBox*) gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
#line 308 "src/systemadm.vala"
	g_object_ref_sink (_tmp212_);
#line 308 "src/systemadm.vala"
	bbox = _tmp212_;
#line 309 "src/systemadm.vala"
	_tmp213_ = bbox;
#line 309 "src/systemadm.vala"
	gtk_button_box_set_layout (_tmp213_, GTK_BUTTONBOX_START);
#line 310 "src/systemadm.vala"
	_tmp214_ = bbox;
#line 310 "src/systemadm.vala"
	gtk_box_set_spacing ((GtkBox*) _tmp214_, 6);
#line 311 "src/systemadm.vala"
	_tmp215_ = unit_vbox2;
#line 311 "src/systemadm.vala"
	_tmp216_ = bbox;
#line 311 "src/systemadm.vala"
	gtk_box_pack_start (_tmp215_, (GtkWidget*) _tmp216_, FALSE, TRUE, (guint) 0);
#line 313 "src/systemadm.vala"
	_tmp217_ = (GtkButton*) gtk_button_new_with_mnemonic ("_Start");
#line 313 "src/systemadm.vala"
	g_object_ref_sink (_tmp217_);
#line 313 "src/systemadm.vala"
	_g_object_unref0 (self->priv->start_button);
#line 313 "src/systemadm.vala"
	self->priv->start_button = _tmp217_;
#line 314 "src/systemadm.vala"
	_tmp218_ = (GtkButton*) gtk_button_new_with_mnemonic ("Sto_p");
#line 314 "src/systemadm.vala"
	g_object_ref_sink (_tmp218_);
#line 314 "src/systemadm.vala"
	_g_object_unref0 (self->priv->stop_button);
#line 314 "src/systemadm.vala"
	self->priv->stop_button = _tmp218_;
#line 315 "src/systemadm.vala"
	_tmp219_ = (GtkButton*) gtk_button_new_with_mnemonic ("_Reload");
#line 315 "src/systemadm.vala"
	g_object_ref_sink (_tmp219_);
#line 315 "src/systemadm.vala"
	_g_object_unref0 (self->priv->reload_button);
#line 315 "src/systemadm.vala"
	self->priv->reload_button = _tmp219_;
#line 316 "src/systemadm.vala"
	_tmp220_ = (GtkButton*) gtk_button_new_with_mnemonic ("Res_tart");
#line 316 "src/systemadm.vala"
	g_object_ref_sink (_tmp220_);
#line 316 "src/systemadm.vala"
	_g_object_unref0 (self->priv->restart_button);
#line 316 "src/systemadm.vala"
	self->priv->restart_button = _tmp220_;
#line 318 "src/systemadm.vala"
	_tmp221_ = self->priv->start_button;
#line 318 "src/systemadm.vala"
	g_signal_connect_object (_tmp221_, "clicked", (GCallback) _main_window_on_start_gtk_button_clicked, self, 0);
#line 319 "src/systemadm.vala"
	_tmp222_ = self->priv->stop_button;
#line 319 "src/systemadm.vala"
	g_signal_connect_object (_tmp222_, "clicked", (GCallback) _main_window_on_stop_gtk_button_clicked, self, 0);
#line 320 "src/systemadm.vala"
	_tmp223_ = self->priv->reload_button;
#line 320 "src/systemadm.vala"
	g_signal_connect_object (_tmp223_, "clicked", (GCallback) _main_window_on_reload_gtk_button_clicked, self, 0);
#line 321 "src/systemadm.vala"
	_tmp224_ = self->priv->restart_button;
#line 321 "src/systemadm.vala"
	g_signal_connect_object (_tmp224_, "clicked", (GCallback) _main_window_on_restart_gtk_button_clicked, self, 0);
#line 323 "src/systemadm.vala"
	_tmp225_ = bbox;
#line 323 "src/systemadm.vala"
	_tmp226_ = self->priv->start_button;
#line 323 "src/systemadm.vala"
	gtk_box_pack_start ((GtkBox*) _tmp225_, (GtkWidget*) _tmp226_, FALSE, TRUE, (guint) 0);
#line 324 "src/systemadm.vala"
	_tmp227_ = bbox;
#line 324 "src/systemadm.vala"
	_tmp228_ = self->priv->stop_button;
#line 324 "src/systemadm.vala"
	gtk_box_pack_start ((GtkBox*) _tmp227_, (GtkWidget*) _tmp228_, FALSE, TRUE, (guint) 0);
#line 325 "src/systemadm.vala"
	_tmp229_ = bbox;
#line 325 "src/systemadm.vala"
	_tmp230_ = self->priv->restart_button;
#line 325 "src/systemadm.vala"
	gtk_box_pack_start ((GtkBox*) _tmp229_, (GtkWidget*) _tmp230_, FALSE, TRUE, (guint) 0);
#line 326 "src/systemadm.vala"
	_tmp231_ = bbox;
#line 326 "src/systemadm.vala"
	_tmp232_ = self->priv->reload_button;
#line 326 "src/systemadm.vala"
	gtk_box_pack_start ((GtkBox*) _tmp231_, (GtkWidget*) _tmp232_, FALSE, TRUE, (guint) 0);
#line 328 "src/systemadm.vala"
	_tmp233_ = (GtkButtonBox*) gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
#line 328 "src/systemadm.vala"
	g_object_ref_sink (_tmp233_);
#line 328 "src/systemadm.vala"
	_g_object_unref0 (bbox);
#line 328 "src/systemadm.vala"
	bbox = _tmp233_;
#line 329 "src/systemadm.vala"
	_tmp234_ = bbox;
#line 329 "src/systemadm.vala"
	gtk_button_box_set_layout (_tmp234_, GTK_BUTTONBOX_START);
#line 330 "src/systemadm.vala"
	_tmp235_ = bbox;
#line 330 "src/systemadm.vala"
	gtk_box_set_spacing ((GtkBox*) _tmp235_, 6);
#line 331 "src/systemadm.vala"
	_tmp236_ = job_vbox2;
#line 331 "src/systemadm.vala"
	_tmp237_ = bbox;
#line 331 "src/systemadm.vala"
	gtk_box_pack_start (_tmp236_, (GtkWidget*) _tmp237_, FALSE, TRUE, (guint) 0);
#line 333 "src/systemadm.vala"
	_tmp238_ = (GtkButton*) gtk_button_new_with_mnemonic ("_Cancel");
#line 333 "src/systemadm.vala"
	g_object_ref_sink (_tmp238_);
#line 333 "src/systemadm.vala"
	_g_object_unref0 (self->priv->cancel_button);
#line 333 "src/systemadm.vala"
	self->priv->cancel_button = _tmp238_;
#line 335 "src/systemadm.vala"
	_tmp239_ = self->priv->cancel_button;
#line 335 "src/systemadm.vala"
	g_signal_connect_object (_tmp239_, "clicked", (GCallback) _main_window_on_cancel_gtk_button_clicked, self, 0);
#line 337 "src/systemadm.vala"
	_tmp240_ = bbox;
#line 337 "src/systemadm.vala"
	_tmp241_ = self->priv->cancel_button;
#line 337 "src/systemadm.vala"
	gtk_box_pack_start ((GtkBox*) _tmp240_, (GtkWidget*) _tmp241_, FALSE, TRUE, (guint) 0);
#line 340 "src/systemadm.vala"
	if (user) {
#line 340 "src/systemadm.vala"
		_tmp242_ = G_BUS_TYPE_SESSION;
#line 2537 "systemadm.c"
	} else {
#line 340 "src/systemadm.vala"
		_tmp242_ = G_BUS_TYPE_SYSTEM;
#line 2541 "systemadm.c"
	}
#line 339 "src/systemadm.vala"
	_tmp244_ = (Manager*) g_initable_new (TYPE_MANAGER_PROXY, NULL, &_inner_error0_, "g-flags", 0, "g-name", "org.freedesktop.systemd1", "g-bus-type", _tmp242_, "g-object-path", "/org/freedesktop/systemd1", "g-interface-name", "org.freedesktop.systemd1.Manager", NULL);
#line 339 "src/systemadm.vala"
	_tmp243_ = (Manager*) _tmp244_;
#line 339 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 339 "src/systemadm.vala"
		if ((_inner_error0_->domain == G_DBUS_ERROR) || (_inner_error0_->domain == G_IO_ERROR)) {
#line 339 "src/systemadm.vala"
			g_propagate_error (error, _inner_error0_);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (bbox);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (job_grid);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (unit_grid);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (job_vbox2);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (unit_vbox2);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (paned);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (unit_model_sort);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (unit_model_filter);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (unit_load_hbox);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (type_hbox);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (job_vbox);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (unit_vbox);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (notebook);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (self);
#line 339 "src/systemadm.vala"
			return NULL;
#line 2583 "systemadm.c"
		} else {
#line 339 "src/systemadm.vala"
			_g_object_unref0 (bbox);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (job_grid);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (unit_grid);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (job_vbox2);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (unit_vbox2);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (paned);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (unit_model_sort);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (unit_model_filter);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (unit_load_hbox);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (type_hbox);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (job_vbox);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (unit_vbox);
#line 339 "src/systemadm.vala"
			_g_object_unref0 (notebook);
#line 339 "src/systemadm.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 339 "src/systemadm.vala"
			g_clear_error (&_inner_error0_);
#line 339 "src/systemadm.vala"
			return NULL;
#line 2617 "systemadm.c"
		}
	}
#line 339 "src/systemadm.vala"
	_tmp245_ = _tmp243_;
#line 339 "src/systemadm.vala"
	_tmp243_ = NULL;
#line 339 "src/systemadm.vala"
	_g_object_unref0 (self->priv->manager);
#line 339 "src/systemadm.vala"
	self->priv->manager = _tmp245_;
#line 344 "src/systemadm.vala"
	_tmp246_ = self->priv->manager;
#line 344 "src/systemadm.vala"
	g_signal_connect_object (_tmp246_, "unit-new", (GCallback) _main_window_on_unit_new_manager_unit_new, self, 0);
#line 345 "src/systemadm.vala"
	_tmp247_ = self->priv->manager;
#line 345 "src/systemadm.vala"
	g_signal_connect_object (_tmp247_, "job-new", (GCallback) _main_window_on_job_new_manager_job_new, self, 0);
#line 346 "src/systemadm.vala"
	_tmp248_ = self->priv->manager;
#line 346 "src/systemadm.vala"
	g_signal_connect_object (_tmp248_, "unit-removed", (GCallback) _main_window_on_unit_removed_manager_unit_removed, self, 0);
#line 347 "src/systemadm.vala"
	_tmp249_ = self->priv->manager;
#line 347 "src/systemadm.vala"
	g_signal_connect_object (_tmp249_, "job-removed", (GCallback) _main_window_on_job_removed_manager_job_removed, self, 0);
#line 349 "src/systemadm.vala"
	_tmp250_ = self->priv->manager;
#line 349 "src/systemadm.vala"
	manager_subscribe (_tmp250_, &_inner_error0_);
#line 349 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 349 "src/systemadm.vala"
		if ((_inner_error0_->domain == G_DBUS_ERROR) || (_inner_error0_->domain == G_IO_ERROR)) {
#line 349 "src/systemadm.vala"
			g_propagate_error (error, _inner_error0_);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (_tmp243_);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (bbox);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (job_grid);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (unit_grid);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (job_vbox2);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (unit_vbox2);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (paned);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (unit_model_sort);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (unit_model_filter);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (unit_load_hbox);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (type_hbox);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (job_vbox);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (unit_vbox);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (notebook);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (self);
#line 349 "src/systemadm.vala"
			return NULL;
#line 2686 "systemadm.c"
		} else {
#line 349 "src/systemadm.vala"
			_g_object_unref0 (_tmp243_);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (bbox);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (job_grid);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (unit_grid);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (job_vbox2);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (unit_vbox2);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (paned);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (unit_model_sort);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (unit_model_filter);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (unit_load_hbox);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (type_hbox);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (job_vbox);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (unit_vbox);
#line 349 "src/systemadm.vala"
			_g_object_unref0 (notebook);
#line 349 "src/systemadm.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 349 "src/systemadm.vala"
			g_clear_error (&_inner_error0_);
#line 349 "src/systemadm.vala"
			return NULL;
#line 2722 "systemadm.c"
		}
	}
#line 351 "src/systemadm.vala"
	main_window_clear_unit (self);
#line 352 "src/systemadm.vala"
	main_window_clear_job (self);
#line 353 "src/systemadm.vala"
	main_window_populate_unit_model (self, &_inner_error0_);
#line 353 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 353 "src/systemadm.vala"
		if ((_inner_error0_->domain == G_DBUS_ERROR) || (_inner_error0_->domain == G_IO_ERROR)) {
#line 353 "src/systemadm.vala"
			g_propagate_error (error, _inner_error0_);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (_tmp243_);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (bbox);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (job_grid);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (unit_grid);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (job_vbox2);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (unit_vbox2);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (paned);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (unit_model_sort);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (unit_model_filter);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (unit_load_hbox);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (type_hbox);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (job_vbox);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (unit_vbox);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (notebook);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (self);
#line 353 "src/systemadm.vala"
			return NULL;
#line 2769 "systemadm.c"
		} else {
#line 353 "src/systemadm.vala"
			_g_object_unref0 (_tmp243_);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (bbox);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (job_grid);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (unit_grid);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (job_vbox2);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (unit_vbox2);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (paned);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (unit_model_sort);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (unit_model_filter);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (unit_load_hbox);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (type_hbox);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (job_vbox);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (unit_vbox);
#line 353 "src/systemadm.vala"
			_g_object_unref0 (notebook);
#line 353 "src/systemadm.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 353 "src/systemadm.vala"
			g_clear_error (&_inner_error0_);
#line 353 "src/systemadm.vala"
			return NULL;
#line 2805 "systemadm.c"
		}
	}
#line 354 "src/systemadm.vala"
	main_window_populate_job_model (self, &_inner_error0_);
#line 354 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 354 "src/systemadm.vala"
		if ((_inner_error0_->domain == G_DBUS_ERROR) || (_inner_error0_->domain == G_IO_ERROR)) {
#line 354 "src/systemadm.vala"
			g_propagate_error (error, _inner_error0_);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (_tmp243_);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (bbox);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (job_grid);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (unit_grid);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (job_vbox2);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (unit_vbox2);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (paned);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (unit_model_sort);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (unit_model_filter);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (unit_load_hbox);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (type_hbox);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (job_vbox);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (unit_vbox);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (notebook);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (self);
#line 354 "src/systemadm.vala"
			return NULL;
#line 2848 "systemadm.c"
		} else {
#line 354 "src/systemadm.vala"
			_g_object_unref0 (_tmp243_);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (bbox);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (job_grid);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (unit_grid);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (job_vbox2);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (unit_vbox2);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (paned);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (unit_model_sort);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (unit_model_filter);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (unit_load_hbox);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (type_hbox);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (job_vbox);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (unit_vbox);
#line 354 "src/systemadm.vala"
			_g_object_unref0 (notebook);
#line 354 "src/systemadm.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 354 "src/systemadm.vala"
			g_clear_error (&_inner_error0_);
#line 354 "src/systemadm.vala"
			return NULL;
#line 2884 "systemadm.c"
		}
	}
#line 131 "src/systemadm.vala"
	_g_object_unref0 (_tmp243_);
#line 131 "src/systemadm.vala"
	_g_object_unref0 (bbox);
#line 131 "src/systemadm.vala"
	_g_object_unref0 (job_grid);
#line 131 "src/systemadm.vala"
	_g_object_unref0 (unit_grid);
#line 131 "src/systemadm.vala"
	_g_object_unref0 (job_vbox2);
#line 131 "src/systemadm.vala"
	_g_object_unref0 (unit_vbox2);
#line 131 "src/systemadm.vala"
	_g_object_unref0 (paned);
#line 131 "src/systemadm.vala"
	_g_object_unref0 (unit_model_sort);
#line 131 "src/systemadm.vala"
	_g_object_unref0 (unit_model_filter);
#line 131 "src/systemadm.vala"
	_g_object_unref0 (unit_load_hbox);
#line 131 "src/systemadm.vala"
	_g_object_unref0 (type_hbox);
#line 131 "src/systemadm.vala"
	_g_object_unref0 (job_vbox);
#line 131 "src/systemadm.vala"
	_g_object_unref0 (unit_vbox);
#line 131 "src/systemadm.vala"
	_g_object_unref0 (notebook);
#line 131 "src/systemadm.vala"
	return self;
#line 2917 "systemadm.c"
}

MainWindow*
main_window_new (GError** error)
{
#line 131 "src/systemadm.vala"
	return main_window_construct (TYPE_MAIN_WINDOW, error);
#line 2925 "systemadm.c"
}

static void
_vala_ManagerUnitInfo_array_free (ManagerUnitInfo * array,
                                  gssize array_length)
{
#line 365 "src/systemadm.vala"
	if (array != NULL) {
#line 2934 "systemadm.c"
		gssize i;
#line 365 "src/systemadm.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 365 "src/systemadm.vala"
			manager_unit_info_destroy (&array[i]);
#line 2940 "systemadm.c"
		}
	}
#line 365 "src/systemadm.vala"
	g_free (array);
#line 2945 "systemadm.c"
}

static void
_main_window_on_unit_changed_properties_properties_changed (Properties* _sender,
                                                            const gchar* iface,
                                                            GHashTable* changed_properties,
                                                            gchar** invalidated_properties,
                                                            gint invalidated_properties_length1,
                                                            gpointer self)
{
#line 370 "src/systemadm.vala"
	main_window_on_unit_changed ((MainWindow*) self, _sender, iface, changed_properties, invalidated_properties, invalidated_properties_length1);
#line 2958 "systemadm.c"
}

void
main_window_populate_unit_model (MainWindow* self,
                                 GError** error)
{
	GtkListStore* _tmp0_;
	ManagerUnitInfo* list = NULL;
	Manager* _tmp1_;
	gint _tmp2_ = 0;
	ManagerUnitInfo* _tmp3_;
	gint list_length1;
	gint _list_size_;
	ManagerUnitInfo* _tmp4_;
	gint _tmp4__length1;
	GError* _inner_error0_ = NULL;
#line 357 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 358 "src/systemadm.vala"
	_tmp0_ = self->priv->unit_model;
#line 358 "src/systemadm.vala"
	gtk_list_store_clear (_tmp0_);
#line 360 "src/systemadm.vala"
	_tmp1_ = self->priv->manager;
#line 360 "src/systemadm.vala"
	_tmp3_ = manager_list_units (_tmp1_, &_tmp2_, &_inner_error0_);
#line 360 "src/systemadm.vala"
	list = _tmp3_;
#line 360 "src/systemadm.vala"
	list_length1 = _tmp2_;
#line 360 "src/systemadm.vala"
	_list_size_ = list_length1;
#line 360 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 360 "src/systemadm.vala"
		if ((_inner_error0_->domain == G_DBUS_ERROR) || (_inner_error0_->domain == G_IO_ERROR)) {
#line 360 "src/systemadm.vala"
			g_propagate_error (error, _inner_error0_);
#line 360 "src/systemadm.vala"
			return;
#line 2999 "systemadm.c"
		} else {
#line 360 "src/systemadm.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 360 "src/systemadm.vala"
			g_clear_error (&_inner_error0_);
#line 360 "src/systemadm.vala"
			return;
#line 3007 "systemadm.c"
		}
	}
#line 362 "src/systemadm.vala"
	_tmp4_ = list;
#line 362 "src/systemadm.vala"
	_tmp4__length1 = list_length1;
#line 3014 "systemadm.c"
	{
		ManagerUnitInfo* i_collection = NULL;
		gint i_collection_length1 = 0;
		gint _i_collection_size_ = 0;
		gint i_it = 0;
#line 362 "src/systemadm.vala"
		i_collection = _tmp4_;
#line 362 "src/systemadm.vala"
		i_collection_length1 = _tmp4__length1;
#line 362 "src/systemadm.vala"
		for (i_it = 0; i_it < i_collection_length1; i_it = i_it + 1) {
#line 3026 "systemadm.c"
			ManagerUnitInfo _tmp5_;
			ManagerUnitInfo _tmp6_ = {0};
			ManagerUnitInfo i = {0};
#line 362 "src/systemadm.vala"
			_tmp5_ = i_collection[i_it];
#line 362 "src/systemadm.vala"
			manager_unit_info_copy (&_tmp5_, &_tmp6_);
#line 362 "src/systemadm.vala"
			i = _tmp6_;
#line 3036 "systemadm.c"
			{
				GtkTreeIter iter = {0};
				GBusType _tmp7_ = 0;
				Properties* p = NULL;
				ManagerUnitInfo _tmp8_;
				const char* _tmp9_;
				Properties* _tmp10_;
				Properties* _tmp11_;
				GBusType _tmp12_ = 0;
				Unit* u = NULL;
				ManagerUnitInfo _tmp13_;
				const char* _tmp14_;
				Unit* _tmp15_;
				GeeHashMap* _tmp16_;
				ManagerUnitInfo _tmp17_;
				const gchar* _tmp18_;
				Unit* _tmp19_;
				GtkListStore* _tmp20_;
				GtkTreeIter _tmp21_ = {0};
				gchar* _tmp22_ = NULL;
				ManagerUnitInfo _tmp23_;
				const gchar* _tmp24_;
				GtkListStore* _tmp29_;
				GtkTreeIter _tmp30_;
				ManagerUnitInfo _tmp31_;
				const gchar* _tmp32_;
				ManagerUnitInfo _tmp33_;
				const gchar* _tmp34_;
				ManagerUnitInfo _tmp35_;
				const gchar* _tmp36_;
				ManagerUnitInfo _tmp37_;
				const gchar* _tmp38_;
				ManagerUnitInfo _tmp39_;
				const gchar* _tmp40_;
				Unit* _tmp41_;
#line 366 "src/systemadm.vala"
				if (user) {
#line 366 "src/systemadm.vala"
					_tmp7_ = G_BUS_TYPE_SESSION;
#line 3076 "systemadm.c"
				} else {
#line 366 "src/systemadm.vala"
					_tmp7_ = G_BUS_TYPE_SYSTEM;
#line 3080 "systemadm.c"
				}
#line 365 "src/systemadm.vala"
				_tmp8_ = i;
#line 365 "src/systemadm.vala"
				_tmp9_ = _tmp8_.unit_path;
#line 365 "src/systemadm.vala"
				_tmp10_ = (Properties*) g_initable_new (TYPE_PROPERTIES_PROXY, NULL, &_inner_error0_, "g-flags", 0, "g-name", "org.freedesktop.systemd1", "g-bus-type", _tmp7_, "g-object-path", (const gchar*) _tmp9_, "g-interface-name", "org.freedesktop.Properties", NULL);
#line 365 "src/systemadm.vala"
				p = (Properties*) _tmp10_;
#line 365 "src/systemadm.vala"
				if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 365 "src/systemadm.vala"
					if ((_inner_error0_->domain == G_DBUS_ERROR) || (_inner_error0_->domain == G_IO_ERROR)) {
#line 365 "src/systemadm.vala"
						g_propagate_error (error, _inner_error0_);
#line 365 "src/systemadm.vala"
						manager_unit_info_destroy (&i);
#line 365 "src/systemadm.vala"
						list = (_vala_ManagerUnitInfo_array_free (list, list_length1), NULL);
#line 365 "src/systemadm.vala"
						return;
#line 3102 "systemadm.c"
					} else {
#line 365 "src/systemadm.vala"
						manager_unit_info_destroy (&i);
#line 365 "src/systemadm.vala"
						list = (_vala_ManagerUnitInfo_array_free (list, list_length1), NULL);
#line 365 "src/systemadm.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 365 "src/systemadm.vala"
						g_clear_error (&_inner_error0_);
#line 365 "src/systemadm.vala"
						return;
#line 3114 "systemadm.c"
					}
				}
#line 370 "src/systemadm.vala"
				_tmp11_ = p;
#line 370 "src/systemadm.vala"
				g_signal_connect_object (_tmp11_, "properties-changed", (GCallback) _main_window_on_unit_changed_properties_properties_changed, self, 0);
#line 373 "src/systemadm.vala"
				if (user) {
#line 373 "src/systemadm.vala"
					_tmp12_ = G_BUS_TYPE_SESSION;
#line 3125 "systemadm.c"
				} else {
#line 373 "src/systemadm.vala"
					_tmp12_ = G_BUS_TYPE_SYSTEM;
#line 3129 "systemadm.c"
				}
#line 372 "src/systemadm.vala"
				_tmp13_ = i;
#line 372 "src/systemadm.vala"
				_tmp14_ = _tmp13_.unit_path;
#line 372 "src/systemadm.vala"
				_tmp15_ = (Unit*) g_initable_new (TYPE_UNIT_PROXY, NULL, &_inner_error0_, "g-flags", 0, "g-name", "org.freedesktop.systemd1", "g-bus-type", _tmp12_, "g-object-path", (const gchar*) _tmp14_, "g-interface-name", "org.freedesktop.systemd1.Unit", NULL);
#line 372 "src/systemadm.vala"
				u = (Unit*) _tmp15_;
#line 372 "src/systemadm.vala"
				if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 372 "src/systemadm.vala"
					if ((_inner_error0_->domain == G_DBUS_ERROR) || (_inner_error0_->domain == G_IO_ERROR)) {
#line 372 "src/systemadm.vala"
						g_propagate_error (error, _inner_error0_);
#line 372 "src/systemadm.vala"
						_g_object_unref0 (p);
#line 372 "src/systemadm.vala"
						manager_unit_info_destroy (&i);
#line 372 "src/systemadm.vala"
						list = (_vala_ManagerUnitInfo_array_free (list, list_length1), NULL);
#line 372 "src/systemadm.vala"
						return;
#line 3153 "systemadm.c"
					} else {
#line 372 "src/systemadm.vala"
						_g_object_unref0 (p);
#line 372 "src/systemadm.vala"
						manager_unit_info_destroy (&i);
#line 372 "src/systemadm.vala"
						list = (_vala_ManagerUnitInfo_array_free (list, list_length1), NULL);
#line 372 "src/systemadm.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 372 "src/systemadm.vala"
						g_clear_error (&_inner_error0_);
#line 372 "src/systemadm.vala"
						return;
#line 3167 "systemadm.c"
					}
				}
#line 377 "src/systemadm.vala"
				_tmp16_ = self->priv->unit_map;
#line 377 "src/systemadm.vala"
				_tmp17_ = i;
#line 377 "src/systemadm.vala"
				_tmp18_ = _tmp17_.id;
#line 377 "src/systemadm.vala"
				_tmp19_ = u;
#line 377 "src/systemadm.vala"
				gee_abstract_map_set ((GeeAbstractMap*) _tmp16_, _tmp18_, _tmp19_);
#line 379 "src/systemadm.vala"
				_tmp20_ = self->priv->unit_model;
#line 379 "src/systemadm.vala"
				gtk_list_store_append (_tmp20_, &_tmp21_);
#line 379 "src/systemadm.vala"
				iter = _tmp21_;
#line 386 "src/systemadm.vala"
				_tmp23_ = i;
#line 386 "src/systemadm.vala"
				_tmp24_ = _tmp23_.job_type;
#line 386 "src/systemadm.vala"
				if (g_strcmp0 (_tmp24_, "") != 0) {
#line 3192 "systemadm.c"
					ManagerUnitInfo _tmp25_;
					const gchar* _tmp26_;
					gchar* _tmp27_;
#line 386 "src/systemadm.vala"
					_tmp25_ = i;
#line 386 "src/systemadm.vala"
					_tmp26_ = _tmp25_.job_type;
#line 386 "src/systemadm.vala"
					_tmp27_ = g_strdup_printf ("→ %s", _tmp26_);
#line 386 "src/systemadm.vala"
					_g_free0 (_tmp22_);
#line 386 "src/systemadm.vala"
					_tmp22_ = _tmp27_;
#line 3206 "systemadm.c"
				} else {
					gchar* _tmp28_;
#line 386 "src/systemadm.vala"
					_tmp28_ = g_strdup ("");
#line 386 "src/systemadm.vala"
					_g_free0 (_tmp22_);
#line 386 "src/systemadm.vala"
					_tmp22_ = _tmp28_;
#line 3215 "systemadm.c"
				}
#line 380 "src/systemadm.vala"
				_tmp29_ = self->priv->unit_model;
#line 380 "src/systemadm.vala"
				_tmp30_ = iter;
#line 380 "src/systemadm.vala"
				_tmp31_ = i;
#line 380 "src/systemadm.vala"
				_tmp32_ = _tmp31_.id;
#line 380 "src/systemadm.vala"
				_tmp33_ = i;
#line 380 "src/systemadm.vala"
				_tmp34_ = _tmp33_.description;
#line 380 "src/systemadm.vala"
				_tmp35_ = i;
#line 380 "src/systemadm.vala"
				_tmp36_ = _tmp35_.load_state;
#line 380 "src/systemadm.vala"
				_tmp37_ = i;
#line 380 "src/systemadm.vala"
				_tmp38_ = _tmp37_.active_state;
#line 380 "src/systemadm.vala"
				_tmp39_ = i;
#line 380 "src/systemadm.vala"
				_tmp40_ = _tmp39_.sub_state;
#line 380 "src/systemadm.vala"
				_tmp41_ = u;
#line 380 "src/systemadm.vala"
				gtk_list_store_set (_tmp29_, &_tmp30_, 0, _tmp32_, 1, _tmp34_, 2, _tmp36_, 3, _tmp38_, 4, _tmp40_, 5, _tmp22_, 6, _tmp41_, -1);
#line 362 "src/systemadm.vala"
				_g_free0 (_tmp22_);
#line 362 "src/systemadm.vala"
				_g_object_unref0 (u);
#line 362 "src/systemadm.vala"
				_g_object_unref0 (p);
#line 362 "src/systemadm.vala"
				manager_unit_info_destroy (&i);
#line 3253 "systemadm.c"
			}
		}
	}
#line 357 "src/systemadm.vala"
	list = (_vala_ManagerUnitInfo_array_free (list, list_length1), NULL);
#line 3259 "systemadm.c"
}

static void
_vala_ManagerJobInfo_array_free (ManagerJobInfo * array,
                                 gssize array_length)
{
#line 399 "src/systemadm.vala"
	if (array != NULL) {
#line 3268 "systemadm.c"
		gssize i;
#line 399 "src/systemadm.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 399 "src/systemadm.vala"
			manager_job_info_destroy (&array[i]);
#line 3274 "systemadm.c"
		}
	}
#line 399 "src/systemadm.vala"
	g_free (array);
#line 3279 "systemadm.c"
}

static void
_main_window_on_job_changed_properties_properties_changed (Properties* _sender,
                                                           const gchar* iface,
                                                           GHashTable* changed_properties,
                                                           gchar** invalidated_properties,
                                                           gint invalidated_properties_length1,
                                                           gpointer self)
{
#line 404 "src/systemadm.vala"
	main_window_on_job_changed ((MainWindow*) self, _sender, iface, changed_properties, invalidated_properties, invalidated_properties_length1);
#line 3292 "systemadm.c"
}

void
main_window_populate_job_model (MainWindow* self,
                                GError** error)
{
	GtkListStore* _tmp0_;
	ManagerJobInfo* list = NULL;
	Manager* _tmp1_;
	gint _tmp2_ = 0;
	ManagerJobInfo* _tmp3_;
	gint list_length1;
	gint _list_size_;
	ManagerJobInfo* _tmp4_;
	gint _tmp4__length1;
	GError* _inner_error0_ = NULL;
#line 391 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 392 "src/systemadm.vala"
	_tmp0_ = self->priv->job_model;
#line 392 "src/systemadm.vala"
	gtk_list_store_clear (_tmp0_);
#line 394 "src/systemadm.vala"
	_tmp1_ = self->priv->manager;
#line 394 "src/systemadm.vala"
	_tmp3_ = manager_list_jobs (_tmp1_, &_tmp2_, &_inner_error0_);
#line 394 "src/systemadm.vala"
	list = _tmp3_;
#line 394 "src/systemadm.vala"
	list_length1 = _tmp2_;
#line 394 "src/systemadm.vala"
	_list_size_ = list_length1;
#line 394 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 394 "src/systemadm.vala"
		if ((_inner_error0_->domain == G_DBUS_ERROR) || (_inner_error0_->domain == G_IO_ERROR)) {
#line 394 "src/systemadm.vala"
			g_propagate_error (error, _inner_error0_);
#line 394 "src/systemadm.vala"
			return;
#line 3333 "systemadm.c"
		} else {
#line 394 "src/systemadm.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 394 "src/systemadm.vala"
			g_clear_error (&_inner_error0_);
#line 394 "src/systemadm.vala"
			return;
#line 3341 "systemadm.c"
		}
	}
#line 396 "src/systemadm.vala"
	_tmp4_ = list;
#line 396 "src/systemadm.vala"
	_tmp4__length1 = list_length1;
#line 3348 "systemadm.c"
	{
		ManagerJobInfo* i_collection = NULL;
		gint i_collection_length1 = 0;
		gint _i_collection_size_ = 0;
		gint i_it = 0;
#line 396 "src/systemadm.vala"
		i_collection = _tmp4_;
#line 396 "src/systemadm.vala"
		i_collection_length1 = _tmp4__length1;
#line 396 "src/systemadm.vala"
		for (i_it = 0; i_it < i_collection_length1; i_it = i_it + 1) {
#line 3360 "systemadm.c"
			ManagerJobInfo _tmp5_;
			ManagerJobInfo _tmp6_ = {0};
			ManagerJobInfo i = {0};
#line 396 "src/systemadm.vala"
			_tmp5_ = i_collection[i_it];
#line 396 "src/systemadm.vala"
			manager_job_info_copy (&_tmp5_, &_tmp6_);
#line 396 "src/systemadm.vala"
			i = _tmp6_;
#line 3370 "systemadm.c"
			{
				GtkTreeIter iter = {0};
				GBusType _tmp7_ = 0;
				Properties* p = NULL;
				ManagerJobInfo _tmp8_;
				const char* _tmp9_;
				Properties* _tmp10_;
				Properties* _tmp11_;
				GBusType _tmp12_ = 0;
				Job* j = NULL;
				ManagerJobInfo _tmp13_;
				const char* _tmp14_;
				Job* _tmp15_;
				GtkListStore* _tmp16_;
				GtkTreeIter _tmp17_ = {0};
				GtkListStore* _tmp18_;
				GtkTreeIter _tmp19_;
				ManagerJobInfo _tmp20_;
				gchar* _tmp21_;
				gchar* _tmp22_;
				ManagerJobInfo _tmp23_;
				const gchar* _tmp24_;
				ManagerJobInfo _tmp25_;
				const gchar* _tmp26_;
				gchar* _tmp27_;
				gchar* _tmp28_;
				ManagerJobInfo _tmp29_;
				const gchar* _tmp30_;
				Job* _tmp31_;
				ManagerJobInfo _tmp32_;
#line 400 "src/systemadm.vala"
				if (user) {
#line 400 "src/systemadm.vala"
					_tmp7_ = G_BUS_TYPE_SESSION;
#line 3405 "systemadm.c"
				} else {
#line 400 "src/systemadm.vala"
					_tmp7_ = G_BUS_TYPE_SYSTEM;
#line 3409 "systemadm.c"
				}
#line 399 "src/systemadm.vala"
				_tmp8_ = i;
#line 399 "src/systemadm.vala"
				_tmp9_ = _tmp8_.job_path;
#line 399 "src/systemadm.vala"
				_tmp10_ = (Properties*) g_initable_new (TYPE_PROPERTIES_PROXY, NULL, &_inner_error0_, "g-flags", 0, "g-name", "org.freedesktop.systemd1", "g-bus-type", _tmp7_, "g-object-path", (const gchar*) _tmp9_, "g-interface-name", "org.freedesktop.Properties", NULL);
#line 399 "src/systemadm.vala"
				p = (Properties*) _tmp10_;
#line 399 "src/systemadm.vala"
				if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 399 "src/systemadm.vala"
					if ((_inner_error0_->domain == G_DBUS_ERROR) || (_inner_error0_->domain == G_IO_ERROR)) {
#line 399 "src/systemadm.vala"
						g_propagate_error (error, _inner_error0_);
#line 399 "src/systemadm.vala"
						manager_job_info_destroy (&i);
#line 399 "src/systemadm.vala"
						list = (_vala_ManagerJobInfo_array_free (list, list_length1), NULL);
#line 399 "src/systemadm.vala"
						return;
#line 3431 "systemadm.c"
					} else {
#line 399 "src/systemadm.vala"
						manager_job_info_destroy (&i);
#line 399 "src/systemadm.vala"
						list = (_vala_ManagerJobInfo_array_free (list, list_length1), NULL);
#line 399 "src/systemadm.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 399 "src/systemadm.vala"
						g_clear_error (&_inner_error0_);
#line 399 "src/systemadm.vala"
						return;
#line 3443 "systemadm.c"
					}
				}
#line 404 "src/systemadm.vala"
				_tmp11_ = p;
#line 404 "src/systemadm.vala"
				g_signal_connect_object (_tmp11_, "properties-changed", (GCallback) _main_window_on_job_changed_properties_properties_changed, self, 0);
#line 407 "src/systemadm.vala"
				if (user) {
#line 407 "src/systemadm.vala"
					_tmp12_ = G_BUS_TYPE_SESSION;
#line 3454 "systemadm.c"
				} else {
#line 407 "src/systemadm.vala"
					_tmp12_ = G_BUS_TYPE_SYSTEM;
#line 3458 "systemadm.c"
				}
#line 406 "src/systemadm.vala"
				_tmp13_ = i;
#line 406 "src/systemadm.vala"
				_tmp14_ = _tmp13_.job_path;
#line 406 "src/systemadm.vala"
				_tmp15_ = (Job*) g_initable_new (TYPE_JOB_PROXY, NULL, &_inner_error0_, "g-flags", 0, "g-name", "org.freedesktop.systemd1", "g-bus-type", _tmp12_, "g-object-path", (const gchar*) _tmp14_, "g-interface-name", "org.freedesktop.systemd1.Job", NULL);
#line 406 "src/systemadm.vala"
				j = (Job*) _tmp15_;
#line 406 "src/systemadm.vala"
				if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 406 "src/systemadm.vala"
					if ((_inner_error0_->domain == G_DBUS_ERROR) || (_inner_error0_->domain == G_IO_ERROR)) {
#line 406 "src/systemadm.vala"
						g_propagate_error (error, _inner_error0_);
#line 406 "src/systemadm.vala"
						_g_object_unref0 (p);
#line 406 "src/systemadm.vala"
						manager_job_info_destroy (&i);
#line 406 "src/systemadm.vala"
						list = (_vala_ManagerJobInfo_array_free (list, list_length1), NULL);
#line 406 "src/systemadm.vala"
						return;
#line 3482 "systemadm.c"
					} else {
#line 406 "src/systemadm.vala"
						_g_object_unref0 (p);
#line 406 "src/systemadm.vala"
						manager_job_info_destroy (&i);
#line 406 "src/systemadm.vala"
						list = (_vala_ManagerJobInfo_array_free (list, list_length1), NULL);
#line 406 "src/systemadm.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 406 "src/systemadm.vala"
						g_clear_error (&_inner_error0_);
#line 406 "src/systemadm.vala"
						return;
#line 3496 "systemadm.c"
					}
				}
#line 411 "src/systemadm.vala"
				_tmp16_ = self->priv->job_model;
#line 411 "src/systemadm.vala"
				gtk_list_store_append (_tmp16_, &_tmp17_);
#line 411 "src/systemadm.vala"
				iter = _tmp17_;
#line 412 "src/systemadm.vala"
				_tmp18_ = self->priv->job_model;
#line 412 "src/systemadm.vala"
				_tmp19_ = iter;
#line 412 "src/systemadm.vala"
				_tmp20_ = i;
#line 412 "src/systemadm.vala"
				_tmp21_ = g_strdup_printf ("%u", (guint) _tmp20_.id);
#line 412 "src/systemadm.vala"
				_tmp22_ = _tmp21_;
#line 412 "src/systemadm.vala"
				_tmp23_ = i;
#line 412 "src/systemadm.vala"
				_tmp24_ = _tmp23_.name;
#line 412 "src/systemadm.vala"
				_tmp25_ = i;
#line 412 "src/systemadm.vala"
				_tmp26_ = _tmp25_.type;
#line 412 "src/systemadm.vala"
				_tmp27_ = g_strdup_printf ("→ %s", _tmp26_);
#line 412 "src/systemadm.vala"
				_tmp28_ = _tmp27_;
#line 412 "src/systemadm.vala"
				_tmp29_ = i;
#line 412 "src/systemadm.vala"
				_tmp30_ = _tmp29_.state;
#line 412 "src/systemadm.vala"
				_tmp31_ = j;
#line 412 "src/systemadm.vala"
				_tmp32_ = i;
#line 412 "src/systemadm.vala"
				gtk_list_store_set (_tmp18_, &_tmp19_, 0, _tmp22_, 1, _tmp24_, 2, _tmp28_, 3, _tmp30_, 4, _tmp31_, 5, _tmp32_.id, -1);
#line 412 "src/systemadm.vala"
				_g_free0 (_tmp28_);
#line 412 "src/systemadm.vala"
				_g_free0 (_tmp22_);
#line 396 "src/systemadm.vala"
				_g_object_unref0 (j);
#line 396 "src/systemadm.vala"
				_g_object_unref0 (p);
#line 396 "src/systemadm.vala"
				manager_job_info_destroy (&i);
#line 3547 "systemadm.c"
			}
		}
	}
#line 391 "src/systemadm.vala"
	list = (_vala_ManagerJobInfo_array_free (list, list_length1), NULL);
#line 3553 "systemadm.c"
}

static void
_vala_GtkTreePath_free (GtkTreePath* self)
{
#line 424 "src/systemadm.vala"
	g_boxed_free (gtk_tree_path_get_type (), self);
#line 3561 "systemadm.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 429 "src/systemadm.vala"
	return self ? g_object_ref (self) : NULL;
#line 3569 "systemadm.c"
}

Unit*
main_window_get_current_unit (MainWindow* self)
{
	GtkTreePath* p = NULL;
	GtkTreeView* _tmp0_;
	GtkTreePath* _tmp1_ = NULL;
	GtkTreePath* _tmp2_;
	GtkTreeModel* model = NULL;
	GtkTreeView* _tmp3_;
	GtkTreeModel* _tmp4_;
	GtkTreeModel* _tmp5_;
	GtkTreeIter iter = {0};
	Unit* u = NULL;
	GtkTreeModel* _tmp6_;
	GtkTreePath* _tmp7_;
	GtkTreeIter _tmp8_ = {0};
	GtkTreeModel* _tmp9_;
	GtkTreeIter _tmp10_;
	Unit* _tmp11_ = NULL;
	Unit* result;
#line 422 "src/systemadm.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 424 "src/systemadm.vala"
	_tmp0_ = self->priv->unit_view;
#line 424 "src/systemadm.vala"
	gtk_tree_view_get_cursor (_tmp0_, &_tmp1_, NULL);
#line 424 "src/systemadm.vala"
	__vala_GtkTreePath_free0 (p);
#line 424 "src/systemadm.vala"
	p = _tmp1_;
#line 426 "src/systemadm.vala"
	_tmp2_ = p;
#line 426 "src/systemadm.vala"
	if (_tmp2_ == NULL) {
#line 427 "src/systemadm.vala"
		result = NULL;
#line 427 "src/systemadm.vala"
		__vala_GtkTreePath_free0 (p);
#line 427 "src/systemadm.vala"
		return result;
#line 3612 "systemadm.c"
	}
#line 429 "src/systemadm.vala"
	_tmp3_ = self->priv->unit_view;
#line 429 "src/systemadm.vala"
	_tmp4_ = gtk_tree_view_get_model (_tmp3_);
#line 429 "src/systemadm.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 429 "src/systemadm.vala"
	model = _tmp5_;
#line 433 "src/systemadm.vala"
	_tmp6_ = model;
#line 433 "src/systemadm.vala"
	_tmp7_ = p;
#line 433 "src/systemadm.vala"
	gtk_tree_model_get_iter (_tmp6_, &_tmp8_, _tmp7_);
#line 433 "src/systemadm.vala"
	iter = _tmp8_;
#line 434 "src/systemadm.vala"
	_tmp9_ = model;
#line 434 "src/systemadm.vala"
	_tmp10_ = iter;
#line 434 "src/systemadm.vala"
	gtk_tree_model_get (_tmp9_, &_tmp10_, 6, &_tmp11_, -1);
#line 434 "src/systemadm.vala"
	_g_object_unref0 (u);
#line 434 "src/systemadm.vala"
	u = _tmp11_;
#line 436 "src/systemadm.vala"
	result = u;
#line 436 "src/systemadm.vala"
	_g_object_unref0 (model);
#line 436 "src/systemadm.vala"
	__vala_GtkTreePath_free0 (p);
#line 436 "src/systemadm.vala"
	return result;
#line 3648 "systemadm.c"
}

Unit*
main_window_get_unit (MainWindow* self,
                      const gchar* id)
{
	GeeHashMap* _tmp0_;
	gpointer _tmp1_;
	Unit* result;
#line 439 "src/systemadm.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 439 "src/systemadm.vala"
	g_return_val_if_fail (id != NULL, NULL);
#line 440 "src/systemadm.vala"
	_tmp0_ = self->priv->unit_map;
#line 440 "src/systemadm.vala"
	_tmp1_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp0_, id);
#line 440 "src/systemadm.vala"
	result = (Unit*) _tmp1_;
#line 440 "src/systemadm.vala"
	return result;
#line 3670 "systemadm.c"
}

void
main_window_unit_changed (MainWindow* self)
{
	Unit* u = NULL;
	Unit* _tmp0_;
	Unit* _tmp1_;
#line 443 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 444 "src/systemadm.vala"
	_tmp0_ = main_window_get_current_unit (self);
#line 444 "src/systemadm.vala"
	u = _tmp0_;
#line 446 "src/systemadm.vala"
	_tmp1_ = u;
#line 446 "src/systemadm.vala"
	if (_tmp1_ == NULL) {
#line 447 "src/systemadm.vala"
		main_window_clear_unit (self);
#line 3691 "systemadm.c"
	} else {
		Unit* _tmp2_;
#line 449 "src/systemadm.vala"
		_tmp2_ = u;
#line 449 "src/systemadm.vala"
		main_window_show_unit (self, _tmp2_);
#line 3698 "systemadm.c"
	}
#line 443 "src/systemadm.vala"
	_g_object_unref0 (u);
#line 3702 "systemadm.c"
}

void
main_window_clear_unit (MainWindow* self)
{
	GtkButton* _tmp0_;
	GtkButton* _tmp1_;
	GtkButton* _tmp2_;
	GtkButton* _tmp3_;
	RightLabel* _tmp4_;
	RightLabel* _tmp5_;
	RightLabel* _tmp6_;
	RightLabel* _tmp7_;
	RightLabel* _tmp8_;
	RightLabel* _tmp9_;
	RightLabel* _tmp10_;
	RightLabel* _tmp11_;
	RightLabel* _tmp12_;
	RightLabel* _tmp13_;
	RightLabel* _tmp14_;
	RightLabel* _tmp15_;
#line 452 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 453 "src/systemadm.vala"
	_g_free0 (self->priv->current_unit_id);
#line 453 "src/systemadm.vala"
	self->priv->current_unit_id = NULL;
#line 455 "src/systemadm.vala"
	_tmp0_ = self->priv->start_button;
#line 455 "src/systemadm.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, FALSE);
#line 456 "src/systemadm.vala"
	_tmp1_ = self->priv->stop_button;
#line 456 "src/systemadm.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp1_, FALSE);
#line 457 "src/systemadm.vala"
	_tmp2_ = self->priv->reload_button;
#line 457 "src/systemadm.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp2_, FALSE);
#line 458 "src/systemadm.vala"
	_tmp3_ = self->priv->restart_button;
#line 458 "src/systemadm.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp3_, FALSE);
#line 460 "src/systemadm.vala"
	_tmp4_ = self->priv->unit_id_label;
#line 460 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp4_, NULL);
#line 461 "src/systemadm.vala"
	_tmp5_ = self->priv->unit_description_label;
#line 461 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp5_, NULL);
#line 462 "src/systemadm.vala"
	_tmp6_ = self->priv->unit_description_label;
#line 462 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp6_, NULL);
#line 463 "src/systemadm.vala"
	_tmp7_ = self->priv->unit_load_state_label;
#line 463 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp7_, NULL);
#line 464 "src/systemadm.vala"
	_tmp8_ = self->priv->unit_active_state_label;
#line 464 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp8_, NULL);
#line 465 "src/systemadm.vala"
	_tmp9_ = self->priv->unit_sub_state_label;
#line 465 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp9_, NULL);
#line 466 "src/systemadm.vala"
	_tmp10_ = self->priv->unit_fragment_path_label;
#line 466 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp10_, NULL);
#line 467 "src/systemadm.vala"
	_tmp11_ = self->priv->unit_active_enter_timestamp_label;
#line 467 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp11_, NULL);
#line 468 "src/systemadm.vala"
	_tmp12_ = self->priv->unit_active_exit_timestamp_label;
#line 468 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp12_, NULL);
#line 469 "src/systemadm.vala"
	_tmp13_ = self->priv->unit_can_reload_label;
#line 469 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp13_, NULL);
#line 470 "src/systemadm.vala"
	_tmp14_ = self->priv->unit_can_start_label;
#line 470 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp14_, NULL);
#line 471 "src/systemadm.vala"
	_tmp15_ = self->priv->unit_cgroup_label;
#line 471 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp15_, NULL);
#line 3794 "systemadm.c"
}

gchar*
main_window_format_unit_link (MainWindow* self,
                              const gchar* i,
                              gboolean link)
{
	Unit* u = NULL;
	Unit* _tmp0_;
	Unit* _tmp1_;
	gchar* color = NULL;
	Unit* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	GQuark _tmp11_ = 0U;
#line 480 "src/systemadm.vala"
	static GQuark _tmp10_label0 = 0;
#line 480 "src/systemadm.vala"
	static GQuark _tmp10_label1 = 0;
#line 480 "src/systemadm.vala"
	static GQuark _tmp10_label2 = 0;
#line 480 "src/systemadm.vala"
	static GQuark _tmp10_label3 = 0;
#line 480 "src/systemadm.vala"
	static GQuark _tmp10_label4 = 0;
#line 480 "src/systemadm.vala"
	static GQuark _tmp10_label5 = 0;
#line 480 "src/systemadm.vala"
	static GQuark _tmp10_label6 = 0;
#line 3825 "systemadm.c"
	gchar* span = NULL;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	gchar* _tmp22_;
	gchar* _tmp23_;
	gchar* _tmp24_;
	gchar* _tmp25_;
	gchar* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	Unit* _tmp29_;
	gchar* _tmp30_;
	gchar* _tmp31_;
	gchar* _tmp32_;
	gchar* _tmp33_;
	gchar* _tmp34_;
	gchar* _tmp35_;
	gchar* _tmp36_;
	gchar* _tmp37_;
	gchar* _tmp38_;
	gchar* result;
#line 474 "src/systemadm.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 474 "src/systemadm.vala"
	g_return_val_if_fail (i != NULL, NULL);
#line 475 "src/systemadm.vala"
	_tmp0_ = main_window_get_unit (self, i);
#line 475 "src/systemadm.vala"
	u = _tmp0_;
#line 476 "src/systemadm.vala"
	_tmp1_ = u;
#line 476 "src/systemadm.vala"
	if (_tmp1_ == NULL) {
#line 3859 "systemadm.c"
		gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
#line 477 "src/systemadm.vala"
		_tmp2_ = g_strconcat ("<span color='grey'>", i, NULL);
#line 477 "src/systemadm.vala"
		_tmp3_ = _tmp2_;
#line 477 "src/systemadm.vala"
		_tmp4_ = g_strconcat (_tmp3_, "</span", NULL);
#line 477 "src/systemadm.vala"
		_tmp5_ = _tmp4_;
#line 477 "src/systemadm.vala"
		_g_free0 (_tmp3_);
#line 477 "src/systemadm.vala"
		result = _tmp5_;
#line 477 "src/systemadm.vala"
		_g_object_unref0 (u);
#line 477 "src/systemadm.vala"
		return result;
#line 3880 "systemadm.c"
	}
#line 480 "src/systemadm.vala"
	_tmp6_ = u;
#line 480 "src/systemadm.vala"
	_tmp7_ = unit_get_sub_state (_tmp6_);
#line 480 "src/systemadm.vala"
	_tmp8_ = _tmp7_;
#line 480 "src/systemadm.vala"
	_tmp9_ = _tmp8_;
#line 480 "src/systemadm.vala"
	_tmp11_ = (NULL == _tmp9_) ? 0 : g_quark_from_string (_tmp9_);
#line 480 "src/systemadm.vala"
	g_free (_tmp9_);
#line 480 "src/systemadm.vala"
	if (_tmp11_ == ((0 != _tmp10_label0) ? _tmp10_label0 : (_tmp10_label0 = g_quark_from_static_string ("active")))) {
#line 480 "src/systemadm.vala"
		switch (0) {
#line 3898 "systemadm.c"
			default:
			{
				gchar* _tmp12_;
#line 481 "src/systemadm.vala"
				_tmp12_ = g_strdup ("blue");
#line 481 "src/systemadm.vala"
				_g_free0 (color);
#line 481 "src/systemadm.vala"
				color = _tmp12_;
#line 481 "src/systemadm.vala"
				break;
#line 3910 "systemadm.c"
			}
		}
	} else if (_tmp11_ == ((0 != _tmp10_label1) ? _tmp10_label1 : (_tmp10_label1 = g_quark_from_static_string ("dead")))) {
#line 480 "src/systemadm.vala"
		switch (0) {
#line 3916 "systemadm.c"
			default:
			{
				gchar* _tmp13_;
#line 482 "src/systemadm.vala"
				_tmp13_ = g_strdup ("black");
#line 482 "src/systemadm.vala"
				_g_free0 (color);
#line 482 "src/systemadm.vala"
				color = _tmp13_;
#line 482 "src/systemadm.vala"
				break;
#line 3928 "systemadm.c"
			}
		}
	} else if (_tmp11_ == ((0 != _tmp10_label2) ? _tmp10_label2 : (_tmp10_label2 = g_quark_from_static_string ("running")))) {
#line 480 "src/systemadm.vala"
		switch (0) {
#line 3934 "systemadm.c"
			default:
			{
				gchar* _tmp14_;
#line 483 "src/systemadm.vala"
				_tmp14_ = g_strdup ("green");
#line 483 "src/systemadm.vala"
				_g_free0 (color);
#line 483 "src/systemadm.vala"
				color = _tmp14_;
#line 483 "src/systemadm.vala"
				break;
#line 3946 "systemadm.c"
			}
		}
	} else if (_tmp11_ == ((0 != _tmp10_label3) ? _tmp10_label3 : (_tmp10_label3 = g_quark_from_static_string ("plugged")))) {
#line 480 "src/systemadm.vala"
		switch (0) {
#line 3952 "systemadm.c"
			default:
			{
				gchar* _tmp15_;
#line 484 "src/systemadm.vala"
				_tmp15_ = g_strdup ("light blue");
#line 484 "src/systemadm.vala"
				_g_free0 (color);
#line 484 "src/systemadm.vala"
				color = _tmp15_;
#line 484 "src/systemadm.vala"
				break;
#line 3964 "systemadm.c"
			}
		}
	} else if (_tmp11_ == ((0 != _tmp10_label4) ? _tmp10_label4 : (_tmp10_label4 = g_quark_from_static_string ("mounted")))) {
#line 480 "src/systemadm.vala"
		switch (0) {
#line 3970 "systemadm.c"
			default:
			{
				gchar* _tmp16_;
#line 485 "src/systemadm.vala"
				_tmp16_ = g_strdup ("light green");
#line 485 "src/systemadm.vala"
				_g_free0 (color);
#line 485 "src/systemadm.vala"
				color = _tmp16_;
#line 485 "src/systemadm.vala"
				break;
#line 3982 "systemadm.c"
			}
		}
	} else if (_tmp11_ == ((0 != _tmp10_label5) ? _tmp10_label5 : (_tmp10_label5 = g_quark_from_static_string ("exited")))) {
#line 480 "src/systemadm.vala"
		switch (0) {
#line 3988 "systemadm.c"
			default:
			{
				gchar* _tmp17_;
#line 486 "src/systemadm.vala"
				_tmp17_ = g_strdup ("brown");
#line 486 "src/systemadm.vala"
				_g_free0 (color);
#line 486 "src/systemadm.vala"
				color = _tmp17_;
#line 486 "src/systemadm.vala"
				break;
#line 4000 "systemadm.c"
			}
		}
	} else if (_tmp11_ == ((0 != _tmp10_label6) ? _tmp10_label6 : (_tmp10_label6 = g_quark_from_static_string ("failed")))) {
#line 480 "src/systemadm.vala"
		switch (0) {
#line 4006 "systemadm.c"
			default:
			{
				gchar* _tmp18_;
#line 487 "src/systemadm.vala"
				_tmp18_ = g_strdup ("red");
#line 487 "src/systemadm.vala"
				_g_free0 (color);
#line 487 "src/systemadm.vala"
				color = _tmp18_;
#line 487 "src/systemadm.vala"
				break;
#line 4018 "systemadm.c"
			}
		}
	} else {
#line 480 "src/systemadm.vala"
		switch (0) {
#line 4024 "systemadm.c"
			default:
			{
				gchar* _tmp19_;
#line 488 "src/systemadm.vala"
				_tmp19_ = g_strdup ("black");
#line 488 "src/systemadm.vala"
				_g_free0 (color);
#line 488 "src/systemadm.vala"
				color = _tmp19_;
#line 488 "src/systemadm.vala"
				break;
#line 4036 "systemadm.c"
			}
		}
	}
#line 490 "src/systemadm.vala"
	_tmp20_ = color;
#line 490 "src/systemadm.vala"
	_tmp21_ = g_strconcat ("<span underline='none' color='", _tmp20_, NULL);
#line 490 "src/systemadm.vala"
	_tmp22_ = _tmp21_;
#line 490 "src/systemadm.vala"
	_tmp23_ = g_strconcat (_tmp22_, "'>", NULL);
#line 490 "src/systemadm.vala"
	_tmp24_ = _tmp23_;
#line 490 "src/systemadm.vala"
	_tmp25_ = g_strconcat (_tmp24_, i, NULL);
#line 490 "src/systemadm.vala"
	_tmp26_ = _tmp25_;
#line 490 "src/systemadm.vala"
	_tmp27_ = g_strconcat (_tmp26_, "(", NULL);
#line 490 "src/systemadm.vala"
	_tmp28_ = _tmp27_;
#line 490 "src/systemadm.vala"
	_tmp29_ = u;
#line 490 "src/systemadm.vala"
	_tmp30_ = unit_get_sub_state (_tmp29_);
#line 490 "src/systemadm.vala"
	_tmp31_ = _tmp30_;
#line 490 "src/systemadm.vala"
	_tmp32_ = _tmp31_;
#line 490 "src/systemadm.vala"
	_tmp33_ = g_strconcat (_tmp28_, _tmp32_, NULL);
#line 490 "src/systemadm.vala"
	_tmp34_ = _tmp33_;
#line 490 "src/systemadm.vala"
	_tmp35_ = g_strconcat (_tmp34_, ")", NULL);
#line 490 "src/systemadm.vala"
	_tmp36_ = _tmp35_;
#line 490 "src/systemadm.vala"
	_tmp37_ = g_strconcat (_tmp36_, "</span>", NULL);
#line 490 "src/systemadm.vala"
	_tmp38_ = _tmp37_;
#line 490 "src/systemadm.vala"
	_g_free0 (_tmp36_);
#line 490 "src/systemadm.vala"
	_g_free0 (_tmp34_);
#line 490 "src/systemadm.vala"
	_g_free0 (_tmp32_);
#line 490 "src/systemadm.vala"
	_g_free0 (_tmp28_);
#line 490 "src/systemadm.vala"
	_g_free0 (_tmp26_);
#line 490 "src/systemadm.vala"
	_g_free0 (_tmp24_);
#line 490 "src/systemadm.vala"
	_g_free0 (_tmp22_);
#line 490 "src/systemadm.vala"
	span = _tmp38_;
#line 493 "src/systemadm.vala"
	if (link) {
#line 4096 "systemadm.c"
		gchar* _tmp39_;
		gchar* _tmp40_;
		gchar* _tmp41_;
		gchar* _tmp42_;
		const gchar* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
#line 494 "src/systemadm.vala"
		_tmp39_ = g_strconcat (" <a href='", i, NULL);
#line 494 "src/systemadm.vala"
		_tmp40_ = _tmp39_;
#line 494 "src/systemadm.vala"
		_tmp41_ = g_strconcat (_tmp40_, "'>", NULL);
#line 494 "src/systemadm.vala"
		_tmp42_ = _tmp41_;
#line 494 "src/systemadm.vala"
		_tmp43_ = span;
#line 494 "src/systemadm.vala"
		_tmp44_ = g_strconcat (_tmp42_, _tmp43_, NULL);
#line 494 "src/systemadm.vala"
		_tmp45_ = _tmp44_;
#line 494 "src/systemadm.vala"
		_tmp46_ = g_strconcat (_tmp45_, "</a>", NULL);
#line 494 "src/systemadm.vala"
		_tmp47_ = _tmp46_;
#line 494 "src/systemadm.vala"
		_g_free0 (_tmp45_);
#line 494 "src/systemadm.vala"
		_g_free0 (_tmp42_);
#line 494 "src/systemadm.vala"
		_g_free0 (_tmp40_);
#line 494 "src/systemadm.vala"
		result = _tmp47_;
#line 494 "src/systemadm.vala"
		_g_free0 (span);
#line 494 "src/systemadm.vala"
		_g_free0 (color);
#line 494 "src/systemadm.vala"
		_g_object_unref0 (u);
#line 494 "src/systemadm.vala"
		return result;
#line 4140 "systemadm.c"
	} else {
#line 496 "src/systemadm.vala"
		result = span;
#line 496 "src/systemadm.vala"
		_g_free0 (color);
#line 496 "src/systemadm.vala"
		_g_object_unref0 (u);
#line 496 "src/systemadm.vala"
		return result;
#line 4150 "systemadm.c"
	}
}

gchar*
main_window_make_dependency_string (MainWindow* self,
                                    const gchar* prefix,
                                    const gchar* word,
                                    gchar** dependencies,
                                    gint dependencies_length1)
{
	GeeCollection* sorted = NULL;
	GeeTreeSet* _tmp0_;
	gboolean first = FALSE;
	gchar* r = NULL;
	gchar* result;
#line 500 "src/systemadm.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 500 "src/systemadm.vala"
	g_return_val_if_fail (word != NULL, NULL);
#line 501 "src/systemadm.vala"
	_tmp0_ = gee_tree_set_new (G_TYPE_STRING, NULL, NULL, NULL, NULL, NULL);
#line 501 "src/systemadm.vala"
	sorted = (GeeCollection*) _tmp0_;
#line 4174 "systemadm.c"
	{
		gchar** i_collection = NULL;
		gint i_collection_length1 = 0;
		gint _i_collection_size_ = 0;
		gint i_it = 0;
#line 502 "src/systemadm.vala"
		i_collection = dependencies;
#line 502 "src/systemadm.vala"
		i_collection_length1 = dependencies_length1;
#line 502 "src/systemadm.vala"
		for (i_it = 0; i_it < i_collection_length1; i_it = i_it + 1) {
#line 4186 "systemadm.c"
			gchar* _tmp1_;
			gchar* i = NULL;
#line 502 "src/systemadm.vala"
			_tmp1_ = g_strdup (i_collection[i_it]);
#line 502 "src/systemadm.vala"
			i = _tmp1_;
#line 4193 "systemadm.c"
			{
				GeeCollection* _tmp2_;
				const gchar* _tmp3_;
#line 503 "src/systemadm.vala"
				_tmp2_ = sorted;
#line 503 "src/systemadm.vala"
				_tmp3_ = i;
#line 503 "src/systemadm.vala"
				gee_collection_add (_tmp2_, _tmp3_);
#line 502 "src/systemadm.vala"
				_g_free0 (i);
#line 4205 "systemadm.c"
			}
		}
	}
#line 505 "src/systemadm.vala"
	first = TRUE;
#line 508 "src/systemadm.vala"
	if (prefix == NULL) {
#line 4213 "systemadm.c"
		gchar* _tmp4_;
#line 509 "src/systemadm.vala"
		_tmp4_ = g_strdup ("");
#line 509 "src/systemadm.vala"
		_g_free0 (r);
#line 509 "src/systemadm.vala"
		r = _tmp4_;
#line 4221 "systemadm.c"
	} else {
		gchar* _tmp5_;
#line 511 "src/systemadm.vala"
		_tmp5_ = g_strdup (prefix);
#line 511 "src/systemadm.vala"
		_g_free0 (r);
#line 511 "src/systemadm.vala"
		r = _tmp5_;
#line 4230 "systemadm.c"
	}
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp6_;
		GeeIterator* _tmp7_;
#line 513 "src/systemadm.vala"
		_tmp6_ = sorted;
#line 513 "src/systemadm.vala"
		_tmp7_ = gee_iterable_iterator ((GeeIterable*) _tmp6_);
#line 513 "src/systemadm.vala"
		_i_it = _tmp7_;
#line 513 "src/systemadm.vala"
		while (TRUE) {
#line 4244 "systemadm.c"
			GeeIterator* _tmp8_;
			gchar* i = NULL;
			GeeIterator* _tmp9_;
			gpointer _tmp10_;
			gchar* _tmp11_;
			const gchar* _tmp12_;
			const gchar* _tmp22_;
			const gchar* _tmp23_;
			gchar* _tmp24_;
			gchar* _tmp25_;
			gchar* _tmp26_;
#line 513 "src/systemadm.vala"
			_tmp8_ = _i_it;
#line 513 "src/systemadm.vala"
			if (!gee_iterator_next (_tmp8_)) {
#line 513 "src/systemadm.vala"
				break;
#line 4262 "systemadm.c"
			}
#line 513 "src/systemadm.vala"
			_tmp9_ = _i_it;
#line 513 "src/systemadm.vala"
			_tmp10_ = gee_iterator_get (_tmp9_);
#line 513 "src/systemadm.vala"
			_tmp11_ = g_strdup ((const gchar*) _tmp10_);
#line 513 "src/systemadm.vala"
			i = _tmp11_;
#line 514 "src/systemadm.vala"
			_tmp12_ = r;
#line 514 "src/systemadm.vala"
			if (g_strcmp0 (_tmp12_, "") != 0) {
#line 4276 "systemadm.c"
				const gchar* _tmp13_ = NULL;
				const gchar* _tmp14_;
				gchar* _tmp15_;
#line 515 "src/systemadm.vala"
				if (first) {
#line 515 "src/systemadm.vala"
					_tmp13_ = "\n";
#line 4284 "systemadm.c"
				} else {
#line 515 "src/systemadm.vala"
					_tmp13_ = ",";
#line 4288 "systemadm.c"
				}
#line 515 "src/systemadm.vala"
				_tmp14_ = r;
#line 515 "src/systemadm.vala"
				_tmp15_ = g_strconcat (_tmp14_, _tmp13_, NULL);
#line 515 "src/systemadm.vala"
				_g_free0 (r);
#line 515 "src/systemadm.vala"
				r = _tmp15_;
#line 4298 "systemadm.c"
			}
#line 517 "src/systemadm.vala"
			if (first) {
#line 4302 "systemadm.c"
				const gchar* _tmp16_;
				gchar* _tmp17_;
				gchar* _tmp18_;
				gchar* _tmp19_;
				gchar* _tmp20_;
				gchar* _tmp21_;
#line 518 "src/systemadm.vala"
				_tmp16_ = r;
#line 518 "src/systemadm.vala"
				_tmp17_ = g_strconcat ("<b>", word, NULL);
#line 518 "src/systemadm.vala"
				_tmp18_ = _tmp17_;
#line 518 "src/systemadm.vala"
				_tmp19_ = g_strconcat (_tmp18_, ":</b>", NULL);
#line 518 "src/systemadm.vala"
				_tmp20_ = _tmp19_;
#line 518 "src/systemadm.vala"
				_tmp21_ = g_strconcat (_tmp16_, _tmp20_, NULL);
#line 518 "src/systemadm.vala"
				_g_free0 (r);
#line 518 "src/systemadm.vala"
				r = _tmp21_;
#line 518 "src/systemadm.vala"
				_g_free0 (_tmp20_);
#line 518 "src/systemadm.vala"
				_g_free0 (_tmp18_);
#line 519 "src/systemadm.vala"
				first = FALSE;
#line 4331 "systemadm.c"
			}
#line 522 "src/systemadm.vala"
			_tmp22_ = r;
#line 522 "src/systemadm.vala"
			_tmp23_ = i;
#line 522 "src/systemadm.vala"
			_tmp24_ = main_window_format_unit_link (self, _tmp23_, TRUE);
#line 522 "src/systemadm.vala"
			_tmp25_ = _tmp24_;
#line 522 "src/systemadm.vala"
			_tmp26_ = g_strconcat (_tmp22_, _tmp25_, NULL);
#line 522 "src/systemadm.vala"
			_g_free0 (r);
#line 522 "src/systemadm.vala"
			r = _tmp26_;
#line 522 "src/systemadm.vala"
			_g_free0 (_tmp25_);
#line 513 "src/systemadm.vala"
			_g_free0 (i);
#line 4351 "systemadm.c"
		}
#line 513 "src/systemadm.vala"
		_g_object_unref0 (_i_it);
#line 4355 "systemadm.c"
	}
#line 525 "src/systemadm.vala"
	result = r;
#line 525 "src/systemadm.vala"
	_g_object_unref0 (sorted);
#line 525 "src/systemadm.vala"
	return result;
#line 4363 "systemadm.c"
}

void
main_window_show_unit (MainWindow* self,
                       Unit* unit)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* id_display = NULL;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	gboolean has_alias = FALSE;
	gchar** _tmp4_;
	gint _tmp4__length1;
	gint _tmp5_ = 0;
	gchar** _tmp6_;
	gint _tmp6__length1;
	RightLabel* _tmp19_;
	const gchar* _tmp20_;
	gchar** requires = NULL;
	gchar** _tmp21_;
	gint _tmp21__length1;
	gint _tmp22_ = 0;
	gchar** _tmp23_;
	gint _tmp23__length1;
	gint requires_length1;
	gint _requires_size_;
	gchar** requires_overridable = NULL;
	gchar** _tmp24_;
	gint _tmp24__length1;
	gint _tmp25_ = 0;
	gchar** _tmp26_;
	gint _tmp26__length1;
	gint requires_overridable_length1;
	gint _requires_overridable_size_;
	gchar** requisite = NULL;
	gchar** _tmp27_;
	gint _tmp27__length1;
	gint _tmp28_ = 0;
	gchar** _tmp29_;
	gint _tmp29__length1;
	gint requisite_length1;
	gint _requisite_size_;
	gchar** requisite_overridable = NULL;
	gchar** _tmp30_;
	gint _tmp30__length1;
	gint _tmp31_ = 0;
	gchar** _tmp32_;
	gint _tmp32__length1;
	gint requisite_overridable_length1;
	gint _requisite_overridable_size_;
	gchar** wants = NULL;
	gchar** _tmp33_;
	gint _tmp33__length1;
	gint _tmp34_ = 0;
	gchar** _tmp35_;
	gint _tmp35__length1;
	gint wants_length1;
	gint _wants_size_;
	gchar** required_by = NULL;
	gchar** _tmp36_;
	gint _tmp36__length1;
	gint _tmp37_ = 0;
	gchar** _tmp38_;
	gint _tmp38__length1;
	gint required_by_length1;
	gint _required_by_size_;
	gchar** required_by_overridable = NULL;
	gchar** _tmp39_;
	gint _tmp39__length1;
	gint _tmp40_ = 0;
	gchar** _tmp41_;
	gint _tmp41__length1;
	gint required_by_overridable_length1;
	gint _required_by_overridable_size_;
	gchar** wanted_by = NULL;
	gchar** _tmp42_;
	gint _tmp42__length1;
	gint _tmp43_ = 0;
	gchar** _tmp44_;
	gint _tmp44__length1;
	gint wanted_by_length1;
	gint _wanted_by_size_;
	gchar** conflicts = NULL;
	gchar** _tmp45_;
	gint _tmp45__length1;
	gint _tmp46_ = 0;
	gchar** _tmp47_;
	gint _tmp47__length1;
	gint conflicts_length1;
	gint _conflicts_size_;
	gchar** before = NULL;
	gchar** _tmp48_;
	gint _tmp48__length1;
	gint _tmp49_ = 0;
	gchar** _tmp50_;
	gint _tmp50__length1;
	gint before_length1;
	gint _before_size_;
	gchar** after = NULL;
	gchar** _tmp51_;
	gint _tmp51__length1;
	gint _tmp52_ = 0;
	gchar** _tmp53_;
	gint _tmp53__length1;
	gint after_length1;
	gint _after_size_;
	RightLabel* _tmp54_;
	gchar** _tmp55_;
	gint _tmp55__length1;
	gchar* _tmp56_;
	gchar* _tmp57_;
	gchar** _tmp58_;
	gint _tmp58__length1;
	gchar* _tmp59_;
	gchar* _tmp60_;
	gchar** _tmp61_;
	gint _tmp61__length1;
	gchar* _tmp62_;
	gchar* _tmp63_;
	gchar** _tmp64_;
	gint _tmp64__length1;
	gchar* _tmp65_;
	gchar* _tmp66_;
	gchar** _tmp67_;
	gint _tmp67__length1;
	gchar* _tmp68_;
	gchar* _tmp69_;
	gchar** _tmp70_;
	gint _tmp70__length1;
	gchar* _tmp71_;
	gchar* _tmp72_;
	gchar** _tmp73_;
	gint _tmp73__length1;
	gchar* _tmp74_;
	gchar* _tmp75_;
	gchar** _tmp76_;
	gint _tmp76__length1;
	gchar* _tmp77_;
	gchar* _tmp78_;
	gchar** _tmp79_;
	gint _tmp79__length1;
	gchar* _tmp80_;
	gchar* _tmp81_;
	gchar** _tmp82_;
	gint _tmp82__length1;
	gchar* _tmp83_;
	gchar* _tmp84_;
	gchar** _tmp85_;
	gint _tmp85__length1;
	gchar* _tmp86_;
	gchar* _tmp87_;
	RightLabel* _tmp88_;
	gchar* _tmp89_;
	gchar* _tmp90_;
	gchar* _tmp91_;
	RightLabel* _tmp92_;
	gchar* _tmp93_;
	gchar* _tmp94_;
	gchar* _tmp95_;
	RightLabel* _tmp96_;
	gchar* _tmp97_;
	gchar* _tmp98_;
	gchar* _tmp99_;
	RightLabel* _tmp100_;
	gchar* _tmp101_;
	gchar* _tmp102_;
	gchar* _tmp103_;
	gchar* fp = NULL;
	gchar* _tmp104_;
	gchar* _tmp105_;
	const gchar* _tmp106_;
	RightLabel* _tmp121_;
	guint64 _tmp122_;
	guint64 _tmp123_;
	gchar* _tmp124_;
	gchar* _tmp125_;
	RightLabel* _tmp126_;
	guint64 _tmp127_;
	guint64 _tmp128_;
	gchar* _tmp129_;
	gchar* _tmp130_;
	gboolean b = FALSE;
	gboolean _tmp131_;
	gboolean _tmp132_;
	GtkButton* _tmp133_;
	GtkButton* _tmp134_;
	GtkButton* _tmp135_;
	const gchar* _tmp136_ = NULL;
	RightLabel* _tmp137_;
	gboolean _tmp138_;
	gboolean _tmp139_;
	GtkButton* _tmp140_;
	const gchar* _tmp141_ = NULL;
	RightLabel* _tmp142_;
	RightLabel* _tmp143_;
	gchar* _tmp144_;
	gchar* _tmp145_;
	gchar* _tmp146_;
#line 528 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 528 "src/systemadm.vala"
	g_return_if_fail (unit != NULL);
#line 529 "src/systemadm.vala"
	_tmp0_ = unit_get_id (unit);
#line 529 "src/systemadm.vala"
	_tmp1_ = _tmp0_;
#line 529 "src/systemadm.vala"
	_g_free0 (self->priv->current_unit_id);
#line 529 "src/systemadm.vala"
	self->priv->current_unit_id = _tmp1_;
#line 531 "src/systemadm.vala"
	_tmp2_ = self->priv->current_unit_id;
#line 531 "src/systemadm.vala"
	_tmp3_ = main_window_format_unit_link (self, _tmp2_, FALSE);
#line 531 "src/systemadm.vala"
	id_display = _tmp3_;
#line 532 "src/systemadm.vala"
	has_alias = FALSE;
#line 533 "src/systemadm.vala"
	_tmp4_ = unit_get_names (unit, &_tmp5_);
#line 533 "src/systemadm.vala"
	_tmp4__length1 = _tmp5_;
#line 533 "src/systemadm.vala"
	_tmp6_ = _tmp4_;
#line 533 "src/systemadm.vala"
	_tmp6__length1 = _tmp4__length1;
#line 4591 "systemadm.c"
	{
		gchar** i_collection = NULL;
		gint i_collection_length1 = 0;
		gint _i_collection_size_ = 0;
		gint i_it = 0;
#line 533 "src/systemadm.vala"
		i_collection = _tmp6_;
#line 533 "src/systemadm.vala"
		i_collection_length1 = _tmp6__length1;
#line 533 "src/systemadm.vala"
		for (i_it = 0; i_it < i_collection_length1; i_it = i_it + 1) {
#line 4603 "systemadm.c"
			gchar* _tmp7_;
			gchar* i = NULL;
#line 533 "src/systemadm.vala"
			_tmp7_ = g_strdup (i_collection[i_it]);
#line 533 "src/systemadm.vala"
			i = _tmp7_;
#line 4610 "systemadm.c"
			{
				const gchar* _tmp8_;
				const gchar* _tmp9_;
				const gchar* _tmp12_;
				const gchar* _tmp13_;
				gchar* _tmp14_;
				gchar* _tmp15_;
				gchar* _tmp16_;
#line 534 "src/systemadm.vala"
				_tmp8_ = i;
#line 534 "src/systemadm.vala"
				_tmp9_ = self->priv->current_unit_id;
#line 534 "src/systemadm.vala"
				if (g_strcmp0 (_tmp8_, _tmp9_) == 0) {
#line 535 "src/systemadm.vala"
					_g_free0 (i);
#line 535 "src/systemadm.vala"
					continue;
#line 4629 "systemadm.c"
				}
#line 537 "src/systemadm.vala"
				if (!has_alias) {
#line 4633 "systemadm.c"
					const gchar* _tmp10_;
					gchar* _tmp11_;
#line 538 "src/systemadm.vala"
					_tmp10_ = id_display;
#line 538 "src/systemadm.vala"
					_tmp11_ = g_strconcat (_tmp10_, " (aliases:", NULL);
#line 538 "src/systemadm.vala"
					_g_free0 (id_display);
#line 538 "src/systemadm.vala"
					id_display = _tmp11_;
#line 539 "src/systemadm.vala"
					has_alias = TRUE;
#line 4646 "systemadm.c"
				}
#line 542 "src/systemadm.vala"
				_tmp12_ = id_display;
#line 542 "src/systemadm.vala"
				_tmp13_ = i;
#line 542 "src/systemadm.vala"
				_tmp14_ = g_strconcat (" ", _tmp13_, NULL);
#line 542 "src/systemadm.vala"
				_tmp15_ = _tmp14_;
#line 542 "src/systemadm.vala"
				_tmp16_ = g_strconcat (_tmp12_, _tmp15_, NULL);
#line 542 "src/systemadm.vala"
				_g_free0 (id_display);
#line 542 "src/systemadm.vala"
				id_display = _tmp16_;
#line 542 "src/systemadm.vala"
				_g_free0 (_tmp15_);
#line 533 "src/systemadm.vala"
				_g_free0 (i);
#line 4666 "systemadm.c"
			}
		}
#line 533 "src/systemadm.vala"
		i_collection = (_vala_array_free (i_collection, i_collection_length1, (GDestroyNotify) g_free), NULL);
#line 4671 "systemadm.c"
	}
#line 544 "src/systemadm.vala"
	if (has_alias) {
#line 4675 "systemadm.c"
		const gchar* _tmp17_;
		gchar* _tmp18_;
#line 545 "src/systemadm.vala"
		_tmp17_ = id_display;
#line 545 "src/systemadm.vala"
		_tmp18_ = g_strconcat (_tmp17_, ")", NULL);
#line 545 "src/systemadm.vala"
		_g_free0 (id_display);
#line 545 "src/systemadm.vala"
		id_display = _tmp18_;
#line 4686 "systemadm.c"
	}
#line 547 "src/systemadm.vala"
	_tmp19_ = self->priv->unit_id_label;
#line 547 "src/systemadm.vala"
	_tmp20_ = id_display;
#line 547 "src/systemadm.vala"
	right_label_set_markup_or_na (_tmp19_, _tmp20_);
#line 549 "src/systemadm.vala"
	_tmp21_ = unit_get_requires (unit, &_tmp22_);
#line 549 "src/systemadm.vala"
	_tmp21__length1 = _tmp22_;
#line 549 "src/systemadm.vala"
	_tmp23_ = _tmp21_;
#line 549 "src/systemadm.vala"
	_tmp23__length1 = _tmp21__length1;
#line 549 "src/systemadm.vala"
	requires = _tmp23_;
#line 549 "src/systemadm.vala"
	requires_length1 = _tmp23__length1;
#line 549 "src/systemadm.vala"
	_requires_size_ = requires_length1;
#line 551 "src/systemadm.vala"
	_tmp24_ = unit_get_requires_overridable (unit, &_tmp25_);
#line 551 "src/systemadm.vala"
	_tmp24__length1 = _tmp25_;
#line 551 "src/systemadm.vala"
	_tmp26_ = _tmp24_;
#line 551 "src/systemadm.vala"
	_tmp26__length1 = _tmp24__length1;
#line 551 "src/systemadm.vala"
	requires_overridable = _tmp26_;
#line 551 "src/systemadm.vala"
	requires_overridable_length1 = _tmp26__length1;
#line 551 "src/systemadm.vala"
	_requires_overridable_size_ = requires_overridable_length1;
#line 552 "src/systemadm.vala"
	_tmp27_ = unit_get_requisite (unit, &_tmp28_);
#line 552 "src/systemadm.vala"
	_tmp27__length1 = _tmp28_;
#line 552 "src/systemadm.vala"
	_tmp29_ = _tmp27_;
#line 552 "src/systemadm.vala"
	_tmp29__length1 = _tmp27__length1;
#line 552 "src/systemadm.vala"
	requisite = _tmp29_;
#line 552 "src/systemadm.vala"
	requisite_length1 = _tmp29__length1;
#line 552 "src/systemadm.vala"
	_requisite_size_ = requisite_length1;
#line 553 "src/systemadm.vala"
	_tmp30_ = unit_get_requisite_overridable (unit, &_tmp31_);
#line 553 "src/systemadm.vala"
	_tmp30__length1 = _tmp31_;
#line 553 "src/systemadm.vala"
	_tmp32_ = _tmp30_;
#line 553 "src/systemadm.vala"
	_tmp32__length1 = _tmp30__length1;
#line 553 "src/systemadm.vala"
	requisite_overridable = _tmp32_;
#line 553 "src/systemadm.vala"
	requisite_overridable_length1 = _tmp32__length1;
#line 553 "src/systemadm.vala"
	_requisite_overridable_size_ = requisite_overridable_length1;
#line 554 "src/systemadm.vala"
	_tmp33_ = unit_get_wants (unit, &_tmp34_);
#line 554 "src/systemadm.vala"
	_tmp33__length1 = _tmp34_;
#line 554 "src/systemadm.vala"
	_tmp35_ = _tmp33_;
#line 554 "src/systemadm.vala"
	_tmp35__length1 = _tmp33__length1;
#line 554 "src/systemadm.vala"
	wants = _tmp35_;
#line 554 "src/systemadm.vala"
	wants_length1 = _tmp35__length1;
#line 554 "src/systemadm.vala"
	_wants_size_ = wants_length1;
#line 555 "src/systemadm.vala"
	_tmp36_ = unit_get_required_by (unit, &_tmp37_);
#line 555 "src/systemadm.vala"
	_tmp36__length1 = _tmp37_;
#line 555 "src/systemadm.vala"
	_tmp38_ = _tmp36_;
#line 555 "src/systemadm.vala"
	_tmp38__length1 = _tmp36__length1;
#line 555 "src/systemadm.vala"
	required_by = _tmp38_;
#line 555 "src/systemadm.vala"
	required_by_length1 = _tmp38__length1;
#line 555 "src/systemadm.vala"
	_required_by_size_ = required_by_length1;
#line 556 "src/systemadm.vala"
	_tmp39_ = unit_get_required_by_overridable (unit, &_tmp40_);
#line 556 "src/systemadm.vala"
	_tmp39__length1 = _tmp40_;
#line 556 "src/systemadm.vala"
	_tmp41_ = _tmp39_;
#line 556 "src/systemadm.vala"
	_tmp41__length1 = _tmp39__length1;
#line 556 "src/systemadm.vala"
	required_by_overridable = _tmp41_;
#line 556 "src/systemadm.vala"
	required_by_overridable_length1 = _tmp41__length1;
#line 556 "src/systemadm.vala"
	_required_by_overridable_size_ = required_by_overridable_length1;
#line 557 "src/systemadm.vala"
	_tmp42_ = unit_get_wanted_by (unit, &_tmp43_);
#line 557 "src/systemadm.vala"
	_tmp42__length1 = _tmp43_;
#line 557 "src/systemadm.vala"
	_tmp44_ = _tmp42_;
#line 557 "src/systemadm.vala"
	_tmp44__length1 = _tmp42__length1;
#line 557 "src/systemadm.vala"
	wanted_by = _tmp44_;
#line 557 "src/systemadm.vala"
	wanted_by_length1 = _tmp44__length1;
#line 557 "src/systemadm.vala"
	_wanted_by_size_ = wanted_by_length1;
#line 558 "src/systemadm.vala"
	_tmp45_ = unit_get_conflicts (unit, &_tmp46_);
#line 558 "src/systemadm.vala"
	_tmp45__length1 = _tmp46_;
#line 558 "src/systemadm.vala"
	_tmp47_ = _tmp45_;
#line 558 "src/systemadm.vala"
	_tmp47__length1 = _tmp45__length1;
#line 558 "src/systemadm.vala"
	conflicts = _tmp47_;
#line 558 "src/systemadm.vala"
	conflicts_length1 = _tmp47__length1;
#line 558 "src/systemadm.vala"
	_conflicts_size_ = conflicts_length1;
#line 559 "src/systemadm.vala"
	_tmp48_ = unit_get_before (unit, &_tmp49_);
#line 559 "src/systemadm.vala"
	_tmp48__length1 = _tmp49_;
#line 559 "src/systemadm.vala"
	_tmp50_ = _tmp48_;
#line 559 "src/systemadm.vala"
	_tmp50__length1 = _tmp48__length1;
#line 559 "src/systemadm.vala"
	before = _tmp50_;
#line 559 "src/systemadm.vala"
	before_length1 = _tmp50__length1;
#line 559 "src/systemadm.vala"
	_before_size_ = before_length1;
#line 560 "src/systemadm.vala"
	_tmp51_ = unit_get_after (unit, &_tmp52_);
#line 560 "src/systemadm.vala"
	_tmp51__length1 = _tmp52_;
#line 560 "src/systemadm.vala"
	_tmp53_ = _tmp51_;
#line 560 "src/systemadm.vala"
	_tmp53__length1 = _tmp51__length1;
#line 560 "src/systemadm.vala"
	after = _tmp53_;
#line 560 "src/systemadm.vala"
	after_length1 = _tmp53__length1;
#line 560 "src/systemadm.vala"
	_after_size_ = after_length1;
#line 562 "src/systemadm.vala"
	_tmp54_ = self->priv->unit_dependency_label;
#line 562 "src/systemadm.vala"
	_tmp55_ = requires;
#line 562 "src/systemadm.vala"
	_tmp55__length1 = requires_length1;
#line 562 "src/systemadm.vala"
	_tmp56_ = main_window_make_dependency_string (self, NULL, "requires", _tmp55_, (gint) _tmp55__length1);
#line 562 "src/systemadm.vala"
	_tmp57_ = _tmp56_;
#line 562 "src/systemadm.vala"
	_tmp58_ = requires_overridable;
#line 562 "src/systemadm.vala"
	_tmp58__length1 = requires_overridable_length1;
#line 562 "src/systemadm.vala"
	_tmp59_ = main_window_make_dependency_string (self, _tmp57_, "overridable requires", _tmp58_, (gint) _tmp58__length1);
#line 562 "src/systemadm.vala"
	_tmp60_ = _tmp59_;
#line 562 "src/systemadm.vala"
	_tmp61_ = requisite;
#line 562 "src/systemadm.vala"
	_tmp61__length1 = requisite_length1;
#line 562 "src/systemadm.vala"
	_tmp62_ = main_window_make_dependency_string (self, _tmp60_, "requisite", _tmp61_, (gint) _tmp61__length1);
#line 562 "src/systemadm.vala"
	_tmp63_ = _tmp62_;
#line 562 "src/systemadm.vala"
	_tmp64_ = requisite_overridable;
#line 562 "src/systemadm.vala"
	_tmp64__length1 = requisite_overridable_length1;
#line 562 "src/systemadm.vala"
	_tmp65_ = main_window_make_dependency_string (self, _tmp63_, "overridable requisite", _tmp64_, (gint) _tmp64__length1);
#line 562 "src/systemadm.vala"
	_tmp66_ = _tmp65_;
#line 562 "src/systemadm.vala"
	_tmp67_ = wants;
#line 562 "src/systemadm.vala"
	_tmp67__length1 = wants_length1;
#line 562 "src/systemadm.vala"
	_tmp68_ = main_window_make_dependency_string (self, _tmp66_, "wants", _tmp67_, (gint) _tmp67__length1);
#line 562 "src/systemadm.vala"
	_tmp69_ = _tmp68_;
#line 562 "src/systemadm.vala"
	_tmp70_ = conflicts;
#line 562 "src/systemadm.vala"
	_tmp70__length1 = conflicts_length1;
#line 562 "src/systemadm.vala"
	_tmp71_ = main_window_make_dependency_string (self, _tmp69_, "conflicts", _tmp70_, (gint) _tmp70__length1);
#line 562 "src/systemadm.vala"
	_tmp72_ = _tmp71_;
#line 562 "src/systemadm.vala"
	_tmp73_ = required_by;
#line 562 "src/systemadm.vala"
	_tmp73__length1 = required_by_length1;
#line 562 "src/systemadm.vala"
	_tmp74_ = main_window_make_dependency_string (self, _tmp72_, "required by", _tmp73_, (gint) _tmp73__length1);
#line 562 "src/systemadm.vala"
	_tmp75_ = _tmp74_;
#line 562 "src/systemadm.vala"
	_tmp76_ = required_by_overridable;
#line 562 "src/systemadm.vala"
	_tmp76__length1 = required_by_overridable_length1;
#line 562 "src/systemadm.vala"
	_tmp77_ = main_window_make_dependency_string (self, _tmp75_, "overridable required by", _tmp76_, (gint) _tmp76__length1);
#line 562 "src/systemadm.vala"
	_tmp78_ = _tmp77_;
#line 562 "src/systemadm.vala"
	_tmp79_ = wanted_by;
#line 562 "src/systemadm.vala"
	_tmp79__length1 = wanted_by_length1;
#line 562 "src/systemadm.vala"
	_tmp80_ = main_window_make_dependency_string (self, _tmp78_, "wanted by", _tmp79_, (gint) _tmp79__length1);
#line 562 "src/systemadm.vala"
	_tmp81_ = _tmp80_;
#line 562 "src/systemadm.vala"
	_tmp82_ = after;
#line 562 "src/systemadm.vala"
	_tmp82__length1 = after_length1;
#line 562 "src/systemadm.vala"
	_tmp83_ = main_window_make_dependency_string (self, _tmp81_, "after", _tmp82_, (gint) _tmp82__length1);
#line 562 "src/systemadm.vala"
	_tmp84_ = _tmp83_;
#line 562 "src/systemadm.vala"
	_tmp85_ = before;
#line 562 "src/systemadm.vala"
	_tmp85__length1 = before_length1;
#line 562 "src/systemadm.vala"
	_tmp86_ = main_window_make_dependency_string (self, _tmp84_, "before", _tmp85_, (gint) _tmp85__length1);
#line 562 "src/systemadm.vala"
	_tmp87_ = _tmp86_;
#line 562 "src/systemadm.vala"
	right_label_set_markup_or_na (_tmp54_, _tmp87_);
#line 562 "src/systemadm.vala"
	_g_free0 (_tmp87_);
#line 562 "src/systemadm.vala"
	_g_free0 (_tmp84_);
#line 562 "src/systemadm.vala"
	_g_free0 (_tmp81_);
#line 562 "src/systemadm.vala"
	_g_free0 (_tmp78_);
#line 562 "src/systemadm.vala"
	_g_free0 (_tmp75_);
#line 562 "src/systemadm.vala"
	_g_free0 (_tmp72_);
#line 562 "src/systemadm.vala"
	_g_free0 (_tmp69_);
#line 562 "src/systemadm.vala"
	_g_free0 (_tmp66_);
#line 562 "src/systemadm.vala"
	_g_free0 (_tmp63_);
#line 562 "src/systemadm.vala"
	_g_free0 (_tmp60_);
#line 562 "src/systemadm.vala"
	_g_free0 (_tmp57_);
#line 586 "src/systemadm.vala"
	_tmp88_ = self->priv->unit_description_label;
#line 586 "src/systemadm.vala"
	_tmp89_ = unit_get_description (unit);
#line 586 "src/systemadm.vala"
	_tmp90_ = _tmp89_;
#line 586 "src/systemadm.vala"
	_tmp91_ = _tmp90_;
#line 586 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp88_, _tmp91_);
#line 586 "src/systemadm.vala"
	_g_free0 (_tmp91_);
#line 587 "src/systemadm.vala"
	_tmp92_ = self->priv->unit_load_state_label;
#line 587 "src/systemadm.vala"
	_tmp93_ = unit_get_load_state (unit);
#line 587 "src/systemadm.vala"
	_tmp94_ = _tmp93_;
#line 587 "src/systemadm.vala"
	_tmp95_ = _tmp94_;
#line 587 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp92_, _tmp95_);
#line 587 "src/systemadm.vala"
	_g_free0 (_tmp95_);
#line 588 "src/systemadm.vala"
	_tmp96_ = self->priv->unit_active_state_label;
#line 588 "src/systemadm.vala"
	_tmp97_ = unit_get_active_state (unit);
#line 588 "src/systemadm.vala"
	_tmp98_ = _tmp97_;
#line 588 "src/systemadm.vala"
	_tmp99_ = _tmp98_;
#line 588 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp96_, _tmp99_);
#line 588 "src/systemadm.vala"
	_g_free0 (_tmp99_);
#line 589 "src/systemadm.vala"
	_tmp100_ = self->priv->unit_sub_state_label;
#line 589 "src/systemadm.vala"
	_tmp101_ = unit_get_sub_state (unit);
#line 589 "src/systemadm.vala"
	_tmp102_ = _tmp101_;
#line 589 "src/systemadm.vala"
	_tmp103_ = _tmp102_;
#line 589 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp100_, _tmp103_);
#line 589 "src/systemadm.vala"
	_g_free0 (_tmp103_);
#line 591 "src/systemadm.vala"
	_tmp104_ = unit_get_fragment_path (unit);
#line 591 "src/systemadm.vala"
	_tmp105_ = _tmp104_;
#line 591 "src/systemadm.vala"
	fp = _tmp105_;
#line 592 "src/systemadm.vala"
	_tmp106_ = fp;
#line 592 "src/systemadm.vala"
	if (g_strcmp0 (_tmp106_, "") != 0) {
#line 5020 "systemadm.c"
		RightLabel* _tmp107_;
		const gchar* _tmp108_;
		gchar* _tmp109_;
		gchar* _tmp110_;
		gchar* _tmp111_;
		gchar* _tmp112_;
		gchar* _tmp113_;
		gchar* _tmp114_;
		const gchar* _tmp115_;
		gchar* _tmp116_;
		gchar* _tmp117_;
		gchar* _tmp118_;
		gchar* _tmp119_;
#line 593 "src/systemadm.vala"
		_tmp107_ = self->priv->unit_fragment_path_label;
#line 593 "src/systemadm.vala"
		_tmp108_ = fp;
#line 593 "src/systemadm.vala"
		_tmp109_ = g_strconcat ("<a href=\"file://", _tmp108_, NULL);
#line 593 "src/systemadm.vala"
		_tmp110_ = _tmp109_;
#line 593 "src/systemadm.vala"
		_tmp111_ = g_strconcat (_tmp110_, "\">", NULL);
#line 593 "src/systemadm.vala"
		_tmp112_ = _tmp111_;
#line 593 "src/systemadm.vala"
		_tmp113_ = g_strconcat (_tmp112_, "<span underline='none' color='black'>", NULL);
#line 593 "src/systemadm.vala"
		_tmp114_ = _tmp113_;
#line 593 "src/systemadm.vala"
		_tmp115_ = fp;
#line 593 "src/systemadm.vala"
		_tmp116_ = g_strconcat (_tmp114_, _tmp115_, NULL);
#line 593 "src/systemadm.vala"
		_tmp117_ = _tmp116_;
#line 593 "src/systemadm.vala"
		_tmp118_ = g_strconcat (_tmp117_, "</span></a>", NULL);
#line 593 "src/systemadm.vala"
		_tmp119_ = _tmp118_;
#line 593 "src/systemadm.vala"
		right_label_set_markup_or_na (_tmp107_, _tmp119_);
#line 593 "src/systemadm.vala"
		_g_free0 (_tmp119_);
#line 593 "src/systemadm.vala"
		_g_free0 (_tmp117_);
#line 593 "src/systemadm.vala"
		_g_free0 (_tmp114_);
#line 593 "src/systemadm.vala"
		_g_free0 (_tmp112_);
#line 593 "src/systemadm.vala"
		_g_free0 (_tmp110_);
#line 5072 "systemadm.c"
	} else {
		RightLabel* _tmp120_;
#line 597 "src/systemadm.vala"
		_tmp120_ = self->priv->unit_fragment_path_label;
#line 597 "src/systemadm.vala"
		right_label_set_text_or_na (_tmp120_, NULL);
#line 5079 "systemadm.c"
	}
#line 600 "src/systemadm.vala"
	_tmp121_ = self->priv->unit_active_enter_timestamp_label;
#line 600 "src/systemadm.vala"
	_tmp122_ = unit_get_active_enter_timestamp (unit);
#line 600 "src/systemadm.vala"
	_tmp123_ = _tmp122_;
#line 600 "src/systemadm.vala"
	_tmp124_ = format_time (_tmp123_);
#line 600 "src/systemadm.vala"
	_tmp125_ = _tmp124_;
#line 600 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp121_, _tmp125_);
#line 600 "src/systemadm.vala"
	_g_free0 (_tmp125_);
#line 602 "src/systemadm.vala"
	_tmp126_ = self->priv->unit_active_exit_timestamp_label;
#line 602 "src/systemadm.vala"
	_tmp127_ = unit_get_active_exit_timestamp (unit);
#line 602 "src/systemadm.vala"
	_tmp128_ = _tmp127_;
#line 602 "src/systemadm.vala"
	_tmp129_ = format_time (_tmp128_);
#line 602 "src/systemadm.vala"
	_tmp130_ = _tmp129_;
#line 602 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp126_, _tmp130_);
#line 602 "src/systemadm.vala"
	_g_free0 (_tmp130_);
#line 604 "src/systemadm.vala"
	_tmp131_ = unit_get_can_start (unit);
#line 604 "src/systemadm.vala"
	_tmp132_ = _tmp131_;
#line 604 "src/systemadm.vala"
	b = _tmp132_;
#line 605 "src/systemadm.vala"
	_tmp133_ = self->priv->start_button;
#line 605 "src/systemadm.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp133_, b);
#line 606 "src/systemadm.vala"
	_tmp134_ = self->priv->stop_button;
#line 606 "src/systemadm.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp134_, b);
#line 607 "src/systemadm.vala"
	_tmp135_ = self->priv->restart_button;
#line 607 "src/systemadm.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp135_, b);
#line 608 "src/systemadm.vala"
	if (b) {
#line 608 "src/systemadm.vala"
		_tmp136_ = "Yes";
#line 5131 "systemadm.c"
	} else {
#line 608 "src/systemadm.vala"
		_tmp136_ = "No";
#line 5135 "systemadm.c"
	}
#line 608 "src/systemadm.vala"
	_tmp137_ = self->priv->unit_can_start_label;
#line 608 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp137_, _tmp136_);
#line 610 "src/systemadm.vala"
	_tmp138_ = unit_get_can_reload (unit);
#line 610 "src/systemadm.vala"
	_tmp139_ = _tmp138_;
#line 610 "src/systemadm.vala"
	b = _tmp139_;
#line 611 "src/systemadm.vala"
	_tmp140_ = self->priv->reload_button;
#line 611 "src/systemadm.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp140_, b);
#line 612 "src/systemadm.vala"
	if (b) {
#line 612 "src/systemadm.vala"
		_tmp141_ = "Yes";
#line 5155 "systemadm.c"
	} else {
#line 612 "src/systemadm.vala"
		_tmp141_ = "No";
#line 5159 "systemadm.c"
	}
#line 612 "src/systemadm.vala"
	_tmp142_ = self->priv->unit_can_reload_label;
#line 612 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp142_, _tmp141_);
#line 614 "src/systemadm.vala"
	_tmp143_ = self->priv->unit_cgroup_label;
#line 614 "src/systemadm.vala"
	_tmp144_ = unit_get_default_control_group (unit);
#line 614 "src/systemadm.vala"
	_tmp145_ = _tmp144_;
#line 614 "src/systemadm.vala"
	_tmp146_ = _tmp145_;
#line 614 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp143_, _tmp146_);
#line 614 "src/systemadm.vala"
	_g_free0 (_tmp146_);
#line 528 "src/systemadm.vala"
	_g_free0 (fp);
#line 528 "src/systemadm.vala"
	after = (_vala_array_free (after, after_length1, (GDestroyNotify) g_free), NULL);
#line 528 "src/systemadm.vala"
	before = (_vala_array_free (before, before_length1, (GDestroyNotify) g_free), NULL);
#line 528 "src/systemadm.vala"
	conflicts = (_vala_array_free (conflicts, conflicts_length1, (GDestroyNotify) g_free), NULL);
#line 528 "src/systemadm.vala"
	wanted_by = (_vala_array_free (wanted_by, wanted_by_length1, (GDestroyNotify) g_free), NULL);
#line 528 "src/systemadm.vala"
	required_by_overridable = (_vala_array_free (required_by_overridable, required_by_overridable_length1, (GDestroyNotify) g_free), NULL);
#line 528 "src/systemadm.vala"
	required_by = (_vala_array_free (required_by, required_by_length1, (GDestroyNotify) g_free), NULL);
#line 528 "src/systemadm.vala"
	wants = (_vala_array_free (wants, wants_length1, (GDestroyNotify) g_free), NULL);
#line 528 "src/systemadm.vala"
	requisite_overridable = (_vala_array_free (requisite_overridable, requisite_overridable_length1, (GDestroyNotify) g_free), NULL);
#line 528 "src/systemadm.vala"
	requisite = (_vala_array_free (requisite, requisite_length1, (GDestroyNotify) g_free), NULL);
#line 528 "src/systemadm.vala"
	requires_overridable = (_vala_array_free (requires_overridable, requires_overridable_length1, (GDestroyNotify) g_free), NULL);
#line 528 "src/systemadm.vala"
	requires = (_vala_array_free (requires, requires_length1, (GDestroyNotify) g_free), NULL);
#line 528 "src/systemadm.vala"
	_g_free0 (id_display);
#line 5203 "systemadm.c"
}

Job*
main_window_get_current_job (MainWindow* self)
{
	GtkTreePath* p = NULL;
	GtkTreeView* _tmp0_;
	GtkTreePath* _tmp1_ = NULL;
	GtkTreePath* _tmp2_;
	GtkTreeIter iter = {0};
	GtkTreeModel* model = NULL;
	GtkTreeView* _tmp3_;
	GtkTreeModel* _tmp4_;
	GtkTreeModel* _tmp5_;
	Job* j = NULL;
	GtkTreeModel* _tmp6_;
	GtkTreePath* _tmp7_;
	GtkTreeIter _tmp8_ = {0};
	GtkTreeModel* _tmp9_;
	GtkTreeIter _tmp10_;
	Job* _tmp11_ = NULL;
	Job* _tmp12_;
	Job* _tmp13_;
	Job* result;
#line 617 "src/systemadm.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 619 "src/systemadm.vala"
	_tmp0_ = self->priv->job_view;
#line 619 "src/systemadm.vala"
	gtk_tree_view_get_cursor (_tmp0_, &_tmp1_, NULL);
#line 619 "src/systemadm.vala"
	__vala_GtkTreePath_free0 (p);
#line 619 "src/systemadm.vala"
	p = _tmp1_;
#line 621 "src/systemadm.vala"
	_tmp2_ = p;
#line 621 "src/systemadm.vala"
	if (_tmp2_ == NULL) {
#line 622 "src/systemadm.vala"
		result = NULL;
#line 622 "src/systemadm.vala"
		__vala_GtkTreePath_free0 (p);
#line 622 "src/systemadm.vala"
		return result;
#line 5248 "systemadm.c"
	}
#line 625 "src/systemadm.vala"
	_tmp3_ = self->priv->job_view;
#line 625 "src/systemadm.vala"
	_tmp4_ = gtk_tree_view_get_model (_tmp3_);
#line 625 "src/systemadm.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 625 "src/systemadm.vala"
	model = _tmp5_;
#line 628 "src/systemadm.vala"
	_tmp6_ = model;
#line 628 "src/systemadm.vala"
	_tmp7_ = p;
#line 628 "src/systemadm.vala"
	gtk_tree_model_get_iter (_tmp6_, &_tmp8_, _tmp7_);
#line 628 "src/systemadm.vala"
	iter = _tmp8_;
#line 629 "src/systemadm.vala"
	_tmp9_ = model;
#line 629 "src/systemadm.vala"
	_tmp10_ = iter;
#line 629 "src/systemadm.vala"
	gtk_tree_model_get (_tmp9_, &_tmp10_, 4, &_tmp11_, -1);
#line 629 "src/systemadm.vala"
	j = _tmp11_;
#line 631 "src/systemadm.vala"
	_tmp12_ = j;
#line 631 "src/systemadm.vala"
	_tmp13_ = _g_object_ref0 (_tmp12_);
#line 631 "src/systemadm.vala"
	result = _tmp13_;
#line 631 "src/systemadm.vala"
	_g_object_unref0 (model);
#line 631 "src/systemadm.vala"
	__vala_GtkTreePath_free0 (p);
#line 631 "src/systemadm.vala"
	return result;
#line 5286 "systemadm.c"
}

void
main_window_job_changed (MainWindow* self)
{
	Job* j = NULL;
	Job* _tmp0_;
	Job* _tmp1_;
#line 634 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 635 "src/systemadm.vala"
	_tmp0_ = main_window_get_current_job (self);
#line 635 "src/systemadm.vala"
	j = _tmp0_;
#line 637 "src/systemadm.vala"
	_tmp1_ = j;
#line 637 "src/systemadm.vala"
	if (_tmp1_ == NULL) {
#line 638 "src/systemadm.vala"
		main_window_clear_job (self);
#line 5307 "systemadm.c"
	} else {
		Job* _tmp2_;
#line 640 "src/systemadm.vala"
		_tmp2_ = j;
#line 640 "src/systemadm.vala"
		main_window_show_job (self, _tmp2_);
#line 5314 "systemadm.c"
	}
#line 634 "src/systemadm.vala"
	_g_object_unref0 (j);
#line 5318 "systemadm.c"
}

void
main_window_clear_job (MainWindow* self)
{
	RightLabel* _tmp0_;
	RightLabel* _tmp1_;
	RightLabel* _tmp2_;
	GtkButton* _tmp3_;
#line 643 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 644 "src/systemadm.vala"
	self->priv->current_job_id = (guint32) 0;
#line 646 "src/systemadm.vala"
	_tmp0_ = self->priv->job_id_label;
#line 646 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp0_, NULL);
#line 647 "src/systemadm.vala"
	_tmp1_ = self->priv->job_state_label;
#line 647 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp1_, NULL);
#line 648 "src/systemadm.vala"
	_tmp2_ = self->priv->job_type_label;
#line 648 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp2_, NULL);
#line 650 "src/systemadm.vala"
	_tmp3_ = self->priv->cancel_button;
#line 650 "src/systemadm.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp3_, FALSE);
#line 5348 "systemadm.c"
}

void
main_window_show_job (MainWindow* self,
                      Job* job)
{
	guint32 _tmp0_;
	guint32 _tmp1_;
	RightLabel* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	RightLabel* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	RightLabel* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	GtkButton* _tmp13_;
#line 653 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 653 "src/systemadm.vala"
	g_return_if_fail (job != NULL);
#line 654 "src/systemadm.vala"
	_tmp0_ = job_get_id (job);
#line 654 "src/systemadm.vala"
	_tmp1_ = _tmp0_;
#line 654 "src/systemadm.vala"
	self->priv->current_job_id = _tmp1_;
#line 656 "src/systemadm.vala"
	_tmp2_ = self->priv->job_id_label;
#line 656 "src/systemadm.vala"
	_tmp3_ = g_strdup_printf ("%u", (guint) self->priv->current_job_id);
#line 656 "src/systemadm.vala"
	_tmp4_ = _tmp3_;
#line 656 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp2_, _tmp4_);
#line 656 "src/systemadm.vala"
	_g_free0 (_tmp4_);
#line 657 "src/systemadm.vala"
	_tmp5_ = self->priv->job_state_label;
#line 657 "src/systemadm.vala"
	_tmp6_ = job_get_state (job);
#line 657 "src/systemadm.vala"
	_tmp7_ = _tmp6_;
#line 657 "src/systemadm.vala"
	_tmp8_ = _tmp7_;
#line 657 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp5_, _tmp8_);
#line 657 "src/systemadm.vala"
	_g_free0 (_tmp8_);
#line 658 "src/systemadm.vala"
	_tmp9_ = self->priv->job_type_label;
#line 658 "src/systemadm.vala"
	_tmp10_ = job_get_job_type (job);
#line 658 "src/systemadm.vala"
	_tmp11_ = _tmp10_;
#line 658 "src/systemadm.vala"
	_tmp12_ = _tmp11_;
#line 658 "src/systemadm.vala"
	right_label_set_text_or_na (_tmp9_, _tmp12_);
#line 658 "src/systemadm.vala"
	_g_free0 (_tmp12_);
#line 660 "src/systemadm.vala"
	_tmp13_ = self->priv->cancel_button;
#line 660 "src/systemadm.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp13_, TRUE);
#line 5417 "systemadm.c"
}

void
main_window_on_start (MainWindow* self)
{
	Unit* u = NULL;
	Unit* _tmp0_;
	Unit* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 663 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 664 "src/systemadm.vala"
	_tmp0_ = main_window_get_current_unit (self);
#line 664 "src/systemadm.vala"
	u = _tmp0_;
#line 666 "src/systemadm.vala"
	_tmp1_ = u;
#line 666 "src/systemadm.vala"
	if (_tmp1_ == NULL) {
#line 667 "src/systemadm.vala"
		_g_object_unref0 (u);
#line 667 "src/systemadm.vala"
		return;
#line 5441 "systemadm.c"
	}
	{
		Unit* _tmp2_;
		char* _tmp3_;
		char* _tmp4_;
#line 670 "src/systemadm.vala"
		_tmp2_ = u;
#line 670 "src/systemadm.vala"
		_tmp3_ = unit_start (_tmp2_, "replace", &_inner_error0_);
#line 670 "src/systemadm.vala"
		_tmp4_ = _tmp3_;
#line 670 "src/systemadm.vala"
		_g_free0 (_tmp4_);
#line 670 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5457 "systemadm.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp5_;
#line 669 "src/systemadm.vala"
		e = _inner_error0_;
#line 669 "src/systemadm.vala"
		_inner_error0_ = NULL;
#line 672 "src/systemadm.vala"
		_tmp5_ = e;
#line 672 "src/systemadm.vala"
		main_window_show_error (self, _tmp5_);
#line 669 "src/systemadm.vala"
		_g_error_free0 (e);
#line 5476 "systemadm.c"
	}
	__finally0:
#line 669 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 669 "src/systemadm.vala"
		_g_object_unref0 (u);
#line 669 "src/systemadm.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 669 "src/systemadm.vala"
		g_clear_error (&_inner_error0_);
#line 669 "src/systemadm.vala"
		return;
#line 5489 "systemadm.c"
	}
#line 663 "src/systemadm.vala"
	_g_object_unref0 (u);
#line 5493 "systemadm.c"
}

void
main_window_on_stop (MainWindow* self)
{
	Unit* u = NULL;
	Unit* _tmp0_;
	Unit* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 676 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 677 "src/systemadm.vala"
	_tmp0_ = main_window_get_current_unit (self);
#line 677 "src/systemadm.vala"
	u = _tmp0_;
#line 679 "src/systemadm.vala"
	_tmp1_ = u;
#line 679 "src/systemadm.vala"
	if (_tmp1_ == NULL) {
#line 680 "src/systemadm.vala"
		_g_object_unref0 (u);
#line 680 "src/systemadm.vala"
		return;
#line 5517 "systemadm.c"
	}
	{
		Unit* _tmp2_;
		char* _tmp3_;
		char* _tmp4_;
#line 683 "src/systemadm.vala"
		_tmp2_ = u;
#line 683 "src/systemadm.vala"
		_tmp3_ = unit_stop (_tmp2_, "replace", &_inner_error0_);
#line 683 "src/systemadm.vala"
		_tmp4_ = _tmp3_;
#line 683 "src/systemadm.vala"
		_g_free0 (_tmp4_);
#line 683 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5533 "systemadm.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp5_;
#line 682 "src/systemadm.vala"
		e = _inner_error0_;
#line 682 "src/systemadm.vala"
		_inner_error0_ = NULL;
#line 685 "src/systemadm.vala"
		_tmp5_ = e;
#line 685 "src/systemadm.vala"
		main_window_show_error (self, _tmp5_);
#line 682 "src/systemadm.vala"
		_g_error_free0 (e);
#line 5552 "systemadm.c"
	}
	__finally0:
#line 682 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 682 "src/systemadm.vala"
		_g_object_unref0 (u);
#line 682 "src/systemadm.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 682 "src/systemadm.vala"
		g_clear_error (&_inner_error0_);
#line 682 "src/systemadm.vala"
		return;
#line 5565 "systemadm.c"
	}
#line 676 "src/systemadm.vala"
	_g_object_unref0 (u);
#line 5569 "systemadm.c"
}

void
main_window_on_reload (MainWindow* self)
{
	Unit* u = NULL;
	Unit* _tmp0_;
	Unit* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 689 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 690 "src/systemadm.vala"
	_tmp0_ = main_window_get_current_unit (self);
#line 690 "src/systemadm.vala"
	u = _tmp0_;
#line 692 "src/systemadm.vala"
	_tmp1_ = u;
#line 692 "src/systemadm.vala"
	if (_tmp1_ == NULL) {
#line 693 "src/systemadm.vala"
		_g_object_unref0 (u);
#line 693 "src/systemadm.vala"
		return;
#line 5593 "systemadm.c"
	}
	{
		Unit* _tmp2_;
		char* _tmp3_;
		char* _tmp4_;
#line 696 "src/systemadm.vala"
		_tmp2_ = u;
#line 696 "src/systemadm.vala"
		_tmp3_ = unit_reload (_tmp2_, "replace", &_inner_error0_);
#line 696 "src/systemadm.vala"
		_tmp4_ = _tmp3_;
#line 696 "src/systemadm.vala"
		_g_free0 (_tmp4_);
#line 696 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5609 "systemadm.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp5_;
#line 695 "src/systemadm.vala"
		e = _inner_error0_;
#line 695 "src/systemadm.vala"
		_inner_error0_ = NULL;
#line 698 "src/systemadm.vala"
		_tmp5_ = e;
#line 698 "src/systemadm.vala"
		main_window_show_error (self, _tmp5_);
#line 695 "src/systemadm.vala"
		_g_error_free0 (e);
#line 5628 "systemadm.c"
	}
	__finally0:
#line 695 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 695 "src/systemadm.vala"
		_g_object_unref0 (u);
#line 695 "src/systemadm.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 695 "src/systemadm.vala"
		g_clear_error (&_inner_error0_);
#line 695 "src/systemadm.vala"
		return;
#line 5641 "systemadm.c"
	}
#line 689 "src/systemadm.vala"
	_g_object_unref0 (u);
#line 5645 "systemadm.c"
}

void
main_window_on_restart (MainWindow* self)
{
	Unit* u = NULL;
	Unit* _tmp0_;
	Unit* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 702 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 703 "src/systemadm.vala"
	_tmp0_ = main_window_get_current_unit (self);
#line 703 "src/systemadm.vala"
	u = _tmp0_;
#line 705 "src/systemadm.vala"
	_tmp1_ = u;
#line 705 "src/systemadm.vala"
	if (_tmp1_ == NULL) {
#line 706 "src/systemadm.vala"
		_g_object_unref0 (u);
#line 706 "src/systemadm.vala"
		return;
#line 5669 "systemadm.c"
	}
	{
		Unit* _tmp2_;
		char* _tmp3_;
		char* _tmp4_;
#line 709 "src/systemadm.vala"
		_tmp2_ = u;
#line 709 "src/systemadm.vala"
		_tmp3_ = unit_restart (_tmp2_, "replace", &_inner_error0_);
#line 709 "src/systemadm.vala"
		_tmp4_ = _tmp3_;
#line 709 "src/systemadm.vala"
		_g_free0 (_tmp4_);
#line 709 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5685 "systemadm.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp5_;
#line 708 "src/systemadm.vala"
		e = _inner_error0_;
#line 708 "src/systemadm.vala"
		_inner_error0_ = NULL;
#line 711 "src/systemadm.vala"
		_tmp5_ = e;
#line 711 "src/systemadm.vala"
		main_window_show_error (self, _tmp5_);
#line 708 "src/systemadm.vala"
		_g_error_free0 (e);
#line 5704 "systemadm.c"
	}
	__finally0:
#line 708 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 708 "src/systemadm.vala"
		_g_object_unref0 (u);
#line 708 "src/systemadm.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 708 "src/systemadm.vala"
		g_clear_error (&_inner_error0_);
#line 708 "src/systemadm.vala"
		return;
#line 5717 "systemadm.c"
	}
#line 702 "src/systemadm.vala"
	_g_object_unref0 (u);
#line 5721 "systemadm.c"
}

void
main_window_on_cancel (MainWindow* self)
{
	Job* j = NULL;
	Job* _tmp0_;
	Job* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 715 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 716 "src/systemadm.vala"
	_tmp0_ = main_window_get_current_job (self);
#line 716 "src/systemadm.vala"
	j = _tmp0_;
#line 718 "src/systemadm.vala"
	_tmp1_ = j;
#line 718 "src/systemadm.vala"
	if (_tmp1_ == NULL) {
#line 719 "src/systemadm.vala"
		_g_object_unref0 (j);
#line 719 "src/systemadm.vala"
		return;
#line 5745 "systemadm.c"
	}
	{
		Job* _tmp2_;
#line 722 "src/systemadm.vala"
		_tmp2_ = j;
#line 722 "src/systemadm.vala"
		job_cancel (_tmp2_, &_inner_error0_);
#line 722 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5755 "systemadm.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp3_;
#line 721 "src/systemadm.vala"
		e = _inner_error0_;
#line 721 "src/systemadm.vala"
		_inner_error0_ = NULL;
#line 724 "src/systemadm.vala"
		_tmp3_ = e;
#line 724 "src/systemadm.vala"
		main_window_show_error (self, _tmp3_);
#line 721 "src/systemadm.vala"
		_g_error_free0 (e);
#line 5774 "systemadm.c"
	}
	__finally0:
#line 721 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 721 "src/systemadm.vala"
		_g_object_unref0 (j);
#line 721 "src/systemadm.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 721 "src/systemadm.vala"
		g_clear_error (&_inner_error0_);
#line 721 "src/systemadm.vala"
		return;
#line 5787 "systemadm.c"
	}
#line 715 "src/systemadm.vala"
	_g_object_unref0 (j);
#line 5791 "systemadm.c"
}

void
main_window_update_unit_iter (MainWindow* self,
                              GtkTreeIter* iter,
                              const gchar* id,
                              Unit* u)
{
	GError* _inner_error0_ = NULL;
#line 728 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 728 "src/systemadm.vala"
	g_return_if_fail (iter != NULL);
#line 728 "src/systemadm.vala"
	g_return_if_fail (id != NULL);
#line 728 "src/systemadm.vala"
	g_return_if_fail (u != NULL);
#line 5809 "systemadm.c"
	{
		gchar* t = NULL;
		gchar* _tmp0_;
		UnitJobLink jl = {0};
		UnitJobLink _tmp1_ = {0};
		UnitJobLink _tmp2_;
		UnitJobLink _tmp3_;
		gchar* _tmp11_ = NULL;
		const gchar* _tmp12_;
		GtkListStore* _tmp16_;
		GtkTreeIter _tmp17_;
		gchar* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
#line 731 "src/systemadm.vala"
		_tmp0_ = g_strdup ("");
#line 731 "src/systemadm.vala"
		t = _tmp0_;
#line 732 "src/systemadm.vala"
		unit_get_job (u, &_tmp1_);
#line 732 "src/systemadm.vala"
		_tmp2_ = _tmp1_;
#line 732 "src/systemadm.vala"
		jl = _tmp2_;
#line 734 "src/systemadm.vala"
		_tmp3_ = jl;
#line 734 "src/systemadm.vala"
		if (_tmp3_.id != ((guint32) 0)) {
#line 5847 "systemadm.c"
			GBusType _tmp4_ = 0;
			Job* j = NULL;
			UnitJobLink _tmp5_;
			const char* _tmp6_;
			Job* _tmp7_;
			Job* _tmp8_;
			gchar* _tmp9_;
			gchar* _tmp10_;
#line 736 "src/systemadm.vala"
			if (user) {
#line 736 "src/systemadm.vala"
				_tmp4_ = G_BUS_TYPE_SESSION;
#line 5860 "systemadm.c"
			} else {
#line 736 "src/systemadm.vala"
				_tmp4_ = G_BUS_TYPE_SYSTEM;
#line 5864 "systemadm.c"
			}
#line 735 "src/systemadm.vala"
			_tmp5_ = jl;
#line 735 "src/systemadm.vala"
			_tmp6_ = _tmp5_.path;
#line 735 "src/systemadm.vala"
			_tmp7_ = (Job*) g_initable_new (TYPE_JOB_PROXY, NULL, &_inner_error0_, "g-flags", 0, "g-name", "org.freedesktop.systemd1", "g-bus-type", _tmp4_, "g-object-path", (const gchar*) _tmp6_, "g-interface-name", "org.freedesktop.systemd1.Job", NULL);
#line 735 "src/systemadm.vala"
			j = (Job*) _tmp7_;
#line 735 "src/systemadm.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 735 "src/systemadm.vala"
				unit_job_link_destroy (&jl);
#line 735 "src/systemadm.vala"
				_g_free0 (t);
#line 5880 "systemadm.c"
				goto __catch0_g_error;
			}
#line 740 "src/systemadm.vala"
			_tmp8_ = j;
#line 740 "src/systemadm.vala"
			_tmp9_ = job_get_job_type (_tmp8_);
#line 740 "src/systemadm.vala"
			_tmp10_ = _tmp9_;
#line 740 "src/systemadm.vala"
			_g_free0 (t);
#line 740 "src/systemadm.vala"
			t = _tmp10_;
#line 734 "src/systemadm.vala"
			_g_object_unref0 (j);
#line 5895 "systemadm.c"
		}
#line 749 "src/systemadm.vala"
		_tmp12_ = t;
#line 749 "src/systemadm.vala"
		if (g_strcmp0 (_tmp12_, "") != 0) {
#line 5901 "systemadm.c"
			const gchar* _tmp13_;
			gchar* _tmp14_;
#line 749 "src/systemadm.vala"
			_tmp13_ = t;
#line 749 "src/systemadm.vala"
			_tmp14_ = g_strdup_printf ("→ %s", _tmp13_);
#line 749 "src/systemadm.vala"
			_g_free0 (_tmp11_);
#line 749 "src/systemadm.vala"
			_tmp11_ = _tmp14_;
#line 5912 "systemadm.c"
		} else {
			gchar* _tmp15_;
#line 749 "src/systemadm.vala"
			_tmp15_ = g_strdup ("");
#line 749 "src/systemadm.vala"
			_g_free0 (_tmp11_);
#line 749 "src/systemadm.vala"
			_tmp11_ = _tmp15_;
#line 5921 "systemadm.c"
		}
#line 743 "src/systemadm.vala"
		_tmp16_ = self->priv->unit_model;
#line 743 "src/systemadm.vala"
		_tmp17_ = *iter;
#line 743 "src/systemadm.vala"
		_tmp18_ = unit_get_description (u);
#line 743 "src/systemadm.vala"
		_tmp19_ = _tmp18_;
#line 743 "src/systemadm.vala"
		_tmp20_ = _tmp19_;
#line 743 "src/systemadm.vala"
		_tmp21_ = unit_get_load_state (u);
#line 743 "src/systemadm.vala"
		_tmp22_ = _tmp21_;
#line 743 "src/systemadm.vala"
		_tmp23_ = _tmp22_;
#line 743 "src/systemadm.vala"
		_tmp24_ = unit_get_active_state (u);
#line 743 "src/systemadm.vala"
		_tmp25_ = _tmp24_;
#line 743 "src/systemadm.vala"
		_tmp26_ = _tmp25_;
#line 743 "src/systemadm.vala"
		_tmp27_ = unit_get_sub_state (u);
#line 743 "src/systemadm.vala"
		_tmp28_ = _tmp27_;
#line 743 "src/systemadm.vala"
		_tmp29_ = _tmp28_;
#line 743 "src/systemadm.vala"
		gtk_list_store_set (_tmp16_, &_tmp17_, 0, id, 1, _tmp20_, 2, _tmp23_, 3, _tmp26_, 4, _tmp29_, 5, _tmp11_, 6, u, -1);
#line 743 "src/systemadm.vala"
		_g_free0 (_tmp29_);
#line 743 "src/systemadm.vala"
		_g_free0 (_tmp26_);
#line 743 "src/systemadm.vala"
		_g_free0 (_tmp23_);
#line 743 "src/systemadm.vala"
		_g_free0 (_tmp20_);
#line 730 "src/systemadm.vala"
		_g_free0 (_tmp11_);
#line 730 "src/systemadm.vala"
		unit_job_link_destroy (&jl);
#line 730 "src/systemadm.vala"
		_g_free0 (t);
#line 5967 "systemadm.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp30_;
#line 730 "src/systemadm.vala"
		e = _inner_error0_;
#line 730 "src/systemadm.vala"
		_inner_error0_ = NULL;
#line 752 "src/systemadm.vala"
		_tmp30_ = e;
#line 752 "src/systemadm.vala"
		main_window_show_error (self, _tmp30_);
#line 730 "src/systemadm.vala"
		_g_error_free0 (e);
#line 5984 "systemadm.c"
	}
	__finally0:
#line 730 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 730 "src/systemadm.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 730 "src/systemadm.vala"
		g_clear_error (&_inner_error0_);
#line 730 "src/systemadm.vala"
		return;
#line 5995 "systemadm.c"
	}
}

void
main_window_on_unit_new (MainWindow* self,
                         const gchar* id,
                         const char* path)
{
	GError* _inner_error0_ = NULL;
#line 756 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 756 "src/systemadm.vala"
	g_return_if_fail (id != NULL);
#line 756 "src/systemadm.vala"
	g_return_if_fail (path != NULL);
#line 6011 "systemadm.c"
	{
		GBusType _tmp0_ = 0;
		Properties* p = NULL;
		Properties* _tmp1_;
		Properties* _tmp2_;
		GtkTreeIter iter = {0};
		GtkListStore* _tmp3_;
		GtkTreeIter _tmp4_ = {0};
		GBusType _tmp5_ = 0;
		Unit* u = NULL;
		Unit* _tmp6_;
		GeeHashMap* _tmp7_;
		Unit* _tmp8_;
		GtkTreeIter _tmp9_;
		Unit* _tmp10_;
#line 760 "src/systemadm.vala"
		if (user) {
#line 760 "src/systemadm.vala"
			_tmp0_ = G_BUS_TYPE_SESSION;
#line 6031 "systemadm.c"
		} else {
#line 760 "src/systemadm.vala"
			_tmp0_ = G_BUS_TYPE_SYSTEM;
#line 6035 "systemadm.c"
		}
#line 759 "src/systemadm.vala"
		_tmp1_ = (Properties*) g_initable_new (TYPE_PROPERTIES_PROXY, NULL, &_inner_error0_, "g-flags", 0, "g-name", "org.freedesktop.systemd1", "g-bus-type", _tmp0_, "g-object-path", (const gchar*) path, "g-interface-name", "org.freedesktop.Properties", NULL);
#line 759 "src/systemadm.vala"
		p = (Properties*) _tmp1_;
#line 759 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 6043 "systemadm.c"
			goto __catch0_g_error;
		}
#line 764 "src/systemadm.vala"
		_tmp2_ = p;
#line 764 "src/systemadm.vala"
		g_signal_connect_object (_tmp2_, "properties-changed", (GCallback) _main_window_on_unit_changed_properties_properties_changed, self, 0);
#line 767 "src/systemadm.vala"
		_tmp3_ = self->priv->unit_model;
#line 767 "src/systemadm.vala"
		gtk_list_store_append (_tmp3_, &_tmp4_);
#line 767 "src/systemadm.vala"
		iter = _tmp4_;
#line 770 "src/systemadm.vala"
		if (user) {
#line 770 "src/systemadm.vala"
			_tmp5_ = G_BUS_TYPE_SESSION;
#line 6060 "systemadm.c"
		} else {
#line 770 "src/systemadm.vala"
			_tmp5_ = G_BUS_TYPE_SYSTEM;
#line 6064 "systemadm.c"
		}
#line 769 "src/systemadm.vala"
		_tmp6_ = (Unit*) g_initable_new (TYPE_UNIT_PROXY, NULL, &_inner_error0_, "g-flags", 0, "g-name", "org.freedesktop.systemd1", "g-bus-type", _tmp5_, "g-object-path", (const gchar*) path, "g-interface-name", "org.freedesktop.systemd1.Unit", NULL);
#line 769 "src/systemadm.vala"
		u = (Unit*) _tmp6_;
#line 769 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 769 "src/systemadm.vala"
			_g_object_unref0 (p);
#line 6074 "systemadm.c"
			goto __catch0_g_error;
		}
#line 774 "src/systemadm.vala"
		_tmp7_ = self->priv->unit_map;
#line 774 "src/systemadm.vala"
		_tmp8_ = u;
#line 774 "src/systemadm.vala"
		gee_abstract_map_set ((GeeAbstractMap*) _tmp7_, id, _tmp8_);
#line 776 "src/systemadm.vala"
		_tmp9_ = iter;
#line 776 "src/systemadm.vala"
		_tmp10_ = u;
#line 776 "src/systemadm.vala"
		main_window_update_unit_iter (self, &_tmp9_, id, _tmp10_);
#line 757 "src/systemadm.vala"
		_g_object_unref0 (u);
#line 757 "src/systemadm.vala"
		_g_object_unref0 (p);
#line 6093 "systemadm.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp11_;
#line 757 "src/systemadm.vala"
		e = _inner_error0_;
#line 757 "src/systemadm.vala"
		_inner_error0_ = NULL;
#line 778 "src/systemadm.vala"
		_tmp11_ = e;
#line 778 "src/systemadm.vala"
		main_window_show_error (self, _tmp11_);
#line 757 "src/systemadm.vala"
		_g_error_free0 (e);
#line 6110 "systemadm.c"
	}
	__finally0:
#line 757 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 757 "src/systemadm.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 757 "src/systemadm.vala"
		g_clear_error (&_inner_error0_);
#line 757 "src/systemadm.vala"
		return;
#line 6121 "systemadm.c"
	}
}

void
main_window_update_job_iter (MainWindow* self,
                             GtkTreeIter* iter,
                             guint32 id,
                             Job* j)
{
	GtkListStore* _tmp0_;
	GtkTreeIter _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	JobUnitLink _tmp4_ = {0};
	JobUnitLink _tmp5_;
	JobUnitLink _tmp6_;
	const gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
#line 782 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 782 "src/systemadm.vala"
	g_return_if_fail (iter != NULL);
#line 782 "src/systemadm.vala"
	g_return_if_fail (j != NULL);
#line 783 "src/systemadm.vala"
	_tmp0_ = self->priv->job_model;
#line 783 "src/systemadm.vala"
	_tmp1_ = *iter;
#line 783 "src/systemadm.vala"
	_tmp2_ = g_strdup_printf ("%u", (guint) id);
#line 783 "src/systemadm.vala"
	_tmp3_ = _tmp2_;
#line 783 "src/systemadm.vala"
	job_get_unit (j, &_tmp4_);
#line 783 "src/systemadm.vala"
	_tmp5_ = _tmp4_;
#line 783 "src/systemadm.vala"
	_tmp6_ = _tmp5_;
#line 783 "src/systemadm.vala"
	_tmp7_ = _tmp6_.id;
#line 783 "src/systemadm.vala"
	_tmp8_ = job_get_job_type (j);
#line 783 "src/systemadm.vala"
	_tmp9_ = _tmp8_;
#line 783 "src/systemadm.vala"
	_tmp10_ = _tmp9_;
#line 783 "src/systemadm.vala"
	_tmp11_ = g_strdup_printf ("→ %s", _tmp10_);
#line 783 "src/systemadm.vala"
	_tmp12_ = _tmp11_;
#line 783 "src/systemadm.vala"
	_tmp13_ = job_get_state (j);
#line 783 "src/systemadm.vala"
	_tmp14_ = _tmp13_;
#line 783 "src/systemadm.vala"
	_tmp15_ = _tmp14_;
#line 783 "src/systemadm.vala"
	gtk_list_store_set (_tmp0_, &_tmp1_, 0, _tmp3_, 1, _tmp7_, 2, _tmp12_, 3, _tmp15_, 4, j, 5, id, -1);
#line 783 "src/systemadm.vala"
	_g_free0 (_tmp15_);
#line 783 "src/systemadm.vala"
	_g_free0 (_tmp12_);
#line 783 "src/systemadm.vala"
	_g_free0 (_tmp10_);
#line 783 "src/systemadm.vala"
	job_unit_link_destroy (&_tmp6_);
#line 783 "src/systemadm.vala"
	_g_free0 (_tmp3_);
#line 6197 "systemadm.c"
}

void
main_window_on_job_new (MainWindow* self,
                        guint32 id,
                        const char* path)
{
	GError* _inner_error0_ = NULL;
#line 792 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 792 "src/systemadm.vala"
	g_return_if_fail (path != NULL);
#line 6210 "systemadm.c"
	{
		GBusType _tmp0_ = 0;
		Properties* p = NULL;
		Properties* _tmp1_;
		Properties* _tmp2_;
		GtkTreeIter iter = {0};
		GtkListStore* _tmp3_;
		GtkTreeIter _tmp4_ = {0};
		GBusType _tmp5_ = 0;
		Job* j = NULL;
		Job* _tmp6_;
		GtkTreeIter _tmp7_;
		Job* _tmp8_;
#line 797 "src/systemadm.vala"
		if (user) {
#line 797 "src/systemadm.vala"
			_tmp0_ = G_BUS_TYPE_SESSION;
#line 6228 "systemadm.c"
		} else {
#line 797 "src/systemadm.vala"
			_tmp0_ = G_BUS_TYPE_SYSTEM;
#line 6232 "systemadm.c"
		}
#line 796 "src/systemadm.vala"
		_tmp1_ = (Properties*) g_initable_new (TYPE_PROPERTIES_PROXY, NULL, &_inner_error0_, "g-flags", 0, "g-name", "org.freedesktop.systemd1", "g-bus-type", _tmp0_, "g-object-path", (const gchar*) path, "g-interface-name", "org.freedesktop.Properties", NULL);
#line 796 "src/systemadm.vala"
		p = (Properties*) _tmp1_;
#line 796 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 6240 "systemadm.c"
			goto __catch0_g_error;
		}
#line 801 "src/systemadm.vala"
		_tmp2_ = p;
#line 801 "src/systemadm.vala"
		g_signal_connect_object (_tmp2_, "properties-changed", (GCallback) _main_window_on_job_changed_properties_properties_changed, self, 0);
#line 804 "src/systemadm.vala"
		_tmp3_ = self->priv->job_model;
#line 804 "src/systemadm.vala"
		gtk_list_store_append (_tmp3_, &_tmp4_);
#line 804 "src/systemadm.vala"
		iter = _tmp4_;
#line 807 "src/systemadm.vala"
		if (user) {
#line 807 "src/systemadm.vala"
			_tmp5_ = G_BUS_TYPE_SESSION;
#line 6257 "systemadm.c"
		} else {
#line 807 "src/systemadm.vala"
			_tmp5_ = G_BUS_TYPE_SYSTEM;
#line 6261 "systemadm.c"
		}
#line 806 "src/systemadm.vala"
		_tmp6_ = (Job*) g_initable_new (TYPE_JOB_PROXY, NULL, &_inner_error0_, "g-flags", 0, "g-name", "org.freedesktop.systemd1", "g-bus-type", _tmp5_, "g-object-path", (const gchar*) path, "g-interface-name", "org.freedesktop.systemd1.Job", NULL);
#line 806 "src/systemadm.vala"
		j = (Job*) _tmp6_;
#line 806 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 806 "src/systemadm.vala"
			_g_object_unref0 (p);
#line 6271 "systemadm.c"
			goto __catch0_g_error;
		}
#line 811 "src/systemadm.vala"
		_tmp7_ = iter;
#line 811 "src/systemadm.vala"
		_tmp8_ = j;
#line 811 "src/systemadm.vala"
		main_window_update_job_iter (self, &_tmp7_, id, _tmp8_);
#line 794 "src/systemadm.vala"
		_g_object_unref0 (j);
#line 794 "src/systemadm.vala"
		_g_object_unref0 (p);
#line 6284 "systemadm.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp9_;
#line 794 "src/systemadm.vala"
		e = _inner_error0_;
#line 794 "src/systemadm.vala"
		_inner_error0_ = NULL;
#line 814 "src/systemadm.vala"
		_tmp9_ = e;
#line 814 "src/systemadm.vala"
		main_window_show_error (self, _tmp9_);
#line 794 "src/systemadm.vala"
		_g_error_free0 (e);
#line 6301 "systemadm.c"
	}
	__finally0:
#line 794 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 794 "src/systemadm.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 794 "src/systemadm.vala"
		g_clear_error (&_inner_error0_);
#line 794 "src/systemadm.vala"
		return;
#line 6312 "systemadm.c"
	}
}

void
main_window_on_unit_removed (MainWindow* self,
                             const gchar* id,
                             const char* path)
{
	GtkTreeIter iter = {0};
	GtkListStore* _tmp0_;
	GtkTreeIter _tmp1_ = {0};
	gboolean _tmp2_;
	GeeHashMap* _tmp13_;
#line 818 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 818 "src/systemadm.vala"
	g_return_if_fail (id != NULL);
#line 818 "src/systemadm.vala"
	g_return_if_fail (path != NULL);
#line 820 "src/systemadm.vala"
	_tmp0_ = self->priv->unit_model;
#line 820 "src/systemadm.vala"
	_tmp2_ = gtk_tree_model_get_iter_first ((GtkTreeModel*) _tmp0_, &_tmp1_);
#line 820 "src/systemadm.vala"
	iter = _tmp1_;
#line 820 "src/systemadm.vala"
	if (!_tmp2_) {
#line 821 "src/systemadm.vala"
		return;
#line 6342 "systemadm.c"
	}
	{
		gboolean _tmp3_ = FALSE;
#line 823 "src/systemadm.vala"
		_tmp3_ = TRUE;
#line 823 "src/systemadm.vala"
		while (TRUE) {
#line 6350 "systemadm.c"
			gchar* name = NULL;
			GtkListStore* _tmp6_;
			GtkTreeIter _tmp7_;
			gchar* _tmp8_ = NULL;
			const gchar* _tmp9_;
#line 823 "src/systemadm.vala"
			if (!_tmp3_) {
#line 6358 "systemadm.c"
				GtkListStore* _tmp4_;
				gboolean _tmp5_;
#line 836 "src/systemadm.vala"
				_tmp4_ = self->priv->unit_model;
#line 836 "src/systemadm.vala"
				_tmp5_ = gtk_tree_model_iter_next ((GtkTreeModel*) _tmp4_, &iter);
#line 836 "src/systemadm.vala"
				if (!_tmp5_) {
#line 836 "src/systemadm.vala"
					break;
#line 6369 "systemadm.c"
				}
			}
#line 823 "src/systemadm.vala"
			_tmp3_ = FALSE;
#line 826 "src/systemadm.vala"
			_tmp6_ = self->priv->unit_model;
#line 826 "src/systemadm.vala"
			_tmp7_ = iter;
#line 826 "src/systemadm.vala"
			gtk_tree_model_get ((GtkTreeModel*) _tmp6_, &_tmp7_, 0, &_tmp8_, -1);
#line 826 "src/systemadm.vala"
			_g_free0 (name);
#line 826 "src/systemadm.vala"
			name = _tmp8_;
#line 828 "src/systemadm.vala"
			_tmp9_ = name;
#line 828 "src/systemadm.vala"
			if (g_strcmp0 (id, _tmp9_) == 0) {
#line 6388 "systemadm.c"
				const gchar* _tmp10_;
				const gchar* _tmp11_;
				GtkListStore* _tmp12_;
#line 829 "src/systemadm.vala"
				_tmp10_ = self->priv->current_unit_id;
#line 829 "src/systemadm.vala"
				_tmp11_ = name;
#line 829 "src/systemadm.vala"
				if (g_strcmp0 (_tmp10_, _tmp11_) == 0) {
#line 830 "src/systemadm.vala"
					main_window_clear_unit (self);
#line 6400 "systemadm.c"
				}
#line 832 "src/systemadm.vala"
				_tmp12_ = self->priv->unit_model;
#line 832 "src/systemadm.vala"
				gtk_list_store_remove (_tmp12_, &iter);
#line 833 "src/systemadm.vala"
				_g_free0 (name);
#line 833 "src/systemadm.vala"
				break;
#line 6410 "systemadm.c"
			}
#line 823 "src/systemadm.vala"
			_g_free0 (name);
#line 6414 "systemadm.c"
		}
	}
#line 838 "src/systemadm.vala"
	_tmp13_ = self->priv->unit_map;
#line 838 "src/systemadm.vala"
	gee_abstract_map_unset ((GeeAbstractMap*) _tmp13_, id, NULL);
#line 6421 "systemadm.c"
}

void
main_window_on_job_removed (MainWindow* self,
                            guint32 id,
                            const char* path,
                            const gchar* res)
{
	GtkTreeIter iter = {0};
	GtkListStore* _tmp0_;
	GtkTreeIter _tmp1_ = {0};
	gboolean _tmp2_;
#line 841 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 841 "src/systemadm.vala"
	g_return_if_fail (path != NULL);
#line 841 "src/systemadm.vala"
	g_return_if_fail (res != NULL);
#line 843 "src/systemadm.vala"
	_tmp0_ = self->priv->job_model;
#line 843 "src/systemadm.vala"
	_tmp2_ = gtk_tree_model_get_iter_first ((GtkTreeModel*) _tmp0_, &_tmp1_);
#line 843 "src/systemadm.vala"
	iter = _tmp1_;
#line 843 "src/systemadm.vala"
	if (!_tmp2_) {
#line 844 "src/systemadm.vala"
		return;
#line 6450 "systemadm.c"
	}
	{
		gboolean _tmp3_ = FALSE;
#line 846 "src/systemadm.vala"
		_tmp3_ = TRUE;
#line 846 "src/systemadm.vala"
		while (TRUE) {
#line 6458 "systemadm.c"
			guint32 j = 0U;
			GtkListStore* _tmp6_;
			GtkTreeIter _tmp7_;
			guint32 _tmp8_ = 0U;
#line 846 "src/systemadm.vala"
			if (!_tmp3_) {
#line 6465 "systemadm.c"
				GtkListStore* _tmp4_;
				gboolean _tmp5_;
#line 860 "src/systemadm.vala"
				_tmp4_ = self->priv->job_model;
#line 860 "src/systemadm.vala"
				_tmp5_ = gtk_tree_model_iter_next ((GtkTreeModel*) _tmp4_, &iter);
#line 860 "src/systemadm.vala"
				if (!_tmp5_) {
#line 860 "src/systemadm.vala"
					break;
#line 6476 "systemadm.c"
				}
			}
#line 846 "src/systemadm.vala"
			_tmp3_ = FALSE;
#line 849 "src/systemadm.vala"
			_tmp6_ = self->priv->job_model;
#line 849 "src/systemadm.vala"
			_tmp7_ = iter;
#line 849 "src/systemadm.vala"
			gtk_tree_model_get ((GtkTreeModel*) _tmp6_, &_tmp7_, 5, &_tmp8_, -1);
#line 849 "src/systemadm.vala"
			j = _tmp8_;
#line 851 "src/systemadm.vala"
			if (id == j) {
#line 6491 "systemadm.c"
				GtkListStore* _tmp9_;
#line 852 "src/systemadm.vala"
				if (self->priv->current_job_id == j) {
#line 853 "src/systemadm.vala"
					main_window_clear_job (self);
#line 6497 "systemadm.c"
				}
#line 855 "src/systemadm.vala"
				_tmp9_ = self->priv->job_model;
#line 855 "src/systemadm.vala"
				gtk_list_store_remove (_tmp9_, &iter);
#line 857 "src/systemadm.vala"
				break;
#line 6505 "systemadm.c"
			}
		}
	}
}

void
main_window_on_unit_changed (MainWindow* self,
                             Properties* p,
                             const gchar* iface,
                             GHashTable* changed_properties,
                             gchar** invalidated_properties,
                             gint invalidated_properties_length1)
{
	GError* _inner_error0_ = NULL;
#line 863 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 863 "src/systemadm.vala"
	g_return_if_fail (p != NULL);
#line 863 "src/systemadm.vala"
	g_return_if_fail (iface != NULL);
#line 863 "src/systemadm.vala"
	g_return_if_fail (changed_properties != NULL);
#line 6528 "systemadm.c"
	{
		GtkTreeIter iter = {0};
		gchar* id = NULL;
		GBusType _tmp0_ = 0;
		Unit* u = NULL;
		const gchar* _tmp1_;
		const gchar* _tmp2_;
		Unit* _tmp3_;
		GtkListStore* _tmp4_;
		GtkTreeIter _tmp5_ = {0};
		gboolean _tmp6_;
		Unit* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
#line 870 "src/systemadm.vala"
		if (user) {
#line 870 "src/systemadm.vala"
			_tmp0_ = G_BUS_TYPE_SESSION;
#line 6547 "systemadm.c"
		} else {
#line 870 "src/systemadm.vala"
			_tmp0_ = G_BUS_TYPE_SYSTEM;
#line 6551 "systemadm.c"
		}
#line 869 "src/systemadm.vala"
		_tmp1_ = g_dbus_proxy_get_name ((GDBusProxy*) p);
#line 869 "src/systemadm.vala"
		_tmp2_ = g_dbus_proxy_get_object_path ((GDBusProxy*) p);
#line 869 "src/systemadm.vala"
		_tmp3_ = (Unit*) g_initable_new (TYPE_UNIT_PROXY, NULL, &_inner_error0_, "g-flags", 0, "g-name", _tmp1_, "g-bus-type", _tmp0_, "g-object-path", _tmp2_, "g-interface-name", "org.freedesktop.systemd1.Unit", NULL);
#line 869 "src/systemadm.vala"
		u = (Unit*) _tmp3_;
#line 869 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 869 "src/systemadm.vala"
			_g_free0 (id);
#line 6565 "systemadm.c"
			goto __catch0_g_error;
		}
#line 874 "src/systemadm.vala"
		_tmp4_ = self->priv->unit_model;
#line 874 "src/systemadm.vala"
		_tmp6_ = gtk_tree_model_get_iter_first ((GtkTreeModel*) _tmp4_, &_tmp5_);
#line 874 "src/systemadm.vala"
		iter = _tmp5_;
#line 874 "src/systemadm.vala"
		if (!_tmp6_) {
#line 875 "src/systemadm.vala"
			_g_object_unref0 (u);
#line 875 "src/systemadm.vala"
			_g_free0 (id);
#line 875 "src/systemadm.vala"
			return;
#line 6582 "systemadm.c"
		}
#line 877 "src/systemadm.vala"
		_tmp7_ = u;
#line 877 "src/systemadm.vala"
		_tmp8_ = unit_get_id (_tmp7_);
#line 877 "src/systemadm.vala"
		_tmp9_ = _tmp8_;
#line 877 "src/systemadm.vala"
		_g_free0 (id);
#line 877 "src/systemadm.vala"
		id = _tmp9_;
#line 6594 "systemadm.c"
		{
			gboolean _tmp10_ = FALSE;
#line 879 "src/systemadm.vala"
			_tmp10_ = TRUE;
#line 879 "src/systemadm.vala"
			while (TRUE) {
#line 6601 "systemadm.c"
				gchar* name = NULL;
				GtkListStore* _tmp13_;
				GtkTreeIter _tmp14_;
				gchar* _tmp15_ = NULL;
				const gchar* _tmp16_;
				const gchar* _tmp17_;
#line 879 "src/systemadm.vala"
				if (!_tmp10_) {
#line 6610 "systemadm.c"
					GtkListStore* _tmp11_;
					gboolean _tmp12_;
#line 893 "src/systemadm.vala"
					_tmp11_ = self->priv->unit_model;
#line 893 "src/systemadm.vala"
					_tmp12_ = gtk_tree_model_iter_next ((GtkTreeModel*) _tmp11_, &iter);
#line 893 "src/systemadm.vala"
					if (!_tmp12_) {
#line 893 "src/systemadm.vala"
						break;
#line 6621 "systemadm.c"
					}
				}
#line 879 "src/systemadm.vala"
				_tmp10_ = FALSE;
#line 882 "src/systemadm.vala"
				_tmp13_ = self->priv->unit_model;
#line 882 "src/systemadm.vala"
				_tmp14_ = iter;
#line 882 "src/systemadm.vala"
				gtk_tree_model_get ((GtkTreeModel*) _tmp13_, &_tmp14_, 0, &_tmp15_, -1);
#line 882 "src/systemadm.vala"
				_g_free0 (name);
#line 882 "src/systemadm.vala"
				name = _tmp15_;
#line 884 "src/systemadm.vala"
				_tmp16_ = id;
#line 884 "src/systemadm.vala"
				_tmp17_ = name;
#line 884 "src/systemadm.vala"
				if (g_strcmp0 (_tmp16_, _tmp17_) == 0) {
#line 6642 "systemadm.c"
					GtkTreeIter _tmp18_;
					const gchar* _tmp19_;
					Unit* _tmp20_;
					const gchar* _tmp21_;
					const gchar* _tmp22_;
#line 885 "src/systemadm.vala"
					_tmp18_ = iter;
#line 885 "src/systemadm.vala"
					_tmp19_ = id;
#line 885 "src/systemadm.vala"
					_tmp20_ = u;
#line 885 "src/systemadm.vala"
					main_window_update_unit_iter (self, &_tmp18_, _tmp19_, _tmp20_);
#line 887 "src/systemadm.vala"
					_tmp21_ = self->priv->current_unit_id;
#line 887 "src/systemadm.vala"
					_tmp22_ = id;
#line 887 "src/systemadm.vala"
					if (g_strcmp0 (_tmp21_, _tmp22_) == 0) {
#line 6662 "systemadm.c"
						Unit* _tmp23_;
#line 888 "src/systemadm.vala"
						_tmp23_ = u;
#line 888 "src/systemadm.vala"
						main_window_show_unit (self, _tmp23_);
#line 6668 "systemadm.c"
					}
#line 890 "src/systemadm.vala"
					_g_free0 (name);
#line 890 "src/systemadm.vala"
					break;
#line 6674 "systemadm.c"
				}
#line 879 "src/systemadm.vala"
				_g_free0 (name);
#line 6678 "systemadm.c"
			}
		}
#line 865 "src/systemadm.vala"
		_g_object_unref0 (u);
#line 865 "src/systemadm.vala"
		_g_free0 (id);
#line 6685 "systemadm.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp24_;
#line 865 "src/systemadm.vala"
		e = _inner_error0_;
#line 865 "src/systemadm.vala"
		_inner_error0_ = NULL;
#line 896 "src/systemadm.vala"
		_tmp24_ = e;
#line 896 "src/systemadm.vala"
		main_window_show_error (self, _tmp24_);
#line 865 "src/systemadm.vala"
		_g_error_free0 (e);
#line 6702 "systemadm.c"
	}
	__finally0:
#line 865 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 865 "src/systemadm.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 865 "src/systemadm.vala"
		g_clear_error (&_inner_error0_);
#line 865 "src/systemadm.vala"
		return;
#line 6713 "systemadm.c"
	}
}

void
main_window_on_job_changed (MainWindow* self,
                            Properties* p,
                            const gchar* iface,
                            GHashTable* changed_properties,
                            gchar** invalidated_properties,
                            gint invalidated_properties_length1)
{
	GError* _inner_error0_ = NULL;
#line 900 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 900 "src/systemadm.vala"
	g_return_if_fail (p != NULL);
#line 900 "src/systemadm.vala"
	g_return_if_fail (iface != NULL);
#line 900 "src/systemadm.vala"
	g_return_if_fail (changed_properties != NULL);
#line 6734 "systemadm.c"
	{
		GtkTreeIter iter = {0};
		guint32 id = 0U;
		GBusType _tmp0_ = 0;
		Job* j = NULL;
		const gchar* _tmp1_;
		const gchar* _tmp2_;
		Job* _tmp3_;
		GtkListStore* _tmp4_;
		GtkTreeIter _tmp5_ = {0};
		gboolean _tmp6_;
		Job* _tmp7_;
		guint32 _tmp8_;
		guint32 _tmp9_;
#line 906 "src/systemadm.vala"
		if (user) {
#line 906 "src/systemadm.vala"
			_tmp0_ = G_BUS_TYPE_SESSION;
#line 6753 "systemadm.c"
		} else {
#line 906 "src/systemadm.vala"
			_tmp0_ = G_BUS_TYPE_SYSTEM;
#line 6757 "systemadm.c"
		}
#line 905 "src/systemadm.vala"
		_tmp1_ = g_dbus_proxy_get_name ((GDBusProxy*) p);
#line 905 "src/systemadm.vala"
		_tmp2_ = g_dbus_proxy_get_object_path ((GDBusProxy*) p);
#line 905 "src/systemadm.vala"
		_tmp3_ = (Job*) g_initable_new (TYPE_JOB_PROXY, NULL, &_inner_error0_, "g-flags", 0, "g-name", _tmp1_, "g-bus-type", _tmp0_, "g-object-path", _tmp2_, "g-interface-name", "org.freedesktop.systemd1.Job", NULL);
#line 905 "src/systemadm.vala"
		j = (Job*) _tmp3_;
#line 905 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 6769 "systemadm.c"
			goto __catch0_g_error;
		}
#line 910 "src/systemadm.vala"
		_tmp4_ = self->priv->job_model;
#line 910 "src/systemadm.vala"
		_tmp6_ = gtk_tree_model_get_iter_first ((GtkTreeModel*) _tmp4_, &_tmp5_);
#line 910 "src/systemadm.vala"
		iter = _tmp5_;
#line 910 "src/systemadm.vala"
		if (!_tmp6_) {
#line 911 "src/systemadm.vala"
			_g_object_unref0 (j);
#line 911 "src/systemadm.vala"
			return;
#line 6784 "systemadm.c"
		}
#line 913 "src/systemadm.vala"
		_tmp7_ = j;
#line 913 "src/systemadm.vala"
		_tmp8_ = job_get_id (_tmp7_);
#line 913 "src/systemadm.vala"
		_tmp9_ = _tmp8_;
#line 913 "src/systemadm.vala"
		id = _tmp9_;
#line 6794 "systemadm.c"
		{
			gboolean _tmp10_ = FALSE;
#line 915 "src/systemadm.vala"
			_tmp10_ = TRUE;
#line 915 "src/systemadm.vala"
			while (TRUE) {
#line 6801 "systemadm.c"
				guint32 k = 0U;
				GtkListStore* _tmp13_;
				GtkTreeIter _tmp14_;
				guint32 _tmp15_ = 0U;
#line 915 "src/systemadm.vala"
				if (!_tmp10_) {
#line 6808 "systemadm.c"
					GtkListStore* _tmp11_;
					gboolean _tmp12_;
#line 929 "src/systemadm.vala"
					_tmp11_ = self->priv->job_model;
#line 929 "src/systemadm.vala"
					_tmp12_ = gtk_tree_model_iter_next ((GtkTreeModel*) _tmp11_, &iter);
#line 929 "src/systemadm.vala"
					if (!_tmp12_) {
#line 929 "src/systemadm.vala"
						break;
#line 6819 "systemadm.c"
					}
				}
#line 915 "src/systemadm.vala"
				_tmp10_ = FALSE;
#line 918 "src/systemadm.vala"
				_tmp13_ = self->priv->job_model;
#line 918 "src/systemadm.vala"
				_tmp14_ = iter;
#line 918 "src/systemadm.vala"
				gtk_tree_model_get ((GtkTreeModel*) _tmp13_, &_tmp14_, 5, &_tmp15_, -1);
#line 918 "src/systemadm.vala"
				k = _tmp15_;
#line 920 "src/systemadm.vala"
				if (id == k) {
#line 6834 "systemadm.c"
					GtkTreeIter _tmp16_;
					Job* _tmp17_;
#line 921 "src/systemadm.vala"
					_tmp16_ = iter;
#line 921 "src/systemadm.vala"
					_tmp17_ = j;
#line 921 "src/systemadm.vala"
					main_window_update_job_iter (self, &_tmp16_, id, _tmp17_);
#line 923 "src/systemadm.vala"
					if (self->priv->current_job_id == id) {
#line 6845 "systemadm.c"
						Job* _tmp18_;
#line 924 "src/systemadm.vala"
						_tmp18_ = j;
#line 924 "src/systemadm.vala"
						main_window_show_job (self, _tmp18_);
#line 6851 "systemadm.c"
					}
#line 926 "src/systemadm.vala"
					break;
#line 6855 "systemadm.c"
				}
			}
		}
#line 901 "src/systemadm.vala"
		_g_object_unref0 (j);
#line 6861 "systemadm.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp19_;
#line 901 "src/systemadm.vala"
		e = _inner_error0_;
#line 901 "src/systemadm.vala"
		_inner_error0_ = NULL;
#line 932 "src/systemadm.vala"
		_tmp19_ = e;
#line 932 "src/systemadm.vala"
		main_window_show_error (self, _tmp19_);
#line 901 "src/systemadm.vala"
		_g_error_free0 (e);
#line 6878 "systemadm.c"
	}
	__finally0:
#line 901 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 901 "src/systemadm.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 901 "src/systemadm.vala"
		g_clear_error (&_inner_error0_);
#line 901 "src/systemadm.vala"
		return;
#line 6889 "systemadm.c"
	}
}

gboolean
main_window_unit_filter (MainWindow* self,
                         GtkTreeModel* model,
                         GtkTreeIter* iter)
{
	gchar* id = NULL;
	gchar* active_state = NULL;
	gchar* job = NULL;
	GtkTreeIter _tmp0_;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
	GtkCheckButton* _tmp7_;
	GtkComboBoxText* _tmp10_;
	gboolean result;
#line 936 "src/systemadm.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 936 "src/systemadm.vala"
	g_return_val_if_fail (model != NULL, FALSE);
#line 936 "src/systemadm.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 939 "src/systemadm.vala"
	_tmp0_ = *iter;
#line 939 "src/systemadm.vala"
	gtk_tree_model_get (model, &_tmp0_, 0, &_tmp1_, 3, &_tmp2_, 5, &_tmp3_, -1);
#line 939 "src/systemadm.vala"
	_g_free0 (id);
#line 939 "src/systemadm.vala"
	id = _tmp1_;
#line 939 "src/systemadm.vala"
	_g_free0 (active_state);
#line 939 "src/systemadm.vala"
	active_state = _tmp2_;
#line 939 "src/systemadm.vala"
	_g_free0 (job);
#line 939 "src/systemadm.vala"
	job = _tmp3_;
#line 941 "src/systemadm.vala"
	_tmp4_ = id;
#line 941 "src/systemadm.vala"
	if (_tmp4_ == NULL) {
#line 942 "src/systemadm.vala"
		result = FALSE;
#line 942 "src/systemadm.vala"
		_g_free0 (job);
#line 942 "src/systemadm.vala"
		_g_free0 (active_state);
#line 942 "src/systemadm.vala"
		_g_free0 (id);
#line 942 "src/systemadm.vala"
		return result;
#line 6947 "systemadm.c"
	}
#line 944 "src/systemadm.vala"
	_tmp7_ = self->priv->inactive_checkbox;
#line 944 "src/systemadm.vala"
	if (!gtk_toggle_button_get_active ((GtkToggleButton*) _tmp7_)) {
#line 6953 "systemadm.c"
		const gchar* _tmp8_;
#line 945 "src/systemadm.vala"
		_tmp8_ = active_state;
#line 945 "src/systemadm.vala"
		_tmp6_ = g_strcmp0 (_tmp8_, "inactive") == 0;
#line 6959 "systemadm.c"
	} else {
#line 944 "src/systemadm.vala"
		_tmp6_ = FALSE;
#line 6963 "systemadm.c"
	}
#line 944 "src/systemadm.vala"
	if (_tmp6_) {
#line 6967 "systemadm.c"
		const gchar* _tmp9_;
#line 945 "src/systemadm.vala"
		_tmp9_ = job;
#line 945 "src/systemadm.vala"
		_tmp5_ = g_strcmp0 (_tmp9_, "") == 0;
#line 6973 "systemadm.c"
	} else {
#line 944 "src/systemadm.vala"
		_tmp5_ = FALSE;
#line 6977 "systemadm.c"
	}
#line 944 "src/systemadm.vala"
	if (_tmp5_) {
#line 946 "src/systemadm.vala"
		result = FALSE;
#line 946 "src/systemadm.vala"
		_g_free0 (job);
#line 946 "src/systemadm.vala"
		_g_free0 (active_state);
#line 946 "src/systemadm.vala"
		_g_free0 (id);
#line 946 "src/systemadm.vala"
		return result;
#line 6991 "systemadm.c"
	}
#line 948 "src/systemadm.vala"
	_tmp10_ = self->priv->unit_type_combo_box;
#line 948 "src/systemadm.vala"
	switch (gtk_combo_box_get_active ((GtkComboBox*) _tmp10_)) {
#line 948 "src/systemadm.vala"
		case 0:
#line 6999 "systemadm.c"
		{
#line 950 "src/systemadm.vala"
			result = TRUE;
#line 950 "src/systemadm.vala"
			_g_free0 (job);
#line 950 "src/systemadm.vala"
			_g_free0 (active_state);
#line 950 "src/systemadm.vala"
			_g_free0 (id);
#line 950 "src/systemadm.vala"
			return result;
#line 7011 "systemadm.c"
		}
#line 948 "src/systemadm.vala"
		case 1:
#line 7015 "systemadm.c"
		{
			const gchar* _tmp11_;
#line 952 "src/systemadm.vala"
			_tmp11_ = id;
#line 952 "src/systemadm.vala"
			result = g_str_has_suffix (_tmp11_, ".target");
#line 952 "src/systemadm.vala"
			_g_free0 (job);
#line 952 "src/systemadm.vala"
			_g_free0 (active_state);
#line 952 "src/systemadm.vala"
			_g_free0 (id);
#line 952 "src/systemadm.vala"
			return result;
#line 7030 "systemadm.c"
		}
#line 948 "src/systemadm.vala"
		case 2:
#line 7034 "systemadm.c"
		{
			const gchar* _tmp12_;
#line 954 "src/systemadm.vala"
			_tmp12_ = id;
#line 954 "src/systemadm.vala"
			result = g_str_has_suffix (_tmp12_, ".slice");
#line 954 "src/systemadm.vala"
			_g_free0 (job);
#line 954 "src/systemadm.vala"
			_g_free0 (active_state);
#line 954 "src/systemadm.vala"
			_g_free0 (id);
#line 954 "src/systemadm.vala"
			return result;
#line 7049 "systemadm.c"
		}
#line 948 "src/systemadm.vala"
		case 3:
#line 7053 "systemadm.c"
		{
			const gchar* _tmp13_;
#line 956 "src/systemadm.vala"
			_tmp13_ = id;
#line 956 "src/systemadm.vala"
			result = g_str_has_suffix (_tmp13_, ".scope");
#line 956 "src/systemadm.vala"
			_g_free0 (job);
#line 956 "src/systemadm.vala"
			_g_free0 (active_state);
#line 956 "src/systemadm.vala"
			_g_free0 (id);
#line 956 "src/systemadm.vala"
			return result;
#line 7068 "systemadm.c"
		}
#line 948 "src/systemadm.vala"
		case 4:
#line 7072 "systemadm.c"
		{
			const gchar* _tmp14_;
#line 958 "src/systemadm.vala"
			_tmp14_ = id;
#line 958 "src/systemadm.vala"
			result = g_str_has_suffix (_tmp14_, ".service");
#line 958 "src/systemadm.vala"
			_g_free0 (job);
#line 958 "src/systemadm.vala"
			_g_free0 (active_state);
#line 958 "src/systemadm.vala"
			_g_free0 (id);
#line 958 "src/systemadm.vala"
			return result;
#line 7087 "systemadm.c"
		}
#line 948 "src/systemadm.vala"
		case 5:
#line 7091 "systemadm.c"
		{
			const gchar* _tmp15_;
#line 960 "src/systemadm.vala"
			_tmp15_ = id;
#line 960 "src/systemadm.vala"
			result = g_str_has_suffix (_tmp15_, ".device");
#line 960 "src/systemadm.vala"
			_g_free0 (job);
#line 960 "src/systemadm.vala"
			_g_free0 (active_state);
#line 960 "src/systemadm.vala"
			_g_free0 (id);
#line 960 "src/systemadm.vala"
			return result;
#line 7106 "systemadm.c"
		}
#line 948 "src/systemadm.vala"
		case 6:
#line 7110 "systemadm.c"
		{
			const gchar* _tmp16_;
#line 962 "src/systemadm.vala"
			_tmp16_ = id;
#line 962 "src/systemadm.vala"
			result = g_str_has_suffix (_tmp16_, ".mount");
#line 962 "src/systemadm.vala"
			_g_free0 (job);
#line 962 "src/systemadm.vala"
			_g_free0 (active_state);
#line 962 "src/systemadm.vala"
			_g_free0 (id);
#line 962 "src/systemadm.vala"
			return result;
#line 7125 "systemadm.c"
		}
#line 948 "src/systemadm.vala"
		case 7:
#line 7129 "systemadm.c"
		{
			const gchar* _tmp17_;
#line 964 "src/systemadm.vala"
			_tmp17_ = id;
#line 964 "src/systemadm.vala"
			result = g_str_has_suffix (_tmp17_, ".automount");
#line 964 "src/systemadm.vala"
			_g_free0 (job);
#line 964 "src/systemadm.vala"
			_g_free0 (active_state);
#line 964 "src/systemadm.vala"
			_g_free0 (id);
#line 964 "src/systemadm.vala"
			return result;
#line 7144 "systemadm.c"
		}
#line 948 "src/systemadm.vala"
		case 8:
#line 7148 "systemadm.c"
		{
			const gchar* _tmp18_;
#line 966 "src/systemadm.vala"
			_tmp18_ = id;
#line 966 "src/systemadm.vala"
			result = g_str_has_suffix (_tmp18_, ".swap");
#line 966 "src/systemadm.vala"
			_g_free0 (job);
#line 966 "src/systemadm.vala"
			_g_free0 (active_state);
#line 966 "src/systemadm.vala"
			_g_free0 (id);
#line 966 "src/systemadm.vala"
			return result;
#line 7163 "systemadm.c"
		}
#line 948 "src/systemadm.vala"
		case 9:
#line 7167 "systemadm.c"
		{
			const gchar* _tmp19_;
#line 968 "src/systemadm.vala"
			_tmp19_ = id;
#line 968 "src/systemadm.vala"
			result = g_str_has_suffix (_tmp19_, ".socket");
#line 968 "src/systemadm.vala"
			_g_free0 (job);
#line 968 "src/systemadm.vala"
			_g_free0 (active_state);
#line 968 "src/systemadm.vala"
			_g_free0 (id);
#line 968 "src/systemadm.vala"
			return result;
#line 7182 "systemadm.c"
		}
#line 948 "src/systemadm.vala"
		case 10:
#line 7186 "systemadm.c"
		{
			const gchar* _tmp20_;
#line 970 "src/systemadm.vala"
			_tmp20_ = id;
#line 970 "src/systemadm.vala"
			result = g_str_has_suffix (_tmp20_, ".path");
#line 970 "src/systemadm.vala"
			_g_free0 (job);
#line 970 "src/systemadm.vala"
			_g_free0 (active_state);
#line 970 "src/systemadm.vala"
			_g_free0 (id);
#line 970 "src/systemadm.vala"
			return result;
#line 7201 "systemadm.c"
		}
#line 948 "src/systemadm.vala"
		case 11:
#line 7205 "systemadm.c"
		{
			const gchar* _tmp21_;
#line 972 "src/systemadm.vala"
			_tmp21_ = id;
#line 972 "src/systemadm.vala"
			result = g_str_has_suffix (_tmp21_, ".timer");
#line 972 "src/systemadm.vala"
			_g_free0 (job);
#line 972 "src/systemadm.vala"
			_g_free0 (active_state);
#line 972 "src/systemadm.vala"
			_g_free0 (id);
#line 972 "src/systemadm.vala"
			return result;
#line 7220 "systemadm.c"
		}
#line 948 "src/systemadm.vala"
		case 12:
#line 7224 "systemadm.c"
		{
			const gchar* _tmp22_;
#line 974 "src/systemadm.vala"
			_tmp22_ = id;
#line 974 "src/systemadm.vala"
			result = g_str_has_suffix (_tmp22_, ".snapshot");
#line 974 "src/systemadm.vala"
			_g_free0 (job);
#line 974 "src/systemadm.vala"
			_g_free0 (active_state);
#line 974 "src/systemadm.vala"
			_g_free0 (id);
#line 974 "src/systemadm.vala"
			return result;
#line 7239 "systemadm.c"
		}
		default:
		{
#line 976 "src/systemadm.vala"
			_vala_assert (FALSE, "false");
#line 977 "src/systemadm.vala"
			result = FALSE;
#line 977 "src/systemadm.vala"
			_g_free0 (job);
#line 977 "src/systemadm.vala"
			_g_free0 (active_state);
#line 977 "src/systemadm.vala"
			_g_free0 (id);
#line 977 "src/systemadm.vala"
			return result;
#line 7255 "systemadm.c"
		}
	}
}

void
main_window_unit_type_changed (MainWindow* self)
{
	GtkTreeModelFilter* model = NULL;
	GtkTreeView* _tmp0_;
	GtkTreeModel* _tmp1_;
	GtkTreeModel* _tmp2_;
	GtkTreeModelFilter* _tmp3_;
#line 981 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 982 "src/systemadm.vala"
	_tmp0_ = self->priv->unit_view;
#line 982 "src/systemadm.vala"
	_tmp1_ = gtk_tree_view_get_model (_tmp0_);
#line 982 "src/systemadm.vala"
	_tmp2_ = gtk_tree_model_sort_get_model (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_tree_model_sort_get_type (), GtkTreeModelSort));
#line 982 "src/systemadm.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_tree_model_filter_get_type (), GtkTreeModelFilter));
#line 982 "src/systemadm.vala"
	model = _tmp3_;
#line 984 "src/systemadm.vala"
	gtk_tree_model_filter_refilter (model);
#line 981 "src/systemadm.vala"
	_g_object_unref0 (model);
#line 7284 "systemadm.c"
}

void
main_window_on_server_reload (MainWindow* self)
{
	GError* _inner_error0_ = NULL;
#line 987 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 7293 "systemadm.c"
	{
		Manager* _tmp0_;
#line 989 "src/systemadm.vala"
		_tmp0_ = self->priv->manager;
#line 989 "src/systemadm.vala"
		manager_reload (_tmp0_, &_inner_error0_);
#line 989 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 7302 "systemadm.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp1_;
#line 988 "src/systemadm.vala"
		e = _inner_error0_;
#line 988 "src/systemadm.vala"
		_inner_error0_ = NULL;
#line 991 "src/systemadm.vala"
		_tmp1_ = e;
#line 991 "src/systemadm.vala"
		main_window_show_error (self, _tmp1_);
#line 988 "src/systemadm.vala"
		_g_error_free0 (e);
#line 7321 "systemadm.c"
	}
	__finally0:
#line 988 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 988 "src/systemadm.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 988 "src/systemadm.vala"
		g_clear_error (&_inner_error0_);
#line 988 "src/systemadm.vala"
		return;
#line 7332 "systemadm.c"
	}
}

void
main_window_on_server_snapshot (MainWindow* self)
{
	GError* _inner_error0_ = NULL;
#line 995 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 7342 "systemadm.c"
	{
		Manager* _tmp0_;
		char* _tmp1_;
		char* _tmp2_;
		GtkComboBoxText* _tmp3_;
#line 997 "src/systemadm.vala"
		_tmp0_ = self->priv->manager;
#line 997 "src/systemadm.vala"
		_tmp1_ = manager_create_snapshot (_tmp0_, "", FALSE, &_inner_error0_);
#line 997 "src/systemadm.vala"
		_tmp2_ = _tmp1_;
#line 997 "src/systemadm.vala"
		_g_free0 (_tmp2_);
#line 997 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 7358 "systemadm.c"
			goto __catch0_g_error;
		}
#line 999 "src/systemadm.vala"
		_tmp3_ = self->priv->unit_type_combo_box;
#line 999 "src/systemadm.vala"
		if (gtk_combo_box_get_active ((GtkComboBox*) _tmp3_) != 0) {
#line 7365 "systemadm.c"
			GtkComboBoxText* _tmp4_;
#line 1000 "src/systemadm.vala"
			_tmp4_ = self->priv->unit_type_combo_box;
#line 1000 "src/systemadm.vala"
			gtk_combo_box_set_active ((GtkComboBox*) _tmp4_, 12);
#line 7371 "systemadm.c"
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp5_;
#line 996 "src/systemadm.vala"
		e = _inner_error0_;
#line 996 "src/systemadm.vala"
		_inner_error0_ = NULL;
#line 1002 "src/systemadm.vala"
		_tmp5_ = e;
#line 1002 "src/systemadm.vala"
		main_window_show_error (self, _tmp5_);
#line 996 "src/systemadm.vala"
		_g_error_free0 (e);
#line 7389 "systemadm.c"
	}
	__finally0:
#line 996 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 996 "src/systemadm.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 996 "src/systemadm.vala"
		g_clear_error (&_inner_error0_);
#line 996 "src/systemadm.vala"
		return;
#line 7400 "systemadm.c"
	}
}

void
main_window_on_unit_load (MainWindow* self)
{
	gchar* t = NULL;
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	const gchar* _tmp3_;
	GError* _inner_error0_ = NULL;
#line 1006 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 1007 "src/systemadm.vala"
	_tmp0_ = self->priv->unit_load_entry;
#line 1007 "src/systemadm.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 1007 "src/systemadm.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 1007 "src/systemadm.vala"
	t = _tmp2_;
#line 1009 "src/systemadm.vala"
	_tmp3_ = t;
#line 1009 "src/systemadm.vala"
	if (g_strcmp0 (_tmp3_, "") == 0) {
#line 1010 "src/systemadm.vala"
		_g_free0 (t);
#line 1010 "src/systemadm.vala"
		return;
#line 7431 "systemadm.c"
	}
	{
		char* path = NULL;
		Manager* _tmp4_;
		const gchar* _tmp5_;
		char* _tmp6_;
		GBusType _tmp7_ = 0;
		Unit* u = NULL;
		const char* _tmp8_;
		Unit* _tmp9_;
		GtkMessageDialog* m = NULL;
		Unit* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		GtkMessageDialog* _tmp14_;
		GtkMessageDialog* _tmp15_;
		GtkMessageDialog* _tmp16_;
		GtkMessageDialog* _tmp17_;
		GtkMessageDialog* _tmp18_;
		Unit* _tmp19_;
#line 1013 "src/systemadm.vala"
		_tmp4_ = self->priv->manager;
#line 1013 "src/systemadm.vala"
		_tmp5_ = t;
#line 1013 "src/systemadm.vala"
		_tmp6_ = manager_load_unit (_tmp4_, _tmp5_, &_inner_error0_);
#line 1013 "src/systemadm.vala"
		path = _tmp6_;
#line 1013 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 7463 "systemadm.c"
			goto __catch0_g_error;
		}
#line 1016 "src/systemadm.vala"
		if (user) {
#line 1016 "src/systemadm.vala"
			_tmp7_ = G_BUS_TYPE_SESSION;
#line 7470 "systemadm.c"
		} else {
#line 1016 "src/systemadm.vala"
			_tmp7_ = G_BUS_TYPE_SYSTEM;
#line 7474 "systemadm.c"
		}
#line 1015 "src/systemadm.vala"
		_tmp8_ = path;
#line 1015 "src/systemadm.vala"
		_tmp9_ = (Unit*) g_initable_new (TYPE_UNIT_PROXY, NULL, &_inner_error0_, "g-flags", 0, "g-name", "org.freedesktop.systemd1", "g-bus-type", _tmp7_, "g-object-path", (const gchar*) _tmp8_, "g-interface-name", "org.freedesktop.systemd1.Unit", NULL);
#line 1015 "src/systemadm.vala"
		u = (Unit*) _tmp9_;
#line 1015 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1015 "src/systemadm.vala"
			_g_free0 (path);
#line 7486 "systemadm.c"
			goto __catch0_g_error;
		}
#line 1020 "src/systemadm.vala"
		_tmp10_ = u;
#line 1020 "src/systemadm.vala"
		_tmp11_ = unit_get_id (_tmp10_);
#line 1020 "src/systemadm.vala"
		_tmp12_ = _tmp11_;
#line 1020 "src/systemadm.vala"
		_tmp13_ = _tmp12_;
#line 1020 "src/systemadm.vala"
		_tmp14_ = (GtkMessageDialog*) gtk_message_dialog_new ((GtkWindow*) self, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, "Unit available as id %s", _tmp13_);
#line 1020 "src/systemadm.vala"
		g_object_ref_sink (_tmp14_);
#line 1020 "src/systemadm.vala"
		_tmp15_ = _tmp14_;
#line 1020 "src/systemadm.vala"
		_g_free0 (_tmp13_);
#line 1020 "src/systemadm.vala"
		m = _tmp15_;
#line 1025 "src/systemadm.vala"
		_tmp16_ = m;
#line 1025 "src/systemadm.vala"
		gtk_window_set_title ((GtkWindow*) _tmp16_, "Unit");
#line 1026 "src/systemadm.vala"
		_tmp17_ = m;
#line 1026 "src/systemadm.vala"
		gtk_dialog_run ((GtkDialog*) _tmp17_);
#line 1027 "src/systemadm.vala"
		_tmp18_ = m;
#line 1027 "src/systemadm.vala"
		gtk_widget_destroy ((GtkWidget*) _tmp18_);
#line 1029 "src/systemadm.vala"
		_tmp19_ = u;
#line 1029 "src/systemadm.vala"
		main_window_show_unit (self, _tmp19_);
#line 1012 "src/systemadm.vala"
		_g_object_unref0 (m);
#line 1012 "src/systemadm.vala"
		_g_object_unref0 (u);
#line 1012 "src/systemadm.vala"
		_g_free0 (path);
#line 7529 "systemadm.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp20_;
#line 1012 "src/systemadm.vala"
		e = _inner_error0_;
#line 1012 "src/systemadm.vala"
		_inner_error0_ = NULL;
#line 1031 "src/systemadm.vala"
		_tmp20_ = e;
#line 1031 "src/systemadm.vala"
		main_window_show_error (self, _tmp20_);
#line 1012 "src/systemadm.vala"
		_g_error_free0 (e);
#line 7546 "systemadm.c"
	}
	__finally0:
#line 1012 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1012 "src/systemadm.vala"
		_g_free0 (t);
#line 1012 "src/systemadm.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 1012 "src/systemadm.vala"
		g_clear_error (&_inner_error0_);
#line 1012 "src/systemadm.vala"
		return;
#line 7559 "systemadm.c"
	}
#line 1006 "src/systemadm.vala"
	_g_free0 (t);
#line 7563 "systemadm.c"
}

void
main_window_on_unit_load_entry_changed (MainWindow* self)
{
	GtkButton* _tmp0_;
	GtkEntry* _tmp1_;
	const gchar* _tmp2_;
#line 1035 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 1036 "src/systemadm.vala"
	_tmp0_ = self->priv->unit_load_button;
#line 1036 "src/systemadm.vala"
	_tmp1_ = self->priv->unit_load_entry;
#line 1036 "src/systemadm.vala"
	_tmp2_ = gtk_entry_get_text (_tmp1_);
#line 1036 "src/systemadm.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, g_strcmp0 (_tmp2_, "") != 0);
#line 7582 "systemadm.c"
}

gboolean
main_window_on_activate_link (MainWindow* self,
                              const gchar* uri)
{
	GError* _inner_error0_ = NULL;
	gboolean result;
#line 1039 "src/systemadm.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1039 "src/systemadm.vala"
	g_return_val_if_fail (uri != NULL, FALSE);
#line 7595 "systemadm.c"
	{
		gchar* path = NULL;
		Manager* _tmp0_;
		char* _tmp1_;
		GBusType _tmp2_ = 0;
		Unit* u = NULL;
		const gchar* _tmp3_;
		Unit* _tmp4_;
		Unit* _tmp5_;
#line 1042 "src/systemadm.vala"
		_tmp0_ = self->priv->manager;
#line 1042 "src/systemadm.vala"
		_tmp1_ = manager_get_unit (_tmp0_, uri, &_inner_error0_);
#line 1042 "src/systemadm.vala"
		path = (gchar*) _tmp1_;
#line 1042 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 7613 "systemadm.c"
			goto __catch0_g_error;
		}
#line 1045 "src/systemadm.vala"
		if (user) {
#line 1045 "src/systemadm.vala"
			_tmp2_ = G_BUS_TYPE_SESSION;
#line 7620 "systemadm.c"
		} else {
#line 1045 "src/systemadm.vala"
			_tmp2_ = G_BUS_TYPE_SYSTEM;
#line 7624 "systemadm.c"
		}
#line 1044 "src/systemadm.vala"
		_tmp3_ = path;
#line 1044 "src/systemadm.vala"
		_tmp4_ = (Unit*) g_initable_new (TYPE_UNIT_PROXY, NULL, &_inner_error0_, "g-flags", 0, "g-name", "org.freedesktop.systemd1", "g-bus-type", _tmp2_, "g-object-path", _tmp3_, "g-interface-name", "org.freedesktop.systemd1.Unit", NULL);
#line 1044 "src/systemadm.vala"
		u = (Unit*) _tmp4_;
#line 1044 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1044 "src/systemadm.vala"
			_g_free0 (path);
#line 7636 "systemadm.c"
			goto __catch0_g_error;
		}
#line 1049 "src/systemadm.vala"
		_tmp5_ = u;
#line 1049 "src/systemadm.vala"
		main_window_show_unit (self, _tmp5_);
#line 1041 "src/systemadm.vala"
		_g_object_unref0 (u);
#line 1041 "src/systemadm.vala"
		_g_free0 (path);
#line 7647 "systemadm.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp6_;
#line 1041 "src/systemadm.vala"
		e = _inner_error0_;
#line 1041 "src/systemadm.vala"
		_inner_error0_ = NULL;
#line 1051 "src/systemadm.vala"
		_tmp6_ = e;
#line 1051 "src/systemadm.vala"
		main_window_show_error (self, _tmp6_);
#line 1041 "src/systemadm.vala"
		_g_error_free0 (e);
#line 7664 "systemadm.c"
	}
	__finally0:
#line 1041 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 7669 "systemadm.c"
		gboolean _tmp7_ = FALSE;
#line 1041 "src/systemadm.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 1041 "src/systemadm.vala"
		g_clear_error (&_inner_error0_);
#line 1041 "src/systemadm.vala"
		return _tmp7_;
#line 7677 "systemadm.c"
	}
#line 1054 "src/systemadm.vala"
	result = TRUE;
#line 1054 "src/systemadm.vala"
	return result;
#line 7683 "systemadm.c"
}

void
main_window_show_error (MainWindow* self,
                        GError* e)
{
	gchar* title = NULL;
	gchar* message = NULL;
	gboolean _tmp0_ = FALSE;
	GtkMessageDialog* m = NULL;
	const gchar* _tmp9_;
	GtkMessageDialog* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
#line 1057 "src/systemadm.vala"
	g_return_if_fail (self != NULL);
#line 1057 "src/systemadm.vala"
	g_return_if_fail (e != NULL);
#line 1059 "src/systemadm.vala"
	if (e->domain == G_DBUS_ERROR) {
#line 1059 "src/systemadm.vala"
		_tmp0_ = g_dbus_error_is_remote_error (e);
#line 7706 "systemadm.c"
	} else {
#line 1059 "src/systemadm.vala"
		_tmp0_ = FALSE;
#line 7710 "systemadm.c"
	}
#line 1059 "src/systemadm.vala"
	if (_tmp0_) {
#line 7714 "systemadm.c"
		gchar* remote = NULL;
		gchar* _tmp1_;
		const gchar* _tmp2_;
		gchar* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		gchar* _tmp6_;
#line 1060 "src/systemadm.vala"
		_tmp1_ = g_dbus_error_get_remote_error (e);
#line 1060 "src/systemadm.vala"
		remote = _tmp1_;
#line 1061 "src/systemadm.vala"
		_tmp2_ = remote;
#line 1061 "src/systemadm.vala"
		_tmp3_ = g_strdup_printf ("Remote DBus Error: %s", _tmp2_);
#line 1061 "src/systemadm.vala"
		_g_free0 (title);
#line 1061 "src/systemadm.vala"
		title = _tmp3_;
#line 1062 "src/systemadm.vala"
		_tmp4_ = remote;
#line 1062 "src/systemadm.vala"
		_tmp5_ = g_strerror (dbus_error_to_errno (_tmp4_));
#line 1062 "src/systemadm.vala"
		_tmp6_ = g_strdup (_tmp5_);
#line 1062 "src/systemadm.vala"
		_g_free0 (message);
#line 1062 "src/systemadm.vala"
		message = _tmp6_;
#line 1059 "src/systemadm.vala"
		_g_free0 (remote);
#line 7746 "systemadm.c"
	} else {
		gchar* _tmp7_;
		gchar* _tmp8_;
#line 1064 "src/systemadm.vala"
		_tmp7_ = g_strdup ("Error");
#line 1064 "src/systemadm.vala"
		_g_free0 (title);
#line 1064 "src/systemadm.vala"
		title = _tmp7_;
#line 1065 "src/systemadm.vala"
		_tmp8_ = g_strdup ("Error");
#line 1065 "src/systemadm.vala"
		_g_free0 (message);
#line 1065 "src/systemadm.vala"
		message = _tmp8_;
#line 7762 "systemadm.c"
	}
#line 1068 "src/systemadm.vala"
	_tmp9_ = message;
#line 1068 "src/systemadm.vala"
	_tmp10_ = (GtkMessageDialog*) gtk_message_dialog_new ((GtkWindow*) self, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, "%s", _tmp9_);
#line 1068 "src/systemadm.vala"
	g_object_ref_sink (_tmp10_);
#line 1068 "src/systemadm.vala"
	m = _tmp10_;
#line 1072 "src/systemadm.vala"
	_tmp11_ = title;
#line 1072 "src/systemadm.vala"
	gtk_window_set_title ((GtkWindow*) m, _tmp11_);
#line 1073 "src/systemadm.vala"
	_tmp12_ = e->message;
#line 1073 "src/systemadm.vala"
	gtk_message_dialog_format_secondary_text (m, "%s", _tmp12_);
#line 1074 "src/systemadm.vala"
	gtk_dialog_run ((GtkDialog*) m);
#line 1075 "src/systemadm.vala"
	gtk_widget_destroy ((GtkWidget*) m);
#line 1057 "src/systemadm.vala"
	_g_object_unref0 (m);
#line 1057 "src/systemadm.vala"
	_g_free0 (message);
#line 1057 "src/systemadm.vala"
	_g_free0 (title);
#line 7790 "systemadm.c"
}

static void
main_window_class_init (MainWindowClass * klass,
                        gpointer klass_data)
{
#line 84 "src/systemadm.vala"
	main_window_parent_class = g_type_class_peek_parent (klass);
#line 84 "src/systemadm.vala"
	g_type_class_adjust_private_offset (klass, &MainWindow_private_offset);
#line 84 "src/systemadm.vala"
	G_OBJECT_CLASS (klass)->finalize = main_window_finalize;
#line 7803 "systemadm.c"
}

static void
main_window_instance_init (MainWindow * self,
                           gpointer klass)
{
#line 84 "src/systemadm.vala"
	self->priv = main_window_get_instance_private (self);
#line 7812 "systemadm.c"
}

static void
main_window_finalize (GObject * obj)
{
	MainWindow * self;
#line 84 "src/systemadm.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_MAIN_WINDOW, MainWindow);
#line 86 "src/systemadm.vala"
	_g_free0 (self->priv->current_unit_id);
#line 89 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_view);
#line 90 "src/systemadm.vala"
	_g_object_unref0 (self->priv->job_view);
#line 92 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_model);
#line 93 "src/systemadm.vala"
	_g_object_unref0 (self->priv->job_model);
#line 95 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_map);
#line 97 "src/systemadm.vala"
	_g_object_unref0 (self->priv->start_button);
#line 98 "src/systemadm.vala"
	_g_object_unref0 (self->priv->stop_button);
#line 99 "src/systemadm.vala"
	_g_object_unref0 (self->priv->restart_button);
#line 100 "src/systemadm.vala"
	_g_object_unref0 (self->priv->reload_button);
#line 101 "src/systemadm.vala"
	_g_object_unref0 (self->priv->cancel_button);
#line 103 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_load_entry);
#line 104 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_load_button);
#line 106 "src/systemadm.vala"
	_g_object_unref0 (self->priv->server_snapshot_button);
#line 107 "src/systemadm.vala"
	_g_object_unref0 (self->priv->server_reload_button);
#line 109 "src/systemadm.vala"
	_g_object_unref0 (self->priv->manager);
#line 111 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_id_label);
#line 112 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_dependency_label);
#line 113 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_description_label);
#line 114 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_load_state_label);
#line 115 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_active_state_label);
#line 116 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_sub_state_label);
#line 117 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_fragment_path_label);
#line 118 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_active_enter_timestamp_label);
#line 119 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_active_exit_timestamp_label);
#line 120 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_can_start_label);
#line 121 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_can_reload_label);
#line 122 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_cgroup_label);
#line 124 "src/systemadm.vala"
	_g_object_unref0 (self->priv->job_id_label);
#line 125 "src/systemadm.vala"
	_g_object_unref0 (self->priv->job_state_label);
#line 126 "src/systemadm.vala"
	_g_object_unref0 (self->priv->job_type_label);
#line 128 "src/systemadm.vala"
	_g_object_unref0 (self->priv->unit_type_combo_box);
#line 129 "src/systemadm.vala"
	_g_object_unref0 (self->priv->inactive_checkbox);
#line 84 "src/systemadm.vala"
	G_OBJECT_CLASS (main_window_parent_class)->finalize (obj);
#line 7889 "systemadm.c"
}

static GType
main_window_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (MainWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) main_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (MainWindow), 0, (GInstanceInitFunc) main_window_instance_init, NULL };
	GType main_window_type_id;
	main_window_type_id = g_type_register_static (gtk_window_get_type (), "MainWindow", &g_define_type_info, 0);
	MainWindow_private_offset = g_type_add_instance_private (main_window_type_id, sizeof (MainWindowPrivate));
	return main_window_type_id;
}

GType
main_window_get_type (void)
{
	static volatile gsize main_window_type_id__once = 0;
	if (g_once_init_enter (&main_window_type_id__once)) {
		GType main_window_type_id;
		main_window_type_id = main_window_get_type_once ();
		g_once_init_leave (&main_window_type_id__once, main_window_type_id);
	}
	return main_window_type_id__once;
}

gint
dbus_error_to_errno (const gchar* _error_)
{
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label0 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label1 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label2 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label3 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label4 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label5 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label6 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label7 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label8 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label9 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label10 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label11 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label12 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label13 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label14 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label15 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label16 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label17 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label18 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label19 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label20 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label21 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label22 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label23 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label24 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label25 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label26 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label27 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label28 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label29 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label30 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label31 = 0;
#line 1080 "src/systemadm.vala"
	static GQuark _tmp1_label32 = 0;
#line 7985 "systemadm.c"
	gint result;
#line 1079 "src/systemadm.vala"
	g_return_val_if_fail (_error_ != NULL, -1);
#line 1080 "src/systemadm.vala"
	_tmp0_ = _error_;
#line 1080 "src/systemadm.vala"
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
#line 1080 "src/systemadm.vala"
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("org.freedesktop.DBus.Error.Failed")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 7997 "systemadm.c"
			default:
			{
#line 1082 "src/systemadm.vala"
				result = EACCES;
#line 1082 "src/systemadm.vala"
				return result;
#line 8004 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("org.freedesktop.DBus.Error.NoMemory")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8010 "systemadm.c"
			default:
			{
#line 1084 "src/systemadm.vala"
				result = ENOMEM;
#line 1084 "src/systemadm.vala"
				return result;
#line 8017 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label2) ? _tmp1_label2 : (_tmp1_label2 = g_quark_from_static_string ("org.freedesktop.DBus.Error.ServiceUnknown")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8023 "systemadm.c"
			default:
			{
#line 1086 "src/systemadm.vala"
				result = EHOSTUNREACH;
#line 1086 "src/systemadm.vala"
				return result;
#line 8030 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label3) ? _tmp1_label3 : (_tmp1_label3 = g_quark_from_static_string ("org.freedesktop.DBus.Error.NameHasNoOwner")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8036 "systemadm.c"
			default:
			{
#line 1088 "src/systemadm.vala"
				result = ENXIO;
#line 1088 "src/systemadm.vala"
				return result;
#line 8043 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label4) ? _tmp1_label4 : (_tmp1_label4 = g_quark_from_static_string ("org.freedesktop.DBus.Error.NoReply")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8049 "systemadm.c"
			default:
			{
#line 1090 "src/systemadm.vala"
				result = ETIMEDOUT;
#line 1090 "src/systemadm.vala"
				return result;
#line 8056 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label5) ? _tmp1_label5 : (_tmp1_label5 = g_quark_from_static_string ("org.freedesktop.DBus.Error.IOError")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8062 "systemadm.c"
			default:
			{
#line 1092 "src/systemadm.vala"
				result = EIO;
#line 1092 "src/systemadm.vala"
				return result;
#line 8069 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label6) ? _tmp1_label6 : (_tmp1_label6 = g_quark_from_static_string ("org.freedesktop.DBus.Error.BadAddress")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8075 "systemadm.c"
			default:
			{
#line 1094 "src/systemadm.vala"
				result = EADDRNOTAVAIL;
#line 1094 "src/systemadm.vala"
				return result;
#line 8082 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label7) ? _tmp1_label7 : (_tmp1_label7 = g_quark_from_static_string ("org.freedesktop.DBus.Error.NotSupported")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8088 "systemadm.c"
			default:
			{
#line 1096 "src/systemadm.vala"
				result = ENOTSUP;
#line 1096 "src/systemadm.vala"
				return result;
#line 8095 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label8) ? _tmp1_label8 : (_tmp1_label8 = g_quark_from_static_string ("org.freedesktop.DBus.Error.LimitsExceeded")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8101 "systemadm.c"
			default:
			{
#line 1098 "src/systemadm.vala"
				result = ENOBUFS;
#line 1098 "src/systemadm.vala"
				return result;
#line 8108 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label9) ? _tmp1_label9 : (_tmp1_label9 = g_quark_from_static_string ("org.freedesktop.DBus.Error.AccessDenied")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8114 "systemadm.c"
			default:
			{
#line 1100 "src/systemadm.vala"
				result = EACCES;
#line 1100 "src/systemadm.vala"
				return result;
#line 8121 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label10) ? _tmp1_label10 : (_tmp1_label10 = g_quark_from_static_string ("org.freedesktop.DBus.Error.AuthFailed")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8127 "systemadm.c"
			default:
			{
#line 1102 "src/systemadm.vala"
				result = EACCES;
#line 1102 "src/systemadm.vala"
				return result;
#line 8134 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label11) ? _tmp1_label11 : (_tmp1_label11 = g_quark_from_static_string ("org.freedesktop.DBus.Error.NoServer")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8140 "systemadm.c"
			default:
			{
#line 1106 "src/systemadm.vala"
				result = EIO;
#line 1106 "src/systemadm.vala"
				return result;
#line 8147 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label12) ? _tmp1_label12 : (_tmp1_label12 = g_quark_from_static_string ("org.freedesktop.DBus.Error.Timeout")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8153 "systemadm.c"
			default:
			{
#line 1108 "src/systemadm.vala"
				result = ETIMEDOUT;
#line 1108 "src/systemadm.vala"
				return result;
#line 8160 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label13) ? _tmp1_label13 : (_tmp1_label13 = g_quark_from_static_string ("org.freedesktop.DBus.Error.NoNetwork")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8166 "systemadm.c"
			default:
			{
#line 1112 "src/systemadm.vala"
				result = EIO;
#line 1112 "src/systemadm.vala"
				return result;
#line 8173 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label14) ? _tmp1_label14 : (_tmp1_label14 = g_quark_from_static_string ("org.freedesktop.DBus.Error.AddressInUse")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8179 "systemadm.c"
			default:
			{
#line 1114 "src/systemadm.vala"
				result = EADDRINUSE;
#line 1114 "src/systemadm.vala"
				return result;
#line 8186 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label15) ? _tmp1_label15 : (_tmp1_label15 = g_quark_from_static_string ("org.freedesktop.DBus.Error.Disconnected")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8192 "systemadm.c"
			default:
			{
#line 1116 "src/systemadm.vala"
				result = ECONNRESET;
#line 1116 "src/systemadm.vala"
				return result;
#line 8199 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label16) ? _tmp1_label16 : (_tmp1_label16 = g_quark_from_static_string ("org.freedesktop.DBus.Error.InvalidArgs")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8205 "systemadm.c"
			default:
			{
#line 1118 "src/systemadm.vala"
				result = EINVAL;
#line 1118 "src/systemadm.vala"
				return result;
#line 8212 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label17) ? _tmp1_label17 : (_tmp1_label17 = g_quark_from_static_string ("org.freedesktop.DBus.Error.FileNotFound")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8218 "systemadm.c"
			default:
			{
#line 1120 "src/systemadm.vala"
				result = ENOENT;
#line 1120 "src/systemadm.vala"
				return result;
#line 8225 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label18) ? _tmp1_label18 : (_tmp1_label18 = g_quark_from_static_string ("org.freedesktop.DBus.Error.FileExists")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8231 "systemadm.c"
			default:
			{
#line 1122 "src/systemadm.vala"
				result = EEXIST;
#line 1122 "src/systemadm.vala"
				return result;
#line 8238 "systemadm.c"
			}
		}
	} else if ((((_tmp2_ == ((0 != _tmp1_label19) ? _tmp1_label19 : (_tmp1_label19 = g_quark_from_static_string ("org.freedesktop.DBus.Error.UnknownMethod")))) || (_tmp2_ == ((0 != _tmp1_label20) ? _tmp1_label20 : (_tmp1_label20 = g_quark_from_static_string ("org.freedesktop.DBus.Error.UnknownObject"))))) || (_tmp2_ == ((0 != _tmp1_label21) ? _tmp1_label21 : (_tmp1_label21 = g_quark_from_static_string ("org.freedesktop.DBus.Error.UnknownInterface"))))) || (_tmp2_ == ((0 != _tmp1_label22) ? _tmp1_label22 : (_tmp1_label22 = g_quark_from_static_string ("org.freedesktop.DBus.Error.UnknownProperty"))))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8244 "systemadm.c"
			default:
			{
#line 1129 "src/systemadm.vala"
				result = EIO;
#line 1129 "src/systemadm.vala"
				return result;
#line 8251 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label23) ? _tmp1_label23 : (_tmp1_label23 = g_quark_from_static_string ("org.freedesktop.DBus.Error.PropertyReadOnly")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8257 "systemadm.c"
			default:
			{
#line 1131 "src/systemadm.vala"
				result = EROFS;
#line 1131 "src/systemadm.vala"
				return result;
#line 8264 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label24) ? _tmp1_label24 : (_tmp1_label24 = g_quark_from_static_string ("org.freedesktop.DBus.Error.UnixProcessIdUnknown")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8270 "systemadm.c"
			default:
			{
#line 1133 "src/systemadm.vala"
				result = ESRCH;
#line 1133 "src/systemadm.vala"
				return result;
#line 8277 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label25) ? _tmp1_label25 : (_tmp1_label25 = g_quark_from_static_string ("org.freedesktop.DBus.Error.InvalidSignature")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8283 "systemadm.c"
			default:
			{
#line 1135 "src/systemadm.vala"
				result = EINVAL;
#line 1135 "src/systemadm.vala"
				return result;
#line 8290 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label26) ? _tmp1_label26 : (_tmp1_label26 = g_quark_from_static_string ("org.freedesktop.DBus.Error.InconsistentMessage")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8296 "systemadm.c"
			default:
			{
#line 1137 "src/systemadm.vala"
				result = EBADMSG;
#line 1137 "src/systemadm.vala"
				return result;
#line 8303 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label27) ? _tmp1_label27 : (_tmp1_label27 = g_quark_from_static_string ("org.freedesktop.DBus.Error.TimedOut")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8309 "systemadm.c"
			default:
			{
#line 1139 "src/systemadm.vala"
				result = ETIMEDOUT;
#line 1139 "src/systemadm.vala"
				return result;
#line 8316 "systemadm.c"
			}
		}
	} else if ((_tmp2_ == ((0 != _tmp1_label28) ? _tmp1_label28 : (_tmp1_label28 = g_quark_from_static_string ("org.freedesktop.DBus.Error.MatchRuleInvalid")))) || (_tmp2_ == ((0 != _tmp1_label29) ? _tmp1_label29 : (_tmp1_label29 = g_quark_from_static_string ("org.freedesktop.DBus.Error.InvalidFileContent"))))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8322 "systemadm.c"
			default:
			{
#line 1142 "src/systemadm.vala"
				result = EINVAL;
#line 1142 "src/systemadm.vala"
				return result;
#line 8329 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label30) ? _tmp1_label30 : (_tmp1_label30 = g_quark_from_static_string ("org.freedesktop.DBus.Error.MatchRuleNotFound")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8335 "systemadm.c"
			default:
			{
#line 1144 "src/systemadm.vala"
				result = ENOENT;
#line 1144 "src/systemadm.vala"
				return result;
#line 8342 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label31) ? _tmp1_label31 : (_tmp1_label31 = g_quark_from_static_string ("org.freedesktop.DBus.Error.SELinuxSecurityContextUnknown")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8348 "systemadm.c"
			default:
			{
#line 1146 "src/systemadm.vala"
				result = ESRCH;
#line 1146 "src/systemadm.vala"
				return result;
#line 8355 "systemadm.c"
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label32) ? _tmp1_label32 : (_tmp1_label32 = g_quark_from_static_string ("org.freedesktop.DBus.Error.ObjectPathInUse")))) {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8361 "systemadm.c"
			default:
			{
#line 1148 "src/systemadm.vala"
				result = EBUSY;
#line 1148 "src/systemadm.vala"
				return result;
#line 8368 "systemadm.c"
			}
		}
	} else {
#line 1080 "src/systemadm.vala"
		switch (0) {
#line 8374 "systemadm.c"
			default:
			{
#line 1150 "src/systemadm.vala"
				result = EIO;
#line 1150 "src/systemadm.vala"
				return result;
#line 8381 "systemadm.c"
			}
		}
	}
}

void
show_error (GError* e)
{
	GtkMessageDialog* m = NULL;
	const gchar* _tmp0_;
	GtkMessageDialog* _tmp1_;
#line 1160 "src/systemadm.vala"
	g_return_if_fail (e != NULL);
#line 1161 "src/systemadm.vala"
	_tmp0_ = e->message;
#line 1161 "src/systemadm.vala"
	_tmp1_ = (GtkMessageDialog*) gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, "%s", _tmp0_);
#line 1161 "src/systemadm.vala"
	g_object_ref_sink (_tmp1_);
#line 1161 "src/systemadm.vala"
	m = _tmp1_;
#line 1162 "src/systemadm.vala"
	gtk_dialog_run ((GtkDialog*) m);
#line 1163 "src/systemadm.vala"
	gtk_widget_destroy ((GtkWidget*) m);
#line 1160 "src/systemadm.vala"
	_g_object_unref0 (m);
#line 8409 "systemadm.c"
}

static gint
_vala_main (gchar** args,
            gint args_length1)
{
	GError* _inner_error0_ = NULL;
	gint result;
	{
		MainWindow* window = NULL;
		MainWindow* _tmp0_;
		MainWindow* _tmp1_;
#line 1169 "src/systemadm.vala"
		gtk_init_with_args ((gint*) (&args_length1), &args, "[OPTION...]", entries, "systemadm", &_inner_error0_);
#line 1169 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1169 "src/systemadm.vala"
			if (_inner_error0_->domain == G_IO_ERROR) {
#line 8428 "systemadm.c"
				goto __catch0_g_io_error;
			}
			goto __catch0_g_error;
		}
#line 1171 "src/systemadm.vala"
		_tmp0_ = main_window_new (&_inner_error0_);
#line 1171 "src/systemadm.vala"
		g_object_ref_sink (_tmp0_);
#line 1171 "src/systemadm.vala"
		window = _tmp0_;
#line 1171 "src/systemadm.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1171 "src/systemadm.vala"
			if (_inner_error0_->domain == G_IO_ERROR) {
#line 8443 "systemadm.c"
				goto __catch0_g_io_error;
			}
			goto __catch0_g_error;
		}
#line 1172 "src/systemadm.vala"
		_tmp1_ = window;
#line 1172 "src/systemadm.vala"
		gtk_widget_show_all ((GtkWidget*) _tmp1_);
#line 1174 "src/systemadm.vala"
		gtk_main ();
#line 1168 "src/systemadm.vala"
		_g_object_unref0 (window);
#line 8456 "systemadm.c"
	}
	goto __finally0;
	__catch0_g_io_error:
	{
		GError* e = NULL;
		GError* _tmp2_;
#line 1168 "src/systemadm.vala"
		e = _inner_error0_;
#line 1168 "src/systemadm.vala"
		_inner_error0_ = NULL;
#line 1176 "src/systemadm.vala"
		_tmp2_ = e;
#line 1176 "src/systemadm.vala"
		show_error (_tmp2_);
#line 1168 "src/systemadm.vala"
		_g_error_free0 (e);
#line 8473 "systemadm.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		FILE* _tmp3_;
		GError* _tmp4_;
		const gchar* _tmp5_;
#line 1168 "src/systemadm.vala"
		e = _inner_error0_;
#line 1168 "src/systemadm.vala"
		_inner_error0_ = NULL;
#line 1178 "src/systemadm.vala"
		_tmp3_ = stderr;
#line 1178 "src/systemadm.vala"
		_tmp4_ = e;
#line 1178 "src/systemadm.vala"
		_tmp5_ = _tmp4_->message;
#line 1178 "src/systemadm.vala"
		fprintf (_tmp3_, "%s\n", _tmp5_);
#line 1168 "src/systemadm.vala"
		_g_error_free0 (e);
#line 8496 "systemadm.c"
	}
	__finally0:
#line 1168 "src/systemadm.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 8501 "systemadm.c"
		gint _tmp6_ = -1;
#line 1168 "src/systemadm.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 1168 "src/systemadm.vala"
		g_clear_error (&_inner_error0_);
#line 1168 "src/systemadm.vala"
		return _tmp6_;
#line 8509 "systemadm.c"
	}
#line 1181 "src/systemadm.vala"
	result = 0;
#line 1181 "src/systemadm.vala"
	return result;
#line 8515 "systemadm.c"
}

int
main (int argc,
      char ** argv)
{
#line 1166 "src/systemadm.vala"
	return _vala_main (argv, argc);
#line 8524 "systemadm.c"
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

